@@ -50,6 +50,11 @@ from binarycpython.tests.test_ensemble import (
     test_load_ensemble,
     test_open_ensemble,
 )
+from binarycpython.tests.test_event_logging import (
+    test_event_file_processing,
+    test_event_parameter_descriptions,
+    test_event_types,
+)
 from binarycpython.tests.test_functions import (
     test_bin_data,
     test_create_arg_string,
@@ -69,11 +74,11 @@ from binarycpython.tests.test_functions import (
 )
 from binarycpython.tests.test_grid import (
     test__cleanup_defaults,
-    test__dict_from_line_source_file,
     test__increment_count,
     test__increment_probtot,
     test__return_argline,
     test__setup,
+    test__source_file_sampling_system_dict_from_line_command_style,
     test_cmdline,
     test_evolve_single,
     test_export_all_info,
@@ -129,11 +134,6 @@ from binarycpython.tests.tests_population_extensions.test_distribution_functions
     test_sana12,
     test_three_part_power_law,
 )
-from binarycpython.tests.tests_population_extensions.test_grid_options_defaults import (
-    test_grid_options_description_checker,
-    test_grid_options_help,
-    test_write_grid_options_to_rst_file,
-)
 from binarycpython.tests.tests_population_extensions.test_HPC import (
     test_HPC_check_requirements,
     test_HPC_dir,
@@ -149,8 +149,12 @@ from binarycpython.tests.tests_population_extensions.test_HPC import (
     test_HPC_njobs,
     test_HPC_set_status,
 )
-from binarycpython.tests.tests_population_extensions.test_sampling_variables import (
-    test_add_grid_variable,
+from binarycpython.tests.tests_population_extensions.test_population_options_defaults import (
+    test_population_options_description_checker,
+    test_population_options_validation,
+    test_write_population_options_to_rst_file,
+)
+from binarycpython.tests.tests_population_extensions.test_sampling_variables import (  # test_add_grid_variable,
     test_add_sampling_variable,
 )
 from binarycpython.tests.tests_population_extensions.test_slurm import (
@@ -162,15 +166,17 @@ from binarycpython.tests.tests_population_extensions.test_slurm import (
     test_slurm_outfile,
     test_slurmID,
 )
+from binarycpython.tests.tests_population_extensions.test_source_file_sampling import (
+    test_source_file_sampling_column_type,
+    test_source_file_sampling_command_type,
+)
+from binarycpython.tests.tests_population_extensions.test_spacing_functions import (
+    test_const,
+)
 from binarycpython.tests.tests_population_extensions.test_version_info import (
     test_parse_binary_c_version_info,
     test_return_binary_c_version_info,
 )
 
-# from binarycpython.tests.test_spacing_functions import *
-# from binarycpython.tests.test_grid_options_defaults import *
-# from binarycpython.tests.test_hpc_functions import *
-
-
 if __name__ == "__main__":
     unittest.main()
