@@ -1,7 +1,13 @@
 #!/usr/bin/python3
 
-from binarycpython import _binary_c_bindings
+"""
+Some tests that can be run quickly
+TODO: turn these into real tests
+"""
 
+import textwrap
+
+from binarycpython import _binary_c_bindings
 from binarycpython.utils.custom_logging_functions import (
     autogen_C_logging_code,
     binary_c_log_code,
@@ -9,9 +15,6 @@ from binarycpython.utils.custom_logging_functions import (
 )
 from binarycpython.utils.functions import temp_dir
 
-import tempfile
-import textwrap
-
 ############################################################
 # Test script for the api functions
 # unittests
@@ -20,6 +23,10 @@ import textwrap
 
 # Evolution functions
 def test_run_system():
+    """
+    Test if run_system runs without errors
+    """
+
     m1 = 15.0  # Msun
     m2 = 14.0  # Msun
     separation = 0  # 0 = ignored, use period
@@ -44,6 +51,10 @@ def test_run_system():
 
 
 def test_run_system_with_log():
+    """
+    Test if run_system runs with outputting a logfile
+    """
+
     m1 = 15.0  # Msun
     m2 = 14.0  # Msun
     separation = 0  # 0 = ignored, use period
@@ -75,6 +86,10 @@ def test_run_system_with_log():
 
 
 def test_run_system_with_custom_logging():
+    """
+    Test if run_system runs with custom logging
+    """
+
     # generate logging lines. Here you can choose whatever you want to have logged, and with what header
     # this generates working print statements
     logging_line = autogen_C_logging_code(
@@ -124,6 +139,10 @@ def test_run_system_with_custom_logging():
 
 # Testing other utility functions
 def test_return_help():
+    """
+    Test if return_help runs without errors
+    """
+
     output = _binary_c_bindings.return_help("M_1")
 
     print("function: test_return_help")
@@ -132,6 +151,10 @@ def test_return_help():
 
 
 def test_return_arglines():
+    """
+    Test if return_arglines runs without errors
+    """
+
     output = _binary_c_bindings.return_arglines()
 
     print("function: test_return_arglines")
@@ -140,6 +163,10 @@ def test_return_arglines():
 
 
 def test_return_help_all():
+    """
+    Test if return_help_all runs without errors
+    """
+
     output = _binary_c_bindings.return_help_all("M_1")
 
     print("function: test_return_help_all")
@@ -148,6 +175,10 @@ def test_return_help_all():
 
 
 def test_return_version_info():
+    """
+    Test if return_version_info runs without errors
+    """
+
     output = _binary_c_bindings.return_version_info()
 
     print("function: test_return_version_info")
@@ -157,6 +188,10 @@ def test_return_version_info():
 
 # Testing other functions
 def test_return_store():
+    """
+    Test if return_store runs without errors
+    """
+
     output = _binary_c_bindings.return_store_memaddr("")
 
     print("function: test_return_store")
