@@ -11,7 +11,7 @@ from binarycpython.utils.dicts import merge_dicts
 from binarycpython.utils.ensemble import extract_ensemble_json_from_string
 from binarycpython.utils.functions import Capturing, is_capsule, temp_dir
 
-TMP_DIR = temp_dir("tests", "test_c_bindings")
+TMP_DIR = temp_dir("tests", "test_c_bindings", clean_path=True)
 
 
 #### some useful functions
