@@ -16,7 +16,7 @@ from binarycpython.utils.custom_logging_functions import (
 )
 from binarycpython.utils.functions import Capturing, temp_dir
 
-TMP_DIR = temp_dir("tests", "test_custom_logging")
+TMP_DIR = temp_dir("tests", "test_custom_logging", clean_path=True)
 
 
 class test_autogen_C_logging_code(unittest.TestCase):
@@ -155,7 +155,7 @@ class test_from_binary_c_config(unittest.TestCase):
         output_2 = from_binary_c_config(BINARY_C_CONFIG, input_2)
         self.assertIn(
             output_2,
-            ["2.2.3"],
+            ["2.2.4"],
             msg="binary_c version doesnt match",
         )
 
