@@ -31,7 +31,7 @@ from binarycpython.utils.dicts import (
 )
 from binarycpython.utils.functions import Capturing, temp_dir
 
-TMP_DIR = temp_dir("tests", "test_dicts")
+TMP_DIR = temp_dir("tests", "test_dicts", clean_path=True)
 
 
 class dummy:
