@@ -22,7 +22,7 @@ from binarycpython.utils.ensemble import (
 from binarycpython.utils.functions import Capturing, temp_dir
 from binarycpython.utils.population_class import Population
 
-TMP_DIR = temp_dir("tests", "test_ensemble")
+TMP_DIR = temp_dir("tests", "test_ensemble", clean_path=True)
 TEST_VERBOSITY = 1
 
 
