@@ -26,6 +26,7 @@ TODO: call_binary_c_config
 import json
 import os
 import tempfile
+import types
 import unittest
 
 import h5py
@@ -52,7 +53,7 @@ from binarycpython.utils.functions import (
 )
 from binarycpython.utils.run_system_wrapper import run_system
 
-TMP_DIR = temp_dir("tests", "test_functions")
+TMP_DIR = temp_dir("tests", "test_functions", clean_path=True)
 
 
 class test_verbose_print(unittest.TestCase):
@@ -202,7 +203,7 @@ class test_output_lines(unittest.TestCase):
         example_text = "hallo\ntest\n123"
         output_1 = output_lines(example_text)
 
-        self.assertTrue(isinstance(output_1, list))
+        self.assertTrue(isinstance(output_1, (list, types.GeneratorType)))
         self.assertIn("hallo", output_1)
         self.assertIn("test", output_1)
         self.assertIn("123", output_1)
@@ -603,4 +604,6 @@ class test_bin_data(unittest.TestCase):
 
 
 if __name__ == "__main__":
-    unittest.main()
+    # unittest.main()
+    test_output_lines_obj = test_output_lines()
+    test_output_lines_obj._test_1()
