@@ -19,8 +19,6 @@ TODO: _dry_run_source_file
 TODO: _load_source_file
 TODO: was_killed
 TODO: _check_binary_c_error
-
-TODO: Before running the non-unit tests to cover functions like evolve, we need to run the unit tests
 """
 
 import gzip
@@ -33,10 +31,16 @@ import unittest
 import numpy as np
 
 from binarycpython.utils.dicts import merge_dicts
-from binarycpython.utils.functions import Capturing, bin_data, remove_file, temp_dir
+from binarycpython.utils.functions import (
+    Capturing,
+    bin_data,
+    output_lines,
+    remove_file,
+    temp_dir,
+)
 from binarycpython.utils.population_class import Population
 
-TMP_DIR = temp_dir("tests", "test_grid")
+TMP_DIR = temp_dir("tests", "test_grid", clean_path=True)
 shutil.rmtree(TMP_DIR)
 os.makedirs(TMP_DIR, exist_ok=True)
 
@@ -57,7 +61,7 @@ def parse_function_test_grid_evolve_2_threads_with_custom_logging(
     output_filename = os.path.join(
         data_dir,
         "test_grid_evolve_2_threads_with_custom_logging_outputfile_population_{}_thread_{}.dat".format(
-            self.grid_options["_population_id"], self.process_ID
+            self.population_options["_population_id"], self.process_ID
         ),
     )
 
@@ -79,10 +83,10 @@ def parse_function_adding_results(self, output):  # pragma: no cover
 
     parameters = ["time", "mass", "zams_mass", "probability", "stellar_type"]
 
-    self.grid_results["example"]["count"] += 1
+    self.population_results["example"]["count"] += 1
 
     # Go over the output.
-    for line in output.splitlines():
+    for line in output_lines(output):
         headerline = line.split()[0]
 
         # CHeck the header and act accordingly
@@ -90,7 +94,7 @@ def parse_function_adding_results(self, output):  # pragma: no cover
             values = line.split()[1:]
 
             # Bin the mass probability
-            self.grid_results["example"]["mass"][
+            self.population_results["example"]["mass"][
                 bin_data(float(values[2]), binwidth=0.5)
             ] += float(values[3])
 
@@ -100,7 +104,7 @@ def parse_function_adding_results(self, output):  # pragma: no cover
                 raise ValueError
 
     # record the probability of this line (Beware, this is meant to only be run once for each system. its a controls quantity)
-    self.grid_results["example"]["probability"] += float(values[3])
+    self.population_results["example"]["probability"] += float(values[3])
 
 
 class test__setup(unittest.TestCase):
@@ -122,11 +126,10 @@ class test__setup(unittest.TestCase):
         self.assertTrue("metallicity" in test_pop.defaults)
         self.assertNotIn("help_all", test_pop.cleaned_up_defaults)
         self.assertEqual(test_pop.bse_options, {})
-        self.assertEqual(test_pop.custom_options, {"save_snapshot": False})
         self.assertEqual(test_pop.argline_dict, {})
         self.assertEqual(test_pop.persistent_data_memory_dict, {})
-        self.assertTrue(test_pop.grid_options["parse_function"] is None)
-        self.assertTrue(isinstance(test_pop.grid_options["_main_pid"], int))
+        self.assertTrue(test_pop.population_options["parse_function"] is None)
+        self.assertTrue(isinstance(test_pop.population_options["_main_pid"], int))
 
 
 class test_set(unittest.TestCase):
@@ -163,7 +166,7 @@ class test_set(unittest.TestCase):
 
         # test grid options
         test_pop.set(num_cores=2)
-        self.assertTrue(test_pop.grid_options["num_cores"] == 2)
+        self.assertTrue(test_pop.population_options["num_cores"] == 2)
 
 
 class test_cmdline(unittest.TestCase):
@@ -204,14 +207,12 @@ class test_cmdline(unittest.TestCase):
         self.assertTrue(test_pop.bse_options["metallicity"] == "0.0002")
 
         # Number of cores
-        print(test_pop.grid_options["num_cores"])
-        print(type(test_pop.grid_options["num_cores"]))
         self.assertTrue(
-            isinstance(test_pop.grid_options["num_cores"], int)
-            or isinstance(test_pop.grid_options["num_cores"], dict)
-            or isinstance(test_pop.grid_options["num_cores"], str)
+            isinstance(test_pop.population_options["num_cores"], int)
+            or isinstance(test_pop.population_options["num_cores"], dict)
+            or isinstance(test_pop.population_options["num_cores"], str)
         )
-        self.assertTrue(test_pop.grid_options["num_cores"] == 2)
+        self.assertTrue(test_pop.population_options["num_cores"] == 2)
 
         # datadir
         self.assertTrue(isinstance(test_pop.custom_options["data_dir"], str))
@@ -278,8 +279,8 @@ class test_return_population_settings(unittest.TestCase):
         self.assertTrue(population_settings["bse_options"]["metallicity"] == 0.02)
         self.assertTrue(population_settings["bse_options"]["M_1"] == 10)
 
-        self.assertIn("grid_options", population_settings)
-        self.assertTrue(population_settings["grid_options"]["num_cores"] == 2)
+        self.assertIn("population_options", population_settings)
+        self.assertTrue(population_settings["population_options"]["num_cores"] == 2)
 
         self.assertIn("custom_options", population_settings)
         self.assertTrue(population_settings["custom_options"]["data_dir"] == "/tmp")
@@ -442,7 +443,7 @@ class test__increment_probtot(unittest.TestCase):
 
         test_pop = Population(tmp_dir=TMP_DIR)
         test_pop._increment_probtot(0.5)
-        self.assertEqual(test_pop.grid_options["_probtot"], 0.5)
+        self.assertEqual(test_pop.population_options["_probtot"], 0.5)
 
 
 class test__increment_count(unittest.TestCase):
@@ -461,21 +462,21 @@ class test__increment_count(unittest.TestCase):
 
         test_pop = Population(tmp_dir=TMP_DIR)
         test_pop._increment_count()
-        self.assertEqual(test_pop.grid_options["_count"], 1)
+        self.assertEqual(test_pop.population_options["_count"], 1)
 
 
-class test__dict_from_line_source_file(unittest.TestCase):
+class test__source_file_sampling_system_dict_from_line_command_style(unittest.TestCase):
     """
     Unittests for _dict_from_line_source_file function
     """
 
-    def test__dict_from_line_source_file(self):
+    def test__source_file_sampling_system_dict_from_line_command_style(self):
         with Capturing() as _:
-            self._test__dict_from_line_source_file()
+            self._test__source_file_sampling_system_dict_from_line_command_style()
 
-    def _test__dict_from_line_source_file(self):
+    def _test__source_file_sampling_system_dict_from_line_command_style(self):
         """
-        Unittests for the function _dict_from_line_source_file
+        Unittests for the function _source_file_sampling_system_dict_from_line_command_style
         """
 
         source_file = os.path.join(TMP_DIR, "example_source_file.txt")
@@ -489,7 +490,11 @@ class test__dict_from_line_source_file(unittest.TestCase):
         # readout
         with open(source_file, "r") as f:
             for line in f.readlines():
-                argdict = test_pop._dict_from_line_source_file(line)
+                argdict = (
+                    test_pop._source_file_sampling_system_dict_from_line_command_style(
+                        line
+                    )
+                )
 
                 self.assertTrue(argdict["M_1"] == 10)
                 self.assertTrue(argdict["metallicity"] == 0.02)
@@ -599,7 +604,7 @@ class test_resultdict(unittest.TestCase):
         example_pop.set(verbosity=0)
         example_pop.set(
             max_evolution_time=15000,  # bse_options
-            # grid_options
+            # population_options
             num_cores=3,
             tmp_dir=TMP_DIR,
             # Custom options
@@ -624,7 +629,7 @@ class test_resultdict(unittest.TestCase):
             dphasevol="dlnm1",
             parameter_name="M_1",
             condition="",  # Impose a condition on this grid variable. Mostly for a check for yourself
-            gridtype="left",
+            gridtype="centred",
         )
 
         ## Executing a population
@@ -633,11 +638,11 @@ class test_resultdict(unittest.TestCase):
 
         #
         grid_prob = analytics["total_probability"]
-        result_dict_prob = example_pop.grid_results["example"]["probability"]
+        result_dict_prob = example_pop.population_results["example"]["probability"]
 
         # amt systems
         grid_count = analytics["total_count"]
-        result_dict_count = example_pop.grid_results["example"]["count"]
+        result_dict_count = example_pop.population_results["example"]["count"]
 
         # Check if the total probability matches
         self.assertAlmostEqual(
@@ -660,20 +665,19 @@ class test_resultdict(unittest.TestCase):
 
         # Check if the structure is what we expect. Note: this depends on the probability calculation. if that changes we need to recalibrate this
         test_case_dict = {
-            2.25: 0.01895481306515,
-            3.75: 0.01081338190204,
-            5.75: 0.006168841009268,
-            9.25: 0.003519213484031,
-            13.75: 0.002007648361756,
-            21.25: 0.001145327489437,
-            33.25: 0.0006533888518775,
-            50.75: 0.0003727466560393,
-            78.25: 0.000212645301782,
-            120.75: 0.0001213103421247,
+            2.75: 0.02041431854182,
+            4.25: 0.01094189907528,
+            6.75: 0.005864763750417,
+            10.75: 0.003143462904527,
+            17.25: 0.001684869067647,
+            27.75: 0.0009030753221317,
+            45.25: 0.0004840406017911,
+            73.25: 0.0002594415974398,
+            118.25: 0.0001390584637591,
         }
 
         self.assertEqual(
-            test_case_dict, dict(example_pop.grid_results["example"]["mass"])
+            test_case_dict, dict(example_pop.population_results["example"]["mass"])
         )
 
 
@@ -714,11 +718,11 @@ class test_grid_evolve(unittest.TestCase):
 
         analytics = test_pop_evolve_1_thread.evolve()
         self.assertLess(
-            np.abs(analytics["total_probability"] - 0.10820655287892997),
+            np.abs(analytics["total_probability"] - 0.10783066961989227),
             1e-10,
-            msg=analytics["total_probability"],
+            msg=analytics["total_probability"] - 0.10783066961989227,
         )
-        self.assertTrue(analytics["total_count"] == 10)
+        self.assertTrue(analytics["total_count"] == 9)
 
     def test_grid_evolve_2_threads(self):
         with Capturing() as _:
@@ -751,12 +755,13 @@ class test_grid_evolve(unittest.TestCase):
         )
 
         analytics = test_pop.evolve()
+        print(analytics["total_probability"])
         self.assertLess(
-            np.abs(analytics["total_probability"] - 0.10820655287892997),
+            np.abs(analytics["total_probability"] - 0.10783066961989227),
             1e-10,
-            msg=analytics["total_probability"],
+            msg=np.abs(analytics["total_probability"] - 0.10783066961989227),
         )  #
-        self.assertTrue(analytics["total_count"] == 10)
+        self.assertTrue(analytics["total_count"] == 9)
 
     def test_grid_evolve_2_threads_with_custom_logging(self):
         with Capturing() as _:
@@ -871,13 +876,13 @@ Printf("TEST_CUSTOM_LOGGING_1 %30.12e %g %g %g %g\\n",
 
         analytics = test_pop.evolve()
         self.assertLess(
-            np.abs(analytics["total_probability"] - 0.10820655287892997),
+            np.abs(analytics["total_probability"] - 0.10783066961989227),
             1e-10,
             msg=analytics["total_probability"],
         )  #
         self.assertEqual(analytics["failed_systems_error_codes"], [0])
-        self.assertTrue(analytics["total_count"] == 10)
-        self.assertTrue(analytics["failed_count"] == 10)
+        self.assertTrue(analytics["total_count"] == 9)
+        self.assertTrue(analytics["failed_count"] == 9)
         self.assertTrue(analytics["errors_found"] is True)
         self.assertTrue(analytics["errors_exceeded"] is True)
 
