@@ -1,3 +1,4 @@
+# /usr/bin/env python
 """
 Notebook tests
 """
@@ -10,7 +11,7 @@ from nbconvert.preprocessors import ExecutePreprocessor
 
 from binarycpython.utils.functions import temp_dir
 
-TMP_DIR = temp_dir("testing", "test_notebooks")
+TMP_DIR = temp_dir("testing", "test_notebooks", clean_path=True)
 NOTEBOOKS_DIR = os.path.abspath(
     os.path.join(os.path.abspath(__file__), "../../../examples")
 )
@@ -18,16 +19,19 @@ NOTEBOOKS_DIR = os.path.abspath(
 # define notebooks
 notebooks = [
     "notebook_api_functionality.ipynb",
-    "notebook_population.ipynb",
-    "notebook_individual_systems.ipynb",
-    "notebook_custom_logging.ipynb",
-    "notebook_extra_features.ipynb",
-    "notebook_luminosity_function_single.ipynb",
-    "notebook_luminosity_function_binaries.ipynb",
     "notebook_BHBH.ipynb",
     "notebook_common_envelope_evolution.ipynb",
+    "notebook_custom_logging.ipynb",
     "notebook_ensembles.ipynb",
+    "notebook_event_based_logging.ipynb",
+    "notebook_extra_features.ipynb",
+    "notebook_HRD.ipynb",
+    "notebook_individual_systems.ipynb",
+    "notebook_luminosity_function_binaries.ipynb",
+    "notebook_luminosity_function_single.ipynb",
+    "notebook_population.ipynb",
     "notebook_solar_system.ipynb",
+    "notebook_source_file_sampling.ipynb",
 ]
 
 
