@@ -6,7 +6,7 @@ Unittests for run_system_wrapper
 
 import unittest
 
-from binarycpython.utils.run_system_wrapper import run_system
+# from binarycpython.utils.run_system_wrapper import run_system
 
 if __name__ == "__main__":
     unittest.main()
