@@ -47,8 +47,8 @@ class test_HPC_njobs(unittest.TestCase):
         """
 
         condor_pop = Population()
-        condor_pop.grid_options["condor"] = 1
-        condor_pop.grid_options["condor_njobs"] = 10
+        condor_pop.population_options["condor"] = 1
+        condor_pop.population_options["condor_njobs"] = 10
 
         result_condor = condor_pop.HPC_njobs()
 
@@ -64,8 +64,8 @@ class test_HPC_njobs(unittest.TestCase):
         """
 
         slurm_pop = Population()
-        slurm_pop.grid_options["slurm"] = 1
-        slurm_pop.grid_options["slurm_njobs"] = 11
+        slurm_pop.population_options["slurm"] = 1
+        slurm_pop.population_options["slurm_njobs"] = 11
 
         result_slurm = slurm_pop.HPC_njobs()
 
@@ -99,7 +99,7 @@ class test_HPC_job(unittest.TestCase):
         """
 
         slurm_pop = Population()
-        slurm_pop.grid_options["slurm"] = 1
+        slurm_pop.population_options["slurm"] = 1
 
         self.assertTrue(slurm_pop.HPC_job())
 
@@ -119,7 +119,7 @@ class test_HPC_job_type(unittest.TestCase):
         """
 
         condor_pop = Population()
-        condor_pop.grid_options["condor"] = 1
+        condor_pop.population_options["condor"] = 1
         result_condor = condor_pop.HPC_job_type()
 
         self.assertEqual(result_condor, "condor")
@@ -134,7 +134,7 @@ class test_HPC_job_type(unittest.TestCase):
         """
 
         slurm_pop = Population()
-        slurm_pop.grid_options["slurm"] = 1
+        slurm_pop.population_options["slurm"] = 1
         result_slurm = slurm_pop.HPC_job_type()
 
         self.assertEqual(result_slurm, "slurm")
@@ -168,9 +168,9 @@ class test_HPC_jobID(unittest.TestCase):
         """
 
         condor_pop = Population()
-        condor_pop.grid_options["condor"] = 1
-        condor_pop.grid_options["condor_ClusterID"] = 2
-        condor_pop.grid_options["condor_Process"] = 3
+        condor_pop.population_options["condor"] = 1
+        condor_pop.population_options["condor_ClusterID"] = 2
+        condor_pop.population_options["condor_Process"] = 3
 
         self.assertEqual(
             condor_pop.HPC_jobID(),
@@ -187,9 +187,9 @@ class test_HPC_jobID(unittest.TestCase):
         """
 
         slurm_pop = Population()
-        slurm_pop.grid_options["slurm"] = 1
-        slurm_pop.grid_options["slurm_jobid"] = 4
-        slurm_pop.grid_options["slurm_jobarrayindex"] = 5
+        slurm_pop.population_options["slurm"] = 1
+        slurm_pop.population_options["slurm_jobid"] = 4
+        slurm_pop.population_options["slurm_jobarrayindex"] = 5
 
         self.assertEqual(
             slurm_pop.HPC_jobID(),
@@ -225,9 +225,9 @@ class test_HPC_jobID_tuple(unittest.TestCase):
         """
 
         condor_pop = Population()
-        condor_pop.grid_options["condor"] = 1
-        condor_pop.grid_options["condor_ClusterID"] = 2
-        condor_pop.grid_options["condor_Process"] = 3
+        condor_pop.population_options["condor"] = 1
+        condor_pop.population_options["condor_ClusterID"] = 2
+        condor_pop.population_options["condor_Process"] = 3
 
         self.assertEqual(condor_pop.HPC_jobID_tuple(), ("2", "3"))
 
@@ -241,9 +241,9 @@ class test_HPC_jobID_tuple(unittest.TestCase):
         """
 
         slurm_pop = Population()
-        slurm_pop.grid_options["slurm"] = 1
-        slurm_pop.grid_options["slurm_jobid"] = 4
-        slurm_pop.grid_options["slurm_jobarrayindex"] = 5
+        slurm_pop.population_options["slurm"] = 1
+        slurm_pop.population_options["slurm_jobid"] = 4
+        slurm_pop.population_options["slurm_jobarrayindex"] = 5
 
         self.assertEqual(slurm_pop.HPC_jobID_tuple(), ("4", "5"))
 
@@ -275,7 +275,7 @@ class test_HPC_dirs(unittest.TestCase):
         """
 
         condor_pop = Population()
-        condor_pop.grid_options["condor"] = 1
+        condor_pop.population_options["condor"] = 1
         self.assertEqual(condor_pop.HPC_dirs(), ["condor_dir"])
 
     def test_slurm(self):
@@ -288,7 +288,7 @@ class test_HPC_dirs(unittest.TestCase):
         """
 
         slurm_pop = Population()
-        slurm_pop.grid_options["slurm"] = 1
+        slurm_pop.population_options["slurm"] = 1
         self.assertEqual(slurm_pop.HPC_dirs(), ["slurm_dir"])
 
     def test_none(self):
@@ -319,7 +319,7 @@ class test_HPC_id_filename(unittest.TestCase):
         """
 
         condor_pop = Population()
-        condor_pop.grid_options["condor"] = 1
+        condor_pop.population_options["condor"] = 1
         self.assertEqual(condor_pop.HPC_id_filename(), "ClusterID")
 
     def test_slurm(self):
@@ -332,7 +332,7 @@ class test_HPC_id_filename(unittest.TestCase):
         """
 
         slurm_pop = Population()
-        slurm_pop.grid_options["slurm"] = 1
+        slurm_pop.population_options["slurm"] = 1
         self.assertEqual(slurm_pop.HPC_id_filename(), "jobid")
 
     def test_none(self):
@@ -363,11 +363,11 @@ class test_HPC_check_requirements(unittest.TestCase):
         """
 
         condor_pop = Population()
-        condor_pop.grid_options["condor"] = 1
+        condor_pop.population_options["condor"] = 1
         self.assertEqual(condor_pop.HPC_id_filename(), "ClusterID")
 
         condor_pop = Population(tmp_dir=TMP_DIR)
-        condor_pop.grid_options["condor"] = 1
+        condor_pop.population_options["condor"] = 1
 
         # First the False test
         result_1 = condor_pop.HPC_check_requirements()
@@ -375,7 +375,7 @@ class test_HPC_check_requirements(unittest.TestCase):
         self.assertTrue(len(result_1[1]) > 0)
 
         # First the True test
-        condor_pop.grid_options["condor_dir"] = TMP_DIR
+        condor_pop.population_options["condor_dir"] = TMP_DIR
         result_2 = condor_pop.HPC_check_requirements()
         self.assertTrue(result_2[0])
         self.assertTrue(len(result_2[1]) == 0)
@@ -390,7 +390,7 @@ class test_HPC_check_requirements(unittest.TestCase):
         """
 
         slurm_pop = Population(tmp_dir=TMP_DIR)
-        slurm_pop.grid_options["slurm"] = 1
+        slurm_pop.population_options["slurm"] = 1
 
         # First the False test
         result_1 = slurm_pop.HPC_check_requirements()
@@ -398,7 +398,7 @@ class test_HPC_check_requirements(unittest.TestCase):
         self.assertTrue(len(result_1[1]) > 0)
 
         # First the True test
-        slurm_pop.grid_options["slurm_dir"] = TMP_DIR
+        slurm_pop.population_options["slurm_dir"] = TMP_DIR
         result_2 = slurm_pop.HPC_check_requirements()
         self.assertTrue(result_2[0])
         self.assertTrue(len(result_2[1]) == 0)
@@ -433,16 +433,16 @@ class test_HPC_set_status(unittest.TestCase):
         """
 
         condor_pop = Population(tmp_dir=TMP_DIR)
-        condor_pop.grid_options["condor"] = 1
-        condor_pop.grid_options["condor_ClusterID"] = 2
-        condor_pop.grid_options["condor_Process"] = 3
-        condor_pop.grid_options["condor_dir"] = TMP_DIR
+        condor_pop.population_options["condor"] = 1
+        condor_pop.population_options["condor_ClusterID"] = 2
+        condor_pop.population_options["condor_Process"] = 3
+        condor_pop.population_options["condor_dir"] = TMP_DIR
 
         #
         os.makedirs(
             os.path.dirname(
                 condor_pop.condor_status_file(
-                    condor_dir=condor_pop.grid_options["condor_dir"]
+                    condor_dir=condor_pop.population_options["condor_dir"]
                 )
             ),
             exist_ok=True,
@@ -452,7 +452,7 @@ class test_HPC_set_status(unittest.TestCase):
         # Check if ID file exists
         self.assertTrue(
             os.path.isfile(
-                os.path.join(condor_pop.grid_options["condor_dir"], "ClusterID")
+                os.path.join(condor_pop.population_options["condor_dir"], "ClusterID")
             )
         )
 
@@ -460,14 +460,14 @@ class test_HPC_set_status(unittest.TestCase):
         self.assertTrue(
             os.path.isfile(
                 condor_pop.condor_status_file(
-                    condor_dir=condor_pop.grid_options["condor_dir"]
+                    condor_dir=condor_pop.population_options["condor_dir"]
                 )
             )
         )
 
         with open(
             condor_pop.condor_status_file(
-                condor_dir=condor_pop.grid_options["condor_dir"]
+                condor_dir=condor_pop.population_options["condor_dir"]
             ),
             "r",
         ) as f:
@@ -484,16 +484,16 @@ class test_HPC_set_status(unittest.TestCase):
         """
 
         slurm_pop = Population(tmp_dir=TMP_DIR)
-        slurm_pop.grid_options["slurm"] = 1
-        slurm_pop.grid_options["slurm_jobid"] = 4
-        slurm_pop.grid_options["slurm_jobarrayindex"] = 5
-        slurm_pop.grid_options["slurm_dir"] = TMP_DIR
+        slurm_pop.population_options["slurm"] = 1
+        slurm_pop.population_options["slurm_jobid"] = 4
+        slurm_pop.population_options["slurm_jobarrayindex"] = 5
+        slurm_pop.population_options["slurm_dir"] = TMP_DIR
 
         #
         os.makedirs(
             os.path.dirname(
                 slurm_pop.slurm_status_file(
-                    slurm_dir=slurm_pop.grid_options["slurm_dir"]
+                    slurm_dir=slurm_pop.population_options["slurm_dir"]
                 )
             ),
             exist_ok=True,
@@ -502,20 +502,24 @@ class test_HPC_set_status(unittest.TestCase):
 
         # Check if ID file exists
         self.assertTrue(
-            os.path.isfile(os.path.join(slurm_pop.grid_options["slurm_dir"], "jobid"))
+            os.path.isfile(
+                os.path.join(slurm_pop.population_options["slurm_dir"], "jobid")
+            )
         )
 
         # Check if status file exists
         self.assertTrue(
             os.path.isfile(
                 slurm_pop.slurm_status_file(
-                    slurm_dir=slurm_pop.grid_options["slurm_dir"]
+                    slurm_dir=slurm_pop.population_options["slurm_dir"]
                 )
             )
         )
 
         with open(
-            slurm_pop.slurm_status_file(slurm_dir=slurm_pop.grid_options["slurm_dir"]),
+            slurm_pop.slurm_status_file(
+                slurm_dir=slurm_pop.population_options["slurm_dir"]
+            ),
             "r",
         ) as f:
             content_file = f.read()
@@ -537,16 +541,16 @@ class test_HPC_get_status(unittest.TestCase):
         """
 
         condor_pop = Population(tmp_dir=TMP_DIR)
-        condor_pop.grid_options["condor"] = 1
-        condor_pop.grid_options["condor_ClusterID"] = 2
-        condor_pop.grid_options["condor_Process"] = 3
-        condor_pop.grid_options["condor_dir"] = TMP_DIR
+        condor_pop.population_options["condor"] = 1
+        condor_pop.population_options["condor_ClusterID"] = 2
+        condor_pop.population_options["condor_Process"] = 3
+        condor_pop.population_options["condor_dir"] = TMP_DIR
 
         #
         os.makedirs(
             os.path.dirname(
                 condor_pop.condor_status_file(
-                    condor_dir=condor_pop.grid_options["condor_dir"]
+                    condor_dir=condor_pop.population_options["condor_dir"]
                 )
             ),
             exist_ok=True,
@@ -567,16 +571,16 @@ class test_HPC_get_status(unittest.TestCase):
         """
 
         slurm_pop = Population(tmp_dir=TMP_DIR)
-        slurm_pop.grid_options["slurm"] = 1
-        slurm_pop.grid_options["slurm_jobid"] = 4
-        slurm_pop.grid_options["slurm_jobarrayindex"] = 5
-        slurm_pop.grid_options["slurm_dir"] = TMP_DIR
+        slurm_pop.population_options["slurm"] = 1
+        slurm_pop.population_options["slurm_jobid"] = 4
+        slurm_pop.population_options["slurm_jobarrayindex"] = 5
+        slurm_pop.population_options["slurm_dir"] = TMP_DIR
 
         #
         os.makedirs(
             os.path.dirname(
                 slurm_pop.slurm_status_file(
-                    slurm_dir=slurm_pop.grid_options["slurm_dir"]
+                    slurm_dir=slurm_pop.population_options["slurm_dir"]
                 )
             ),
             exist_ok=True,
@@ -602,10 +606,10 @@ class test_HPC_job_task(unittest.TestCase):
         """
 
         condor_pop = Population(tmp_dir=TMP_DIR)
-        condor_pop.grid_options["condor"] = 1
-        condor_pop.grid_options["condor_ClusterID"] = 2
-        condor_pop.grid_options["condor_Process"] = 3
-        condor_pop.grid_options["condor_dir"] = TMP_DIR
+        condor_pop.population_options["condor"] = 1
+        condor_pop.population_options["condor_ClusterID"] = 2
+        condor_pop.population_options["condor_Process"] = 3
+        condor_pop.population_options["condor_dir"] = TMP_DIR
 
         #
         job_task = condor_pop.HPC_job_task()
@@ -621,10 +625,10 @@ class test_HPC_job_task(unittest.TestCase):
         """
 
         slurm_pop = Population(tmp_dir=TMP_DIR)
-        slurm_pop.grid_options["slurm"] = 1
-        slurm_pop.grid_options["slurm_jobid"] = 4
-        slurm_pop.grid_options["slurm_jobarrayindex"] = 5
-        slurm_pop.grid_options["slurm_dir"] = TMP_DIR
+        slurm_pop.population_options["slurm"] = 1
+        slurm_pop.population_options["slurm_jobid"] = 4
+        slurm_pop.population_options["slurm_jobarrayindex"] = 5
+        slurm_pop.population_options["slurm_dir"] = TMP_DIR
 
         #
         job_task = slurm_pop.HPC_job_task()
@@ -646,10 +650,10 @@ class test_HPC_dir(unittest.TestCase):
         """
 
         condor_pop = Population(tmp_dir=TMP_DIR)
-        condor_pop.grid_options["condor"] = 1
-        condor_pop.grid_options["condor_ClusterID"] = 2
-        condor_pop.grid_options["condor_Process"] = 3
-        condor_pop.grid_options["condor_dir"] = os.path.join(TMP_DIR, "condor")
+        condor_pop.population_options["condor"] = 1
+        condor_pop.population_options["condor_ClusterID"] = 2
+        condor_pop.population_options["condor_Process"] = 3
+        condor_pop.population_options["condor_dir"] = os.path.join(TMP_DIR, "condor")
 
         #
         self.assertEqual(condor_pop.HPC_dir(), os.path.join(TMP_DIR, "condor"))
@@ -664,10 +668,10 @@ class test_HPC_dir(unittest.TestCase):
         """
 
         slurm_pop = Population(tmp_dir=TMP_DIR)
-        slurm_pop.grid_options["slurm"] = 1
-        slurm_pop.grid_options["slurm_jobid"] = 4
-        slurm_pop.grid_options["slurm_jobarrayindex"] = 5
-        slurm_pop.grid_options["slurm_dir"] = os.path.join(TMP_DIR, "slurm")
+        slurm_pop.population_options["slurm"] = 1
+        slurm_pop.population_options["slurm_jobid"] = 4
+        slurm_pop.population_options["slurm_jobarrayindex"] = 5
+        slurm_pop.population_options["slurm_dir"] = os.path.join(TMP_DIR, "slurm")
 
         #
         self.assertEqual(slurm_pop.HPC_dir(), os.path.join(TMP_DIR, "slurm"))
@@ -702,10 +706,10 @@ class test_HPC_id_from_dir(unittest.TestCase):
         """
 
         condor_pop = Population(tmp_dir=TMP_DIR)
-        condor_pop.grid_options["condor"] = 1
-        condor_pop.grid_options["condor_ClusterID"] = 2
-        condor_pop.grid_options["condor_Process"] = 3
-        condor_pop.grid_options["condor_dir"] = TMP_DIR
+        condor_pop.population_options["condor"] = 1
+        condor_pop.population_options["condor_ClusterID"] = 2
+        condor_pop.population_options["condor_Process"] = 3
+        condor_pop.population_options["condor_dir"] = TMP_DIR
 
         # id
         id_from_dir = condor_pop.HPC_id_from_dir(condor_pop.HPC_dir())
@@ -722,10 +726,10 @@ class test_HPC_id_from_dir(unittest.TestCase):
         """
 
         slurm_pop = Population(tmp_dir=TMP_DIR)
-        slurm_pop.grid_options["slurm"] = 1
-        slurm_pop.grid_options["slurm_jobid"] = 4
-        slurm_pop.grid_options["slurm_jobarrayindex"] = 5
-        slurm_pop.grid_options["slurm_dir"] = os.path.join(TMP_DIR)
+        slurm_pop.population_options["slurm"] = 1
+        slurm_pop.population_options["slurm_jobid"] = 4
+        slurm_pop.population_options["slurm_jobarrayindex"] = 5
+        slurm_pop.population_options["slurm_dir"] = os.path.join(TMP_DIR)
 
         # id
         id_from_dir = slurm_pop.HPC_id_from_dir(slurm_pop.HPC_dir())
