@@ -8,8 +8,6 @@ TODO: Moe_di_Stefano_2017
 TODO: _clean_interpolators
 TODO: _calculate_multiplicity_fraction
 TODO: get_moe_di_stefano_dataset
-TODO: get_Moe_di_Stefano_2017_default_options
-TODO: get_Moe_di_Stefano_2017_default_options_description
 """
 
 import unittest
