@@ -34,9 +34,9 @@ class test_condorID(unittest.TestCase):
         """
 
         condor_pop = Population(tmp_dir=TMP_DIR)
-        condor_pop.grid_options["condor"] = 1
-        condor_pop.grid_options["condor_ClusterID"] = 2
-        condor_pop.grid_options["condor_Process"] = 3
+        condor_pop.population_options["condor"] = 1
+        condor_pop.population_options["condor_ClusterID"] = 2
+        condor_pop.population_options["condor_Process"] = 3
 
         self.assertEqual(
             condor_pop.condorID(),
@@ -59,7 +59,7 @@ class test_condor_dirs(unittest.TestCase):
         """
 
         condor_pop = Population(tmp_dir=TMP_DIR)
-        condor_pop.grid_options["condor"] = 1
+        condor_pop.population_options["condor"] = 1
         self.assertEqual(condor_pop.condor_dirs(), ["condor_dir"])
 
 
@@ -78,7 +78,7 @@ class test_condor_check_requirements(unittest.TestCase):
         """
 
         condor_pop = Population(tmp_dir=TMP_DIR)
-        condor_pop.grid_options["condor"] = 1
+        condor_pop.population_options["condor"] = 1
 
         # First the False test
         result_1 = condor_pop.condor_check_requirements()
@@ -86,7 +86,7 @@ class test_condor_check_requirements(unittest.TestCase):
         self.assertTrue(len(result_1[1]) > 0)
 
         # First the True test
-        condor_pop.grid_options["condor_dir"] = TMP_DIR
+        condor_pop.population_options["condor_dir"] = TMP_DIR
         result_2 = condor_pop.condor_check_requirements()
         self.assertTrue(result_2[0])
         self.assertTrue(len(result_2[1]) == 0)
@@ -107,13 +107,13 @@ class test_set_condor_status(unittest.TestCase):
         """
 
         condor_pop = Population(tmp_dir=TMP_DIR)
-        condor_pop.grid_options["condor"] = 1
-        condor_pop.grid_options["condor_ClusterID"] = 2
-        condor_pop.grid_options["condor_Process"] = 3
-        condor_pop.grid_options["condor_dir"] = TMP_DIR
+        condor_pop.population_options["condor"] = 1
+        condor_pop.population_options["condor_ClusterID"] = 2
+        condor_pop.population_options["condor_Process"] = 3
+        condor_pop.population_options["condor_dir"] = TMP_DIR
 
         id_filename = os.path.isfile(
-            os.path.join(condor_pop.grid_options["condor_dir"], "ClusterID")
+            os.path.join(condor_pop.population_options["condor_dir"], "ClusterID")
         )
         if os.path.isfile(id_filename):
             os.remove(id_filename)
@@ -122,7 +122,7 @@ class test_set_condor_status(unittest.TestCase):
         os.makedirs(
             os.path.dirname(
                 condor_pop.condor_status_file(
-                    condor_dir=condor_pop.grid_options["condor_dir"]
+                    condor_dir=condor_pop.population_options["condor_dir"]
                 )
             ),
             exist_ok=True,
@@ -136,14 +136,14 @@ class test_set_condor_status(unittest.TestCase):
         self.assertTrue(
             os.path.isfile(
                 condor_pop.condor_status_file(
-                    condor_dir=condor_pop.grid_options["condor_dir"]
+                    condor_dir=condor_pop.population_options["condor_dir"]
                 )
             )
         )
 
         with open(
             condor_pop.condor_status_file(
-                condor_dir=condor_pop.grid_options["condor_dir"]
+                condor_dir=condor_pop.population_options["condor_dir"]
             ),
             "r",
         ) as f:
@@ -166,16 +166,16 @@ class test_get_condor_status(unittest.TestCase):
         """
 
         condor_pop = Population(tmp_dir=TMP_DIR)
-        condor_pop.grid_options["condor"] = 1
-        condor_pop.grid_options["condor_ClusterID"] = 2
-        condor_pop.grid_options["condor_Process"] = 3
-        condor_pop.grid_options["condor_dir"] = TMP_DIR
+        condor_pop.population_options["condor"] = 1
+        condor_pop.population_options["condor_ClusterID"] = 2
+        condor_pop.population_options["condor_Process"] = 3
+        condor_pop.population_options["condor_dir"] = TMP_DIR
 
         #
         os.makedirs(
             os.path.dirname(
                 condor_pop.condor_status_file(
-                    condor_dir=condor_pop.grid_options["condor_dir"]
+                    condor_dir=condor_pop.population_options["condor_dir"]
                 )
             ),
             exist_ok=True,
@@ -202,10 +202,10 @@ class test_condor_outfile(unittest.TestCase):
         """
 
         condor_pop = Population(tmp_dir=TMP_DIR)
-        condor_pop.grid_options["condor"] = 1
-        condor_pop.grid_options["condor_ClusterID"] = 2
-        condor_pop.grid_options["condor_Process"] = 3
-        condor_pop.grid_options["condor_dir"] = TMP_DIR
+        condor_pop.population_options["condor"] = 1
+        condor_pop.population_options["condor_ClusterID"] = 2
+        condor_pop.population_options["condor_Process"] = 3
+        condor_pop.population_options["condor_dir"] = TMP_DIR
 
         outfile = condor_pop.condor_outfile()
         condor_id = condor_pop.condorID()
@@ -213,7 +213,7 @@ class test_condor_outfile(unittest.TestCase):
             outfile,
             os.path.abspath(
                 os.path.join(
-                    condor_pop.grid_options["condor_dir"],
+                    condor_pop.population_options["condor_dir"],
                     "results",
                     "{}.gz".format(condor_id),
                 )
@@ -236,10 +236,10 @@ class test_make_condor_dirs(unittest.TestCase):
         """
 
         condor_pop = Population(tmp_dir=TMP_DIR)
-        condor_pop.grid_options["condor"] = 1
-        condor_pop.grid_options["condor_ClusterID"] = 2
-        condor_pop.grid_options["condor_Process"] = 3
-        condor_pop.grid_options["condor_dir"] = TMP_DIR
+        condor_pop.population_options["condor"] = 1
+        condor_pop.population_options["condor_ClusterID"] = 2
+        condor_pop.population_options["condor_Process"] = 3
+        condor_pop.population_options["condor_dir"] = TMP_DIR
 
         shutil.rmtree(TMP_DIR)
         os.makedirs(TMP_DIR)
