@@ -478,14 +478,15 @@ class test_gaussian(unittest.TestCase):
 
         distribution_functions_pop = Population(tmp_dir=TMP_DIR)
 
-        perl_results = [
-            0.00218800520299544,
-            0.0121641269671571,
-            0.0657353455837751,
-            0.104951743573429,
-            0.16899534495487,
-            0.0134332780385336,
+        true_results = [
+            0.002198603353047357,
+            0.012223046956319811,
+            0.06605375115943717,
+            0.10546010357416327,
+            0.1698139161454027,
+            0.013498345478111231,
         ]
+
         python_results = []
         input_lists = []
 
@@ -496,12 +497,16 @@ class test_gaussian(unittest.TestCase):
             )
 
         # GO over the results and check whether they are equal (within tolerance)
-        for i in range(len(python_results)):
-            msg = "Error: Value perl: {} Value python: {} for logper: {}".format(
-                perl_results[i], python_results[i], str(input_lists[i])
+        for python_result_i, python_result in enumerate(python_results):
+            msg = "Error: Value true: {} Value python: {} for logper: {}".format(
+                true_results[python_result_i],
+                python_result,
+                str(input_lists[python_result_i]),
             )
             self.assertLess(
-                np.abs(python_results[i] - perl_results[i]), TOLERANCE, msg=msg
+                np.abs(python_result - true_results[python_result_i]),
+                TOLERANCE,
+                msg=msg,
             )
 
         # Extra test:
@@ -606,43 +611,43 @@ class test_Izzard2012_period_distribution(unittest.TestCase):
 
         distribution_functions_pop = Population(tmp_dir=TMP_DIR)
 
-        perl_results = [
+        true_results = [
             0,
-            0.00941322840619318,
-            0.0575068231479569,
-            0.0963349886047932,
-            0.177058537292581,
-            0.0165713385659234,
+            0.009418106687495185,
+            0.05753662529956688,
+            0.09638491294035179,
+            0.17715029554114,
+            0.01657992644327932,
             0,
-            0.00941322840619318,
-            0.0575068231479569,
-            0.0963349886047932,
-            0.177058537292581,
-            0.0165713385659234,
+            0.009418106687495185,
+            0.05753662529956688,
+            0.09638491294035179,
+            0.17715029554114,
+            0.01657992644327932,
             0,
-            0.00941322840619318,
-            0.0575068231479569,
-            0.0963349886047932,
-            0.177058537292581,
-            0.0165713385659234,
+            0.009418106687495185,
+            0.05753662529956688,
+            0.09638491294035179,
+            0.17715029554114,
+            0.01657992644327932,
             0,
-            7.61631504133159e-09,
-            0.168028727846997,
-            0.130936282216512,
-            0.0559170865520968,
-            0.0100358604460285,
+            7.611759724531097e-09,
+            0.16792822989191364,
+            0.13085796924719031,
+            0.055883642551628955,
+            0.01002985799951086,
             0,
-            2.08432736869149e-21,
-            0.18713622563288,
-            0.143151383185002,
-            0.0676299576972089,
-            0.0192427864870784,
+            2.085068289582091e-21,
+            0.18720274739958628,
+            0.1432022695533882,
+            0.06765399828183155,
+            0.01924962676692883,
             0,
-            1.1130335685003e-24,
-            0.194272603987661,
-            0.14771508552257,
-            0.0713078479280884,
-            0.0221093965810181,
+            1.1134801674535124e-24,
+            0.19435055486356775,
+            0.1477743554353869,
+            0.07133645983265395,
+            0.02211826786185681,
         ]
         python_results = []
         input_lists = []
@@ -656,12 +661,16 @@ class test_Izzard2012_period_distribution(unittest.TestCase):
                 )
 
         # GO over the results and check whether they are equal (within tolerance)
-        for i in range(len(python_results)):
-            msg = "Error: Value perl: {} Value python: {} for mass, per: {}".format(
-                perl_results[i], python_results[i], str(input_lists[i])
+        for python_results_i, python_result in enumerate(python_results):
+            msg = "Error: Value true: {} Value python: {} for mass, per: {}".format(
+                true_results[python_results_i],
+                python_result,
+                str(input_lists[python_results_i]),
             )
             self.assertLess(
-                np.abs(python_results[i] - perl_results[i]), TOLERANCE, msg=msg
+                np.abs(python_result - true_results[python_results_i]),
+                TOLERANCE,
+                msg=msg,
             )
 
 
@@ -1141,12 +1150,12 @@ class test__get_multiplicity_dict(unittest.TestCase):
         _ = distribution_functions_pop._get_multiplicity_dict(system_dict)
 
         # test directly with values for Moe function
-        distribution_functions_pop.grid_options["Moe2017_options"]["M_1"] = system_dict[
+        distribution_functions_pop.population_options["Moe2017_options"][
             "M_1"
-        ]
+        ] = system_dict["M_1"]
         multiplicity_fractions_moe = (
             distribution_functions_pop.Moe_di_Stefano_2017_multiplicity_fractions(
-                distribution_functions_pop.grid_options["Moe2017_options"], 1
+                distribution_functions_pop.population_options["Moe2017_options"], 1
             )
         )
 
@@ -1162,7 +1171,7 @@ class test__get_multiplicity_dict(unittest.TestCase):
         )
 
         # Test without setting Moe2017 options
-        distribution_functions_pop.grid_options["Moe2017_options"] = None
+        distribution_functions_pop.population_options["Moe2017_options"] = None
         self.assertRaises(
             ValueError, distribution_functions_pop._get_multiplicity_dict, {"M_1": 1}
         )
