@@ -11,15 +11,11 @@ TODO: _load_grid_function
 TODO: _last_grid_variable
 """
 
-import os
-import shutil
 import unittest
 
 from binarycpython.utils.functions import temp_dir
 
 TMP_DIR = temp_dir("tests", "test_gridcode")
-shutil.rmtree(TMP_DIR)
-os.makedirs(TMP_DIR, exist_ok=True)
 
 
 if __name__ == "__main__":
