@@ -34,9 +34,9 @@ class test_slurmID(unittest.TestCase):
         """
 
         slurm_pop = Population(tmp_dir=TMP_DIR)
-        slurm_pop.grid_options["slurm"] = 1
-        slurm_pop.grid_options["slurm_jobid"] = 4
-        slurm_pop.grid_options["slurm_jobarrayindex"] = 5
+        slurm_pop.population_options["slurm"] = 1
+        slurm_pop.population_options["slurm_jobid"] = 4
+        slurm_pop.population_options["slurm_jobarrayindex"] = 5
 
         self.assertEqual(
             slurm_pop.HPC_jobID(),
@@ -59,7 +59,7 @@ class test_slurm_dirs(unittest.TestCase):
         """
 
         slurm_pop = Population(tmp_dir=TMP_DIR)
-        slurm_pop.grid_options["slurm"] = 1
+        slurm_pop.population_options["slurm"] = 1
         self.assertEqual(slurm_pop.slurm_dirs(), ["slurm_dir"])
 
 
@@ -78,7 +78,7 @@ class test_slurm_check_requirements(unittest.TestCase):
         """
 
         slurm_pop = Population(tmp_dir=TMP_DIR)
-        slurm_pop.grid_options["slurm"] = 1
+        slurm_pop.population_options["slurm"] = 1
 
         # First the False test
         result_1 = slurm_pop.slurm_check_requirements()
@@ -86,7 +86,7 @@ class test_slurm_check_requirements(unittest.TestCase):
         self.assertTrue(len(result_1[1]) > 0)
 
         # First the True test
-        slurm_pop.grid_options["slurm_dir"] = TMP_DIR
+        slurm_pop.population_options["slurm_dir"] = TMP_DIR
         result_2 = slurm_pop.slurm_check_requirements()
         self.assertTrue(result_2[0])
         self.assertTrue(len(result_2[1]) == 0)
@@ -107,13 +107,13 @@ class test_set_slurm_status(unittest.TestCase):
         """
 
         slurm_pop = Population(tmp_dir=TMP_DIR)
-        slurm_pop.grid_options["slurm"] = 1
-        slurm_pop.grid_options["slurm_jobid"] = 4
-        slurm_pop.grid_options["slurm_jobarrayindex"] = 5
-        slurm_pop.grid_options["slurm_dir"] = TMP_DIR
+        slurm_pop.population_options["slurm"] = 1
+        slurm_pop.population_options["slurm_jobid"] = 4
+        slurm_pop.population_options["slurm_jobarrayindex"] = 5
+        slurm_pop.population_options["slurm_dir"] = TMP_DIR
 
         id_filename = os.path.isfile(
-            os.path.join(slurm_pop.grid_options["slurm_dir"], "jobid")
+            os.path.join(slurm_pop.population_options["slurm_dir"], "jobid")
         )
         if os.path.isfile(id_filename):
             os.remove(id_filename)
@@ -122,7 +122,7 @@ class test_set_slurm_status(unittest.TestCase):
         os.makedirs(
             os.path.dirname(
                 slurm_pop.slurm_status_file(
-                    slurm_dir=slurm_pop.grid_options["slurm_dir"]
+                    slurm_dir=slurm_pop.population_options["slurm_dir"]
                 )
             ),
             exist_ok=True,
@@ -136,13 +136,15 @@ class test_set_slurm_status(unittest.TestCase):
         self.assertTrue(
             os.path.isfile(
                 slurm_pop.slurm_status_file(
-                    slurm_dir=slurm_pop.grid_options["slurm_dir"]
+                    slurm_dir=slurm_pop.population_options["slurm_dir"]
                 )
             )
         )
 
         with open(
-            slurm_pop.slurm_status_file(slurm_dir=slurm_pop.grid_options["slurm_dir"]),
+            slurm_pop.slurm_status_file(
+                slurm_dir=slurm_pop.population_options["slurm_dir"]
+            ),
             "r",
         ) as f:
             content_file = f.read()
@@ -164,16 +166,16 @@ class test_get_slurm_status(unittest.TestCase):
         """
 
         slurm_pop = Population(tmp_dir=TMP_DIR)
-        slurm_pop.grid_options["slurm"] = 1
-        slurm_pop.grid_options["slurm_jobid"] = 4
-        slurm_pop.grid_options["slurm_jobarrayindex"] = 5
-        slurm_pop.grid_options["slurm_dir"] = TMP_DIR
+        slurm_pop.population_options["slurm"] = 1
+        slurm_pop.population_options["slurm_jobid"] = 4
+        slurm_pop.population_options["slurm_jobarrayindex"] = 5
+        slurm_pop.population_options["slurm_dir"] = TMP_DIR
 
         #
         os.makedirs(
             os.path.dirname(
                 slurm_pop.slurm_status_file(
-                    slurm_dir=slurm_pop.grid_options["slurm_dir"]
+                    slurm_dir=slurm_pop.population_options["slurm_dir"]
                 )
             ),
             exist_ok=True,
@@ -199,10 +201,10 @@ class test_slurm_outfile(unittest.TestCase):
         """
 
         slurm_pop = Population(tmp_dir=TMP_DIR)
-        slurm_pop.grid_options["slurm"] = 1
-        slurm_pop.grid_options["slurm_jobid"] = 4
-        slurm_pop.grid_options["slurm_jobarrayindex"] = 5
-        slurm_pop.grid_options["slurm_dir"] = TMP_DIR
+        slurm_pop.population_options["slurm"] = 1
+        slurm_pop.population_options["slurm_jobid"] = 4
+        slurm_pop.population_options["slurm_jobarrayindex"] = 5
+        slurm_pop.population_options["slurm_dir"] = TMP_DIR
 
         outfile = slurm_pop.slurm_outfile()
         slurm_id = slurm_pop.slurmID()
@@ -210,7 +212,7 @@ class test_slurm_outfile(unittest.TestCase):
             outfile,
             os.path.abspath(
                 os.path.join(
-                    slurm_pop.grid_options["slurm_dir"],
+                    slurm_pop.population_options["slurm_dir"],
                     "results",
                     "{}.gz".format(slurm_id),
                 )
@@ -233,10 +235,10 @@ class test_make_slurm_dirs(unittest.TestCase):
         """
 
         slurm_pop = Population(tmp_dir=TMP_DIR)
-        slurm_pop.grid_options["slurm"] = 1
-        slurm_pop.grid_options["slurm_jobid"] = 4
-        slurm_pop.grid_options["slurm_jobarrayindex"] = 5
-        slurm_pop.grid_options["slurm_dir"] = TMP_DIR
+        slurm_pop.population_options["slurm"] = 1
+        slurm_pop.population_options["slurm_jobid"] = 4
+        slurm_pop.population_options["slurm_jobarrayindex"] = 5
+        slurm_pop.population_options["slurm_dir"] = TMP_DIR
 
         shutil.rmtree(TMP_DIR)
         os.makedirs(TMP_DIR)
