@@ -23,10 +23,9 @@ TMP_DIR = temp_dir("tests", "test_spacing_functions")
 
 shutil.rmtree(TMP_DIR)
 os.makedirs(TMP_DIR, exist_ok=True)
-distribution_functions_pop = Population()
 
 
-class test_spacing_functions(unittest.TestCase):
+class test_const(unittest.TestCase):
     """
     Unit test for spacing functions
     """
@@ -40,9 +39,12 @@ class test_spacing_functions(unittest.TestCase):
         Unittest for function const
         """
 
+        distribution_functions_pop = Population()
+
         const_return = distribution_functions_pop.const_linear(1, 10, 10)
+
         self.assertTrue(
-            (const_return == np.linspace(1, 10, 10 + 1)).all(),
+            (const_return == np.linspace(1, 10, 10)).all(),
         )
 
 
