@@ -44,12 +44,16 @@ class test_return_binary_c_version_info(unittest.TestCase):
         self.assertIn("macros", binary_c_version_info)
         self.assertIn("dt_limits", binary_c_version_info)
         self.assertIn("nucleosynthesis_sources", binary_c_version_info)
+        self.assertIn("binary_c_error_codes", binary_c_version_info)
+        self.assertIn("deflists", binary_c_version_info)
         self.assertIn("miscellaneous", binary_c_version_info)
 
         self.assertIsNotNone(binary_c_version_info["argpairs"])
         self.assertIsNotNone(binary_c_version_info["ensembles"])
         self.assertIsNotNone(binary_c_version_info["macros"])
         self.assertIsNotNone(binary_c_version_info["dt_limits"])
+        self.assertIsNotNone(binary_c_version_info["binary_c_error_codes"])
+        self.assertIsNotNone(binary_c_version_info["deflists"])
         self.assertIsNotNone(binary_c_version_info["miscellaneous"])
 
         if binary_c_version_info["macros"]["NUCSYN"] == "on":
@@ -96,6 +100,8 @@ class test_return_binary_c_version_info(unittest.TestCase):
         self.assertIn("elements", version_info_parsed.keys())
         self.assertIn("dt_limits", version_info_parsed.keys())
         self.assertIn("nucleosynthesis_sources", version_info_parsed.keys())
+        self.assertIn("binary_c_error_codes", version_info_parsed.keys())
+        self.assertIn("deflists", version_info_parsed.keys())
         self.assertIn("miscellaneous", version_info_parsed.keys())
 
     def test_envvar(self):
@@ -122,6 +128,8 @@ class test_return_binary_c_version_info(unittest.TestCase):
         self.assertIn("elements", version_info_parsed.keys())
         self.assertIn("dt_limits", version_info_parsed.keys())
         self.assertIn("nucleosynthesis_sources", version_info_parsed.keys())
+        self.assertIn("binary_c_error_codes", version_info_parsed.keys())
+        self.assertIn("deflists", version_info_parsed.keys())
         self.assertIn("miscellaneous", version_info_parsed.keys())
 
 
@@ -152,12 +160,17 @@ class test_parse_binary_c_version_info(unittest.TestCase):
         self.assertIn("elements", parsed_info.keys())
         self.assertIn("dt_limits", parsed_info.keys())
         self.assertIn("nucleosynthesis_sources", parsed_info.keys())
+        self.assertIn("binary_c_error_codes", parsed_info.keys())
+        self.assertIn("deflists", parsed_info.keys())
         self.assertIn("miscellaneous", parsed_info.keys())
 
+        #
         self.assertIsNotNone(parsed_info["argpairs"])
         self.assertIsNotNone(parsed_info["ensembles"])
         self.assertIsNotNone(parsed_info["macros"])
         self.assertIsNotNone(parsed_info["dt_limits"])
+        self.assertIsNotNone(parsed_info["binary_c_error_codes"])
+        self.assertIsNotNone(parsed_info["deflists"])
         self.assertIsNotNone(parsed_info["miscellaneous"])
 
         if parsed_info["macros"]["NUCSYN"] == "on":
