@@ -298,7 +298,7 @@ def subtract_dicts(dict_1: dict, dict_2: dict) -> dict:
     for key in overlapping_keys:
 
         # See whether the types are actually the same
-        if not type(dict_1[key]) is type(dict_2[key]):
+        if not isinstance(dict_1[key], type(dict_2[key])):
             # Exceptions:
             if (type(dict_1[key]) in ALLOWED_NUMERICAL_TYPES) and (
                 type(dict_2[key]) in ALLOWED_NUMERICAL_TYPES
@@ -495,7 +495,7 @@ def merge_dicts(dict_1: dict, dict_2: dict) -> dict:
     for key in overlapping_keys:
 
         # If they keys are not the same, it depends on their type whether we still deal with them at all, or just raise an error
-        if not type(dict_1[key]) is type(dict_2[key]):
+        if not isinstance(dict_1[key], type(dict_2[key])):
             # Exceptions: numbers can be added
             if isinstance(dict_1[key], ALLOWED_NUMERICAL_TYPES) and isinstance(
                 dict_2[key], ALLOWED_NUMERICAL_TYPES
@@ -510,6 +510,21 @@ def merge_dicts(dict_1: dict, dict_2: dict) -> dict:
             ):
                 new_dict[key] = merge_dicts(dict_1[key], dict_2[key])
 
+            # one key is None, just use the other
+            elif dict_1[key] is None:
+                try:
+                    new_dict[key] = dict_2[key]
+                except:
+                    msg = f"{key}: Failed to set from {dict_2[key]} when other key was of NoneType "
+                    raise ValueError(msg)
+
+            elif dict_1[key] is None:
+                try:
+                    new_dict[key] = dict_1[key]
+                except:
+                    msg = f"{key}: Failed to set from {dict_1[key]} when other key was of NoneType "
+                    raise ValueError(msg)
+
             # string-int clash : convert both to ints and save
             elif (
                 isinstance(dict_1[key], str)
@@ -652,7 +667,7 @@ def update_dicts(dict_1: dict, dict_2: dict) -> dict:
     for key in overlapping_keys:
 
         # See whether the types are actually the same
-        if not type(dict_1[key]) is type(dict_2[key]):
+        if not isinstance(dict_1[key], type(dict_2[key])):
             # Exceptions:
             if isinstance(dict_1[key], ALLOWED_NUMERICAL_TYPES) and isinstance(
                 dict_2[key], ALLOWED_NUMERICAL_TYPES
