@@ -3,17 +3,16 @@ Module containing most of the utility functions for the binarycpython package
 
 Functions here are mostly functions used in other classes/functions, or
 useful functions for the user
-
-Tasks:
-    - TODO: change all prints to verbose_prints
 """
 
 import collections
+import copy
 import datetime
 import json
 import os
 import platform
 import resource
+import shutil
 import socket
 import subprocess
 import sys
@@ -31,12 +30,26 @@ from colorama import Back, Fore, Style
 
 from binarycpython import _binary_c_bindings
 from binarycpython.utils.dicts import filter_dict_through_values
+from binarycpython.utils.logging_functions import verbose_print
 
 ########################################################
 # Unsorted
 ########################################################
 
 
+def get_numerical_value(string):
+    """
+    Function to turn a string to a numerical value
+    """
+
+    if "." in string:
+        numerical_value = float(string)
+    else:
+        numerical_value = int(string)
+
+    return numerical_value
+
+
 def calculate_total_mass_system(system_dict):
     """
     Function to calculate the total mass of the system
@@ -432,28 +445,6 @@ def call_binary_c_config(argument):
 ########################################################
 
 
-def verbose_print(
-    message: str, verbosity: int, minimal_verbosity: int, newline: str = "\n"
-) -> None:
-    """
-    Function that decides whether to print a message based on the current verbosity
-    and its minimum verbosity. If verbosity is equal or higher than the minimum, then we print.
-
-    Args:
-        message: message to print.
-        verbosity: current verbosity level.
-        minimal_verbosity: threshold verbosity above which to print.
-        newline: newline character (or set of characters), defaults to ``\\n`` but ``\\x0d`` (carriage return) might be useful.
-    """
-
-    if verbosity >= minimal_verbosity:
-        if newline == "\n":
-            print(message)
-        else:
-            print(message, newline, sep="", end="")
-        sys.stdout.flush()
-
-
 def remove_file(file: str, verbosity: int = 0) -> None:
     """
     Function to remove files but with verbosity
@@ -495,7 +486,7 @@ def get_username():
     return psutil.Process().username()
 
 
-def temp_dir(*child_dirs: str) -> str:
+def temp_dir(*child_dirs: str, clean_path=False) -> str:
     """
     Function to create directory within the TMP directory of the file system, starting with `/<TMP>/binary_c_python-<username>`
 
@@ -503,24 +494,28 @@ def temp_dir(*child_dirs: str) -> str:
 
     Args:
         *child_dirs: str input where each next input will be a child of the previous full_path. e.g. ``temp_dir('tests', 'grid')`` will become ``'/tmp/binary_c_python-<username>/tests/grid'``
-
+        *clean_path (optional): Boolean to make sure that the directory is cleaned if it exists
     Returns:
         the path of a sub directory called binary_c_python in the TMP of the file system
     """
 
     tmp_dir = tempfile.gettempdir()
     username = get_username()
-    path = os.path.join(tmp_dir, "binary_c_python-{}".format(username))
+    full_path = os.path.join(tmp_dir, "binary_c_python-{}".format(username))
 
     # loop over the other paths if there are any:
     if child_dirs:
         for extra_dir in child_dirs:
-            path = os.path.join(path, extra_dir)
+            full_path = os.path.join(full_path, extra_dir)
+
+    # Check if we need to clean the path
+    if clean_path and os.path.isdir(full_path):
+        shutil.rmtree(full_path)
 
     #
-    os.makedirs(path, exist_ok=True)
+    os.makedirs(full_path, exist_ok=True)
 
-    return path
+    return full_path
 
 
 def create_hdf5(data_dir: str, name: str) -> None:
@@ -603,6 +598,8 @@ def output_lines(output: str) -> list:
     """
     Function that outputs the lines that were received from the binary_c run, but now as an iterator.
 
+    This function filters out lines that are empty.
+
     Args:
         output: raw binary_c output
 
@@ -611,7 +608,9 @@ def output_lines(output: str) -> list:
     """
 
     if output:
-        return output.splitlines()
+        for line in output.splitlines():
+            if line:
+                yield line
     return []
 
 
@@ -795,7 +794,10 @@ def create_arg_string(
 
 
 def get_help(
-    param_name: str = "", print_help: bool = True, fail_silently: bool = False
+    param_name: str = "",
+    print_help: bool = True,
+    fail_silently: bool = False,
+    store_memaddr=None,
 ) -> Union[dict, None]:
     """
     Function that returns the help info for a given parameter, by interfacing with binary_c
@@ -833,7 +835,9 @@ def get_help(
         return None
 
     if param_name in available_arg_keys:
-        help_info = _binary_c_bindings.return_help(param_name)
+        help_info = _binary_c_bindings.return_help(
+            param_name, store_memaddr=store_memaddr
+        )
         cleaned = [el for el in help_info.split("\n") if not el == ""]
 
         # Get line numbers
@@ -903,7 +907,7 @@ def get_help(
     return {}
 
 
-def get_help_all(print_help: bool = True) -> dict:
+def get_help_all(print_help: bool = True, store_memaddr=None) -> dict:
     """
     Function that reads out the output of the return_help_all API call to binary_c. This return_help_all binary_c returns all the information for the parameters, their descriptions and other properties. The output is categorised in sections.
 
@@ -915,7 +919,7 @@ def get_help_all(print_help: bool = True) -> dict:
     """
 
     # Call function
-    help_all = _binary_c_bindings.return_help_all()
+    help_all = _binary_c_bindings.return_help_all(store_memaddr=store_memaddr)
 
     # String manipulation
     split = help_all.split(
@@ -1029,8 +1033,11 @@ def get_help_super(print_help: bool = False, fail_silently: bool = True) -> dict
         dictionary containing all dictionaries per section, which then contain as much info as possible per parameter.
     """
 
+    # Setup store memaddr
+    store_memaddr = _binary_c_bindings.return_store_memaddr()
+
     # Get help_all information
-    help_all_dict = get_help_all(print_help=False)
+    help_all_dict = get_help_all(print_help=False, store_memaddr=store_memaddr)
 
     #
     help_all_super_dict = help_all_dict.copy()
@@ -1047,6 +1054,7 @@ def get_help_super(print_help: bool = False, fail_silently: bool = True) -> dict
                     parameter_name,
                     print_help=False,
                     fail_silently=fail_silently,
+                    store_memaddr=store_memaddr,
                 )
 
                 if detailed_help:
@@ -1073,6 +1081,9 @@ def get_help_super(print_help: bool = False, fail_silently: bool = True) -> dict
     if print_help:
         print(json.dumps(help_all_super_dict, indent=4, ensure_ascii=False))
 
+    # Free store memaddr
+    _binary_c_bindings.free_store_memaddr(store_memaddr)
+
     return help_all_super_dict
 
 
@@ -1103,6 +1114,123 @@ This information was obtained by the following binary_c build:
     return info_string.strip()
 
 
+def binary_c_parameter_parse_description(parameter_dict: dict):
+    """
+    Function to parse the binary_c parameter dict
+    """
+
+    # Make a local copy
+    parameter_dict = copy.copy(parameter_dict)
+
+    ############
+    # Add description
+    description_string = "Description:\n   "
+
+    # Clean description text
+    description_text = (
+        parameter_dict["description"].strip().replace("|Rout/Rin-1|", "abs(Rout/Rin-1)")
+    )
+    description_text = description_text[0].capitalize() + description_text[1:]
+    if description_text[-1] != ".":
+        description_text = description_text + "."
+    description_string += description_text
+
+    ##############
+    # Add parameter value input type
+    if "parameter_value_input_type" in parameter_dict:
+        description_string += "\n\nParameter input type:\n   {}".format(
+            parameter_dict["parameter_value_input_type"]
+        )
+
+    ##############
+    # Add defaults
+    if "default" in parameter_dict:
+        description_string += "\n\nDefault value:\n   {}".format(
+            parameter_dict["default"]
+        )
+
+    ##############
+    # Add macros
+    if "macros" in parameter_dict:
+        description_string += "\n\nMacros:\n   {}".format(parameter_dict["macros"])
+
+    ##############
+    # Add extra
+    if "rest" in parameter_dict and not parameter_dict["rest"] == "(null)":
+        description_string += "\n\nExtra:\n   {}".format(parameter_dict["rest"])
+
+    ##############
+    # Check if there are newlines, and replace them by newlines with indent
+    description_string = description_string.replace("\n", "\n       ")
+
+    return description_string
+
+
+def build_binary_c_parameter_section_table(
+    section_name: str, section_dict: dict
+) -> str:
+    """
+    Function to build the binary_c parameter section table
+    """
+
+    #
+    indent = "   "
+
+    # Get parameter list and parse descriptions
+    parameter_list_with_descriptions = [
+        [
+            parameter,
+            binary_c_parameter_parse_description(
+                parameter_dict=section_dict[parameter]
+            ),
+        ]
+        for parameter in section_dict.keys()
+    ]
+
+    # Construct table
+    rst_table = """
+.. list-table:: {}
+{}:widths: 25, 75
+{}:header-rows: 1
+""".format(
+        section_name, indent, indent
+    )
+
+    #
+    rst_table += "\n"
+    rst_table += indent + "* - Option\n"
+    rst_table += indent + "  - Description\n"
+
+    for parameter_el in parameter_list_with_descriptions:
+        rst_table += indent + "* - {}\n".format(parameter_el[0])
+        rst_table += indent + "  - {}\n".format(parameter_el[1])
+
+    return rst_table
+
+
+def build_binary_c_parameter_section_text(section_name: str, section_dict: dict) -> str:
+    """
+    Function to write the binary_c parameter section text as an rst table
+    """
+
+    binary_c_parameter_section_text = ""
+
+    # Build header
+    binary_c_parameter_section_text_header = "Section: {}".format(section_name)
+    binary_c_parameter_section_text += binary_c_parameter_section_text_header + "\n"
+    binary_c_parameter_section_text += (
+        "-" * len("Section: {}".format(section_name)) + "\n\n"
+    )
+
+    # build table
+    binary_c_parameter_section_table_text = build_binary_c_parameter_section_table(
+        section_name=section_name, section_dict=section_dict
+    )
+    binary_c_parameter_section_text += binary_c_parameter_section_table_text
+
+    return binary_c_parameter_section_text
+
+
 def write_binary_c_parameter_descriptions_to_rst_file(output_file: str) -> None:
     """
     Function that calls the get_help_super() to get the help text/descriptions for all the
@@ -1115,11 +1243,7 @@ def write_binary_c_parameter_descriptions_to_rst_file(output_file: str) -> None:
             of all the binary_c parameters.
     """
 
-    # Get the whole arguments dictionary
-    arguments_dict = get_help_super()
-
-    build_info = make_build_text()
-
+    # Check input
     if not output_file.endswith(".rst"):
         raise ValueError(
             "Filename ({}) doesn't end with .rst, please provide a proper filename.".format(
@@ -1127,6 +1251,14 @@ def write_binary_c_parameter_descriptions_to_rst_file(output_file: str) -> None:
             )
         )
 
+    # Get the whole arguments dictionary
+    arguments_dict = get_help_super()
+
+    # Make build-info text
+    build_info = make_build_text()
+
+    ##########
+    # Write to file
     with open(output_file, "w", encoding="utf-8") as f:
 
         print("Binary\\_c parameters", file=f)
@@ -1139,36 +1271,15 @@ def write_binary_c_parameter_descriptions_to_rst_file(output_file: str) -> None:
         print(build_info, file=f)
         print("\n", file=f)
 
-        for el in arguments_dict.keys():
-            print("Section: {}".format(el), file=f)
-            print("{}\n".format("-" * len("Section: {}".format(el))), file=f)
+        ##########
+        # Loop over sections and write arguments
+        for section_name in arguments_dict.keys():
+            binary_c_parameter_section_text = build_binary_c_parameter_section_text(
+                section_name=section_name,
+                section_dict=arguments_dict[section_name]["parameters"],
+            )
 
-            for arg in arguments_dict[el]["parameters"].keys():
-                argdict = arguments_dict[el]["parameters"][arg]
-
-                print("| **Parameter**: {}".format(argdict["param_name"]), file=f)
-                print(
-                    "| **Description**: {}".format(
-                        argdict["description"].replace(
-                            "|Rout/Rin-1|", "abs(Rout/Rin-1)"
-                        )
-                    ),
-                    file=f,
-                )
-                if "parameter_value_input_type" in argdict:
-                    print(
-                        "| **Parameter input type**: {}".format(
-                            argdict["parameter_value_input_type"]
-                        ),
-                        file=f,
-                    )
-                if "default" in argdict:
-                    print("| **Default value**: {}".format(argdict["default"]), file=f)
-                if "macros" in argdict:
-                    print("| **Macros**: {}".format(argdict["macros"]), file=f)
-                if not argdict["rest"] == "(null)":
-                    print("| **Extra**: {}".format(argdict["rest"]), file=f)
-                print("", file=f)
+            print(binary_c_parameter_section_text, file=f)
 
 
 ########################################################
