@@ -6,7 +6,6 @@ Here all the functionality of a Population object is defined.
 TODO: the save_snapshots and save_snapshot, are they actually distinct?
 
 Tasks:
-    - TODO: add functionality to 'on-init' set arguments
     - TODO: type the private functions
     - TODO: fix the correct object types for the default values of the bse_options
     - TODO: think of a clean and nice way to unload and remove the custom_logging_info library from memory (and from disk)
@@ -14,7 +13,6 @@ Tasks:
     - TODO: Some of the methods that we have defined in the (mixin) class are designed to be used as a portal to information (return_binary_c_version_info for example.) The current design is that they are all instance methods, but that is not always necessary. We can decorate them with @staticmethod, or @classmethod to make it easier to use them (https://realpython.com/instance-class-and-static-methods-demystified/)
 """
 
-import copy
 import json
 import multiprocessing
 import os
@@ -26,7 +24,12 @@ import warnings
 from colorama import init as colorama_init
 
 from binarycpython.utils.dicts import AutoVivificationDict
+from binarycpython.utils.email_utils import Email_context_manager
 from binarycpython.utils.ensemble import new_grid_ensemble_results
+from binarycpython.utils.event_logging import (
+    event_based_logging_combine_individual_event_files,
+    event_based_logging_split_event_types_to_files,
+)
 from binarycpython.utils.functions import (
     check_if_in_shell,
     filter_arg_dict,
@@ -42,6 +45,9 @@ from binarycpython.utils.population_extensions.argument_handling import (
     argument_handling,
 )
 from binarycpython.utils.population_extensions.cache import cache
+from binarycpython.utils.population_extensions.custom_binary_c_logging import (
+    custom_binary_c_logging,
+)
 from binarycpython.utils.population_extensions.custom_generator_sampling import (
     custom_generator_sampling,
 )
@@ -49,6 +55,7 @@ from binarycpython.utils.population_extensions.dataIO import dataIO
 from binarycpython.utils.population_extensions.distribution_functions import (
     distribution_functions,
 )
+from binarycpython.utils.population_extensions.email_extension import Email
 from binarycpython.utils.population_extensions.ensemble import ensemble
 from binarycpython.utils.population_extensions.evolution_functions import (
     evolution_functions,
@@ -57,11 +64,11 @@ from binarycpython.utils.population_extensions.failing_systems_functions import
     failing_systems_functions,
 )
 from binarycpython.utils.population_extensions.grid_logging import grid_logging
-from binarycpython.utils.population_extensions.grid_options_defaults import (
-    grid_options_defaults,
-)
 from binarycpython.utils.population_extensions.grid_sampling import grid_sampling
 from binarycpython.utils.population_extensions.HPC import HPC
+from binarycpython.utils.population_extensions.logging_functionality import (
+    logging_functionality,
+)
 from binarycpython.utils.population_extensions.metadata import metadata
 from binarycpython.utils.population_extensions.miscellaneous_functions import (
     miscellaneous_functions,
@@ -72,6 +79,9 @@ from binarycpython.utils.population_extensions.Moe_di_Stefano_2017 import (
 from binarycpython.utils.population_extensions.monte_carlo_sampling import (
     monte_carlo_sampling,
 )
+from binarycpython.utils.population_extensions.population_options_defaults import (
+    population_options_defaults,
+)
 from binarycpython.utils.population_extensions.return_functions import return_functions
 from binarycpython.utils.population_extensions.sampling_variables import (
     sampling_variables,
@@ -98,7 +108,7 @@ class Population(
     dataIO,
     distribution_functions,
     grid_logging,
-    grid_options_defaults,
+    population_options_defaults,
     HPC,
     metadata,
     Moe_di_Stefano_2017,
@@ -117,6 +127,9 @@ class Population(
     evolution_functions,
     failing_systems_functions,
     sampling_variables,
+    custom_binary_c_logging,
+    logging_functionality,
+    Email,
 ):
     """
     Population Object. Contains all the necessary functions to set up, run and process a
@@ -136,7 +149,7 @@ class Population(
         dataIO.__init__(self)
         distribution_functions.__init__(self)
         grid_logging.__init__(self)
-        grid_options_defaults.__init__(self)
+        population_options_defaults.__init__(self)
         grid_sampling.__init__(self)
         HPC.__init__(self)
         metadata.__init__(self)
@@ -155,12 +168,23 @@ class Population(
         evolution_functions.__init__(self)
         failing_systems_functions.__init__(self)
         sampling_variables.__init__(self)
+        custom_binary_c_logging.__init__(self)
+        logging_functionality.__init__(self)
+        Email.__init__(self)
 
+        ##############
         # caches
         self.caches = {}
         self.cached_function_cache = {}
         self.original_function_cache = {}
+
+        # Unsorted
         self.hostnameslist = hostnames()
+        self.preloaded_population = None
+        self.signal_count = {}
+
+        ##############
+        # binary_c arguments
 
         # TODO: put in parameter handling or something
         # Different sections of options
@@ -172,54 +196,64 @@ class Population(
         self.special_params = [
             el for el in list(self.defaults.keys()) if el.endswith("%d")
         ]
-        self.preloaded_population = None
-        self.signal_count = {}
-
-        # make the input dictionary
         self.bse_options = {}  # bse_options is just empty.
 
-        # Grid options
-        self.grid_options = copy.deepcopy(self.get_grid_options_defaults_dict())
+        # Get the parsed version info
+        self.binary_c_version_info = self.return_binary_c_version_info(parsed=True)
 
-        # Custom options
-        # TODO: is this really necessary here? The custom options should be empty on start i think
-        self.custom_options = {
-            "save_snapshot": False,
-        }
+        ###############
+        # Handle options initialisation
 
-        # grid code generation
-        self.indent_depth = 0
-        self.indent_string = "    "
-        self.code_string = ""
+        # validation schema
+        self.set_validation_schema()
 
-        # cached value of minimum stellar mass
-        self._minimum_stellar_mass = None
+        # load default values
+        self.set_default_population_options()
+
+        # Set a custom options dictionary
+        self.custom_options = {}
+
+        #############
+        # Set up logging related stuff
 
         # logging levels
         self._LOGGER_VERBOSITY_LEVEL = 1
         self._CUSTOM_LOGGING_VERBOSITY_LEVEL = 2
 
+        # set loggers
+        self.logger = None
+
+        # grid code sampling generation
+        self.indent_depth = 0
+        self.indent_string = "    "
+        self.code_string = ""
+
         # Set the options that are passed at creation of the object
         self.set(**kwargs)
 
         # Load Moe and di Stefano options
-        self.grid_options["Moe2017_options"] = copy.deepcopy(
-            self.get_Moe_di_Stefano_2017_default_options()
-        )
+        self.population_options["Moe2017_options"] = {
+            key: value["value"]
+            for key, value in self.moe_distefano_options_defaults_dict.items()
+        }
 
         # Write MOE2017 options to a file. NOTE: (david) not sure why i put this here anymore
         os.makedirs(
-            os.path.join(self.grid_options["tmp_dir"], "moe_distefano"), exist_ok=True
+            os.path.join(self.population_options["tmp_dir"], "moe_distefano"),
+            exist_ok=True,
         )
         with self.open(
             os.path.join(
-                os.path.join(self.grid_options["tmp_dir"], "moe_distefano"),
+                os.path.join(self.population_options["tmp_dir"], "moe_distefano"),
                 "moeopts.dat",
             ),
             "w",
         ) as f:
             json.dump(
-                self.grid_options["Moe2017_options"], f, indent=4, ensure_ascii=False
+                self.population_options["Moe2017_options"],
+                f,
+                indent=4,
+                ensure_ascii=False,
             )
 
         # Argline dict
@@ -241,7 +275,7 @@ class Population(
                 self.ANSI_colours[c] = ""
 
         # Set global (OS) process id
-        self.grid_options["_main_pid"] = os.getpid()
+        self.population_options["_main_pid"] = os.getpid()
 
         # local process ID
         self.process_ID = 0
@@ -249,7 +283,7 @@ class Population(
         # Create location to store results. Users should write to this dictionary.
         # The AutoVivificationDict allows for Perl-like addition of possibly
         # non-existant subdicts.
-        self.grid_results = AutoVivificationDict()
+        self.population_results = AutoVivificationDict()
 
         # Create grid ensemble data location
         self.grid_ensemble_results = new_grid_ensemble_results()
@@ -288,7 +322,7 @@ class Population(
         """
 
         # empty results
-        self.grid_results = AutoVivificationDict()
+        self.population_results = AutoVivificationDict()
         self.grid_ensemble_results = new_grid_ensemble_results()
 
         # set number of processes/cores we want to use
@@ -298,7 +332,7 @@ class Population(
         self.process_ID = 0
 
         # Reset population ID:
-        self.grid_options["_population_id"] = uuid.uuid4().hex
+        self.population_options["_population_id"] = uuid.uuid4().hex
 
         # save number of stored log stats
         self.shared_memory["n_saved_log_stats"] = multiprocessing.Value("i", 0)
@@ -306,19 +340,19 @@ class Population(
         # set previous logging time
         _t = time.time()
         self.shared_memory["prev_log_time"] = multiprocessing.Array(
-            "d", [_t] * self.grid_options["n_logging_stats"]
+            "d", [_t] * self.population_options["n_logging_stats"]
         )
 
         # set previous logging system number to 0
         self.shared_memory["prev_log_system_number"] = multiprocessing.Array(
-            "i", [0] * self.grid_options["n_logging_stats"]
+            "i", [0] * self.population_options["n_logging_stats"]
         )
 
         # arrays to store memory and max memory use per-thread
         mem = 1.0 * mem_use()
         for x in ["", "max_"]:
             self.shared_memory[x + "memory_use_per_thread"] = multiprocessing.Array(
-                "d", [mem] * self.grid_options["num_processes"]
+                "d", [mem] * self.population_options["_num_processes"]
             )
 
         ############################################################
@@ -326,11 +360,11 @@ class Population(
         ############################################################
 
         # check tmp_dir exists
-        if self.grid_options["tmp_dir"] is None or not os.path.isdir(
-            self.grid_options["tmp_dir"]
+        if self.population_options["tmp_dir"] is None or not os.path.isdir(
+            self.population_options["tmp_dir"]
         ):
             print(
-                "grid_options['tmp_dir'] is not set or it is not a directory : this should point to a temporary directory location, preferably local to your CPUs"
+                "population_options['tmp_dir'] is not set or it is not a directory : this should point to a temporary directory location, preferably local to your CPUs"
             )
             self.exit(code=1)
 
@@ -346,17 +380,20 @@ class Population(
         #       to an HPC job, while the HPC status dir is common to
         #       all jobs)
         for x in ["status", "cache"]:
-            if self.grid_options[x + "_dir"] is None:
-                self.grid_options[x + "_dir"] = os.path.join(
-                    self.grid_options["tmp_dir"], x
+            if self.population_options[x + "_dir"] is None:
+                self.population_options[x + "_dir"] = os.path.join(
+                    self.population_options["tmp_dir"], x
                 )
 
+        #####################
+        # Check if directories actually are configured and that they exist
+
         # make list of directories we want to use
         dirs = ["tmp_dir", "status_dir", "cache_dir"] + self.HPC_dirs()
 
         for dir in dirs:
             # try to make directories if they don't exist
-            path = self.grid_options[dir]
+            path = self.population_options[dir]
             if path is not None:
                 os.makedirs(path, exist_ok=True)
 
@@ -377,7 +414,7 @@ class Population(
             "snapshots",
         ]
         for subdir in subdirs:
-            path = os.path.join(self.grid_options["tmp_dir"], subdir)
+            path = os.path.join(self.population_options["tmp_dir"], subdir)
             os.makedirs(path, exist_ok=True)
             if self.dir_ok(path) is False:
                 print(
@@ -388,8 +425,8 @@ class Population(
                 self.exit(code=1)
 
         # make sure the arg logging directory exists if we need it
-        if self.grid_options["log_args"]:
-            path = os.path.join(self.grid_options["log_args_dir"])
+        if self.population_options["log_args"]:
+            path = os.path.join(self.population_options["log_args_dir"])
             os.makedirs(path, exist_ok=True)
             if self.dir_ok(path) is False:
                 print(
@@ -399,6 +436,42 @@ class Population(
                 )
                 self.exit(code=1)
 
+        # check event_logging dir
+        if self.population_options["event_based_logging_handle_output"]:
+            if self.population_options["event_based_logging_output_directory"] is None:
+                print(
+                    "The 'event_based_logging_output_directory' parameter is not set to a valid path. Please reconfigure"
+                )
+                self.exit(code=1)
+            else:
+                self.vb_info(
+                    "Trying to create the event_based_logging output directory: {}".format(
+                        self.population_options["event_based_logging_output_directory"]
+                    )
+                )
+                if not os.path.isdir(
+                    self.population_options["event_based_logging_output_directory"]
+                ):
+                    try:
+                        os.makedirs(
+                            self.population_options[
+                                "event_based_logging_output_directory"
+                            ],
+                            exist_ok=True,
+                        )
+                    except:
+                        print(
+                            "Could not create the event_based_logging output directory: {}".format(
+                                self.population_options[
+                                    "event_based_logging_output_directory"
+                                ]
+                            )
+                        )
+                        self.exit(code=1)
+
+        #######
+        #
+
         # restore from existing HPC files
         self.HPC_restore()
 
@@ -423,68 +496,73 @@ class Population(
         Entry point function of the whole object. From here, based on the settings,
         we set up a grid and (probably) evolve the population.
 
-        There are no direct arguments to this function, the grid_options
+        There are no direct arguments to this function, the population_options
         contain all the relevant settings.
 
+        TODO: create a pre-evolve function to handle all the things that need to be done before the evolution
+        TODO: create a post-evolve function to handle all the things that need to be done before the evolution
+
         Returns:
                a dictionary containing the analytics of the run.
         """
 
-        # Just to make sure we don't have stuff from a previous run hanging around
-        self._pre_run_setup()
+        # wrapped to handle notifications with emails
+        with Email_context_manager(config=self.population_options, class_object=self):
 
-        if self.HPC_job():
-            # run HPC grid: if this returns True, then exit immediately
-            self.grid_options["symlink_latest_gridcode"] = False
-            if self.HPC_grid():
-                self.exit(code=0)
+            # Just to make sure we don't have stuff from a previous run hanging around
+            self._pre_run_setup()
 
-        if self.grid_options["evolution_type"] == "join":
-            # join previously calculated data and return immediately
-            self.HPC_join_previous()
-            return
+            if self.HPC_job():
+                # run HPC grid: if this returns True, then exit immediately
+                self.population_options["symlink_latest_gridcode"] = False
+                if self.HPC_grid():
+                    self.exit(code=0)
 
-        # Execute population evolution subroutines
-        result = self._evolve_population_wrapper()
+            if self.population_options["evolution_type"] == "join":
+                # join previously calculated data and return immediately
+                self.HPC_join_previous()
+                return
 
-        if result is False:
-            print("Error detected in _evolve_population() : stopping here")
+            # Execute population evolution subroutines
+            result = self._evolve_population_wrapper()
+            if result is False:
+                print("Error detected in _evolve_population() : stopping here")
+                sys.exit()
 
-            sys.exit()
+            # make analytics information
+            analytics_dict = self.make_analytics_dict()
 
-        # make analytics information
-        analytics_dict = self.make_analytics_dict()
+            if self.HPC_job():
+                self.HPC_dump_status("HPC grid after analytics")
 
-        if self.HPC_job():
-            self.HPC_dump_status("HPC grid after analytics")
+            if self.population_options["save_snapshot"]:
+                # we must save a snapshot, not the population object
+                # ... also save the new starting point: this has to take into
+                # account where we originally started, and that the modulo may
+                # not be == 1.
+                self.population_options["start_at"] = (
+                    self.population_options["start_at"]
+                    + self.population_options["_count"]
+                    * self.population_options["modulo"]
+                )
+                # then save the snapshot
+                self.save_snapshot()
+                exitcode = 1 if self.was_killed() else 0
+                self.exit(code=exitcode)
 
-        if self.custom_options["save_snapshot"]:
-            # we must save a snapshot, not the population object
-            # ... also save the new starting point: this has to take into
-            # account where we originally started, and that the modulo may
-            # not be == 1.
-            self.grid_options["start_at"] = (
-                self.grid_options["start_at"]
-                + self.grid_options["_count"] * self.grid_options["modulo"]
-            )
-            # then save the snapshot
-            self.save_snapshot()
-            exitcode = 1 if self.was_killed() else 0
-            self.exit(code=exitcode)
+            # Save object to a pickle file
+            elif self.population_options["save_population_object"]:
+                self.save_population_object()
 
-        # Save object to a pickle file
-        elif self.grid_options["save_population_object"]:
-            self.save_population_object()
+            # if we're running an HPC grid, exit here
+            # unless we're joining
+            if self.HPC_job() and self.population_options["evolution_type"] != "join":
+                self.exit()
 
-        # if we're running an HPC grid, exit here
-        # unless we're joining
-        if self.HPC_job() and self.grid_options["evolution_type"] != "join":
-            self.exit()
-
-        ##
-        # Clean up code: remove files, unset values, unload interpolators etc. This is placed in the general evolve function,
-        # because that makes for easier control
-        self._cleanup()
+            ##
+            # Clean up code: remove files, unset values, unload interpolators etc. This is placed in the general evolve function,
+            # because that makes for easier control
+            self._cleanup()
 
         return analytics_dict
 
@@ -502,20 +580,24 @@ class Population(
         False if we should return to the original calling script.
         """
 
+        ################
         # Check for restore
-        if self.grid_options["restore_from_snapshot_file"]:
-            self.load_snapshot(self.grid_options["restore_from_snapshot_file"])
+        if self.population_options["restore_from_snapshot_file"]:
+            self.load_snapshot(self.population_options["restore_from_snapshot_file"])
 
+        ###############
         # Check for parse function
-        if not self.grid_options["parse_function"]:
-            print("Warning: No parse function set. Make sure you intended to do this.")
+        if not self.population_options["parse_function"]:
+            self.vb_error(
+                "Warning: No parse function set. Make sure you intended to do this.",
+            )
 
-        # #######################
-        # ### Custom logging code:
+        #####################
+        # Custom logging code:
         self._set_custom_logging()
 
         # Unset some value
-        self.grid_options["_probtot"] = 0
+        self.population_options["_probtot"] = 0
 
         ## check the settings and set all the warnings.
         if self.bse_options.get("ensemble", None):
@@ -525,19 +607,19 @@ class Population(
         # Call setup function for specific evolution type
 
         # grid type
-        if self.grid_options["evolution_type"] == "grid":
+        if self.population_options["evolution_type"] == "grid":
             self._grid_sampling_setup()
 
         # user-provided custom generator
-        if self.grid_options["evolution_type"] == "custom_generator":
+        if self.population_options["evolution_type"] == "custom_generator":
             self._custom_generator_sampling_setup()
 
         # Source file
-        elif self.grid_options["evolution_type"] == "source_file":
+        elif self.population_options["evolution_type"] == "source_file":
             self._source_file_sampling_setup()
 
         # Monte-carlo
-        elif self.grid_options["evolution_type"] == "monte_carlo":
+        elif self.population_options["evolution_type"] == "monte_carlo":
             warnings.warn(
                 "Currently the Monte-Carlo implementation is not well-tested and should not be used for anything other than developing reasons."
             )
@@ -545,7 +627,7 @@ class Population(
 
         #######################
         # Reset values and prepare the grid function
-        self.grid_options[
+        self.population_options[
             "_probtot"
         ] = 0  # To make sure that the values are reset. TODO: fix this in a cleaner way
 
@@ -571,32 +653,74 @@ class Population(
             "_total_mass_run",
             "_total_probability_weighted_mass_run",
         ]:
-            self.grid_options[x] = 0
+            self.population_options[x] = 0
         for x in ["_errors_found", "_errors_exceeded"]:
-            self.grid_options[x] = False
-        self.grid_options["_system_generator"] = None
-        self.grid_options["_failed_systems_error_codes"] = []
-        self.grid_options["_queue_done"] = False
-        self.grid_options["stop_queue"] = False
-        self.grid_options["_job_crashed"] = False
+            self.population_options[x] = False
+        self.population_options["_system_generator"] = None
+        self.population_options["_failed_systems_error_codes"] = []
+        self.population_options["_queue_done"] = False
+        self.population_options["stop_queue"] = False
+        self.population_options["_job_crashed"] = False
+
+        #######
+        # Wrap up event based logging output
+        # TODO: perhaps we should make a general post-evolution hook to store this part
+        if self.population_options["event_based_logging_handle_output"]:
+
+            # Combine and split event types
+            if self.population_options[
+                "event_based_logging_combine_individual_event_files"
+            ]:
+                event_based_logging_combine_individual_event_files(
+                    output_dir=self.population_options[
+                        "event_based_logging_output_directory"
+                    ],
+                    basename="events",
+                    combined_name=self.population_options[
+                        "event_based_logging_combined_events_filename"
+                    ],
+                    check_duplicates_and_all_present=False,
+                    remove_individual_files=self.population_options[
+                        "event_based_logging_remove_individual_event_files_after_combining"
+                    ],
+                )
+
+            # Split combined events file to files for each specific type of event
+            if self.population_options[
+                "event_based_logging_split_events_file_to_each_type"
+            ]:
+                event_based_logging_split_event_types_to_files(
+                    input_file=os.path.join(
+                        self.population_options["event_based_logging_output_directory"],
+                        self.population_options[
+                            "event_based_logging_combined_events_filename"
+                        ],
+                    ),
+                    events_parameters_list_dict=self.population_options[
+                        "event_based_logging_parameter_list_dict"
+                    ],
+                    remove_original_file=self.population_options[
+                        "event_based_logging_remove_original_combined_events_file_after_splitting"
+                    ],
+                )
 
         ############
         # Calls to each specific evolution type cleanup functions
 
         # grid type
-        if self.grid_options["evolution_type"] == "grid":
+        if self.population_options["evolution_type"] == "grid":
             self._grid_sampling_cleanup()
 
         # user-provided custom generator
-        if self.grid_options["evolution_type"] == "custom_generator":
+        if self.population_options["evolution_type"] == "custom_generator":
             self._custom_generator_sampling_cleanup()
 
         # Source file
-        elif self.grid_options["evolution_type"] == "source_file":
+        elif self.population_options["evolution_type"] == "source_file":
             self._source_file_sampling_cleanup()
 
         # Monte-carlo
-        elif self.grid_options["evolution_type"] == "monte_carlo":
+        elif self.population_options["evolution_type"] == "monte_carlo":
             self._monte_carlo_sampling_cleanup()
 
     def _dry_run(self):
@@ -608,12 +732,10 @@ class Population(
         NOTE: (david): this is a rather general function, and I'm not sure if we want to have a general dry-run function?
         """
 
-        self.verbose_print(
-            "Doing a dry run of the grid.", self.grid_options["verbosity"], 1
-        )
-        system_generator = self.grid_options["_system_generator"]
+        self.vb_error("Doing a dry run of the grid.")
+        system_generator = self.population_options["_system_generator"]
         total_starcount = system_generator(self)
-        self.grid_options["_total_starcount"] = total_starcount
+        self.population_options["_total_starcount"] = total_starcount
 
     ###################################################
     # Unordered functions
@@ -645,13 +767,13 @@ class Population(
         Function to add to the total probability. For now not used
         """
 
-        self.grid_options["_probtot"] += prob
+        self.population_options["_probtot"] += prob
 
     def _increment_count(self):
         """
         Function to add to the total number of stars. For now not used
         """
-        self.grid_options["_count"] += 1
+        self.population_options["_count"] += 1
 
     #####
     #
@@ -664,19 +786,19 @@ class Population(
         # Get generator for different evolution methods
 
         # grid type
-        if self.grid_options["evolution_type"] == "grid":
+        if self.population_options["evolution_type"] == "grid":
             generator = self._grid_sampling_get_generator()
 
         # user-provided custom generator
-        if self.grid_options["evolution_type"] == "custom_generator":
+        if self.population_options["evolution_type"] == "custom_generator":
             generator = self._custom_generator_sampling_get_generator()
 
         # Source file
-        elif self.grid_options["evolution_type"] == "source_file":
+        elif self.population_options["evolution_type"] == "source_file":
             generator = self._source_file_sampling_get_generator()
 
         # Monte-carlo
-        elif self.grid_options["evolution_type"] == "monte_carlo":
+        elif self.population_options["evolution_type"] == "monte_carlo":
             generator = self._monte_carlo_sampling_get_generator()
 
         return generator
