@@ -40,10 +40,10 @@ class HPC(condor, slurm):
         Function to return the number of jobs this HPC jobs will use, as an int.
         """
 
-        if self.grid_options["slurm"] > 0:
-            n = self.grid_options["slurm_njobs"]
-        elif self.grid_options["condor"] > 0:
-            n = self.grid_options["condor_njobs"]
+        if self.population_options["slurm"] > 0:
+            n = self.population_options["slurm_njobs"]
+        elif self.population_options["condor"] > 0:
+            n = self.population_options["condor_njobs"]
         else:
             n = None
         return int(n)
@@ -99,14 +99,14 @@ class HPC(condor, slurm):
         # check the joiningfile doesn't exist
         if not overwrite and os.path.isfile(file):
             # file already exists
-            print(
+            self.vb_info(
                 "Cannot make joiningfile at {file} because it already exists, instead I am waiting for it to be unlocked.".format(
                     file=file
                 )
             )
             self.wait_for_unlock(file)
             joinfiles = self.HPC_load_joinfiles_list(joinlist=file)
-            print(
+            self.vb_info(
                 "Unlocked and got {} should be {}".format(
                     len(joinfiles), self.HPC_njobs()
                 )
@@ -121,7 +121,9 @@ class HPC(condor, slurm):
 
             # write to it if we are first to obtain unique access
             if lock and f:
-                print("Making joiningfile list range (0,{}) at {}".format(n, file))
+                self.vb_info(
+                    "Making joiningfile list range (0,{}) at {}".format(n, file)
+                )
                 f.write(string)
                 f.flush()
                 os.fsync(f.fileno())
@@ -130,17 +132,21 @@ class HPC(condor, slurm):
                 os.sync()
                 self.NFS_flush_hack(file)
 
-                print(
+                self.vb_info(
                     "Checking joiningfile {} length (size = {})".format(
                         file, os.path.getsize(file)
                     )
                 )
                 joinfiles = self.HPC_load_joinfiles_list(joinlist=file)
-                print("Got {} should be {}".format(len(joinfiles), self.HPC_njobs()))
+                self.vb_info(
+                    "Got {} should be {}".format(len(joinfiles), self.HPC_njobs())
+                )
 
             else:
                 x = False
-                print("Joiningfile failed to get lock: waiting for it to be unlocked")
+                self.vb_info(
+                    "Joiningfile failed to get lock: waiting for it to be unlocked"
+                )
                 self.wait_for_unlock(file)
         return x
 
@@ -150,22 +156,22 @@ class HPC(condor, slurm):
         """
 
         if joinlist is None:
-            joinlist = self.grid_options["joinlist"]
+            joinlist = self.population_options["joinlist"]
         return joinlist
 
     def HPC_load_joinfiles_list(self, joinlist=None):
         """
         Function to load in the list of files we should join, and return it.
 
-        If grid_options['HPC_rebuild_joinlist'] is True, we rebuild it.
+        If population_options['HPC_rebuild_joinlist'] is True, we rebuild it.
         """
 
         prefix = os.path.join(self.HPC_dir(), "results")
 
-        if self.grid_options["HPC_rebuild_joinlist"] == 1:
+        if self.population_options["HPC_rebuild_joinlist"] == 1:
             # we should rebuild the joinlist from the
             # files we find at the prefix directory
-            print("Rebuild joinlist from existing files")
+            self.vb_info("Rebuild joinlist from existing files")
             joinlist = glob.glob(str(prefix) + "/*.gz")
             return joinlist
 
@@ -176,14 +182,13 @@ class HPC(condor, slurm):
             joinlist = f.read().splitlines()
             f.close()
 
-            if False:
-                print(
-                    "HPC_load_joinfiles_list read joinlist {joinlist} -> gave file joinlist of length {len_joinlist} with contents {joinlist}".format(
-                        joinlist=joinlist, len_joinlist=len(joinlist)
-                    )
+            self.vb_info(
+                "HPC_load_joinfiles_list read joinlist {joinlist} -> gave file joinlist of length {len_joinlist} with contents {joinlist}".format(
+                    joinlist=joinlist, len_joinlist=len(joinlist)
                 )
+            )
         except Exception as e:
-            print(
+            self.vb_info(
                 "Failed to open joinlist at {joinlist} : {e}".format(
                     joinlist=joinlist, e=e
                 )
@@ -197,7 +202,7 @@ class HPC(condor, slurm):
         Merge the results from the list joinfiles into newobj.
         """
         for file in joinfiles:
-            print("Join data in", file)
+            self.vb_info("Join data in", file)
             self.merge_populations_from_file(newobj, file)
         return newobj
 
@@ -207,62 +212,52 @@ class HPC(condor, slurm):
         and their .saved equivalents also exist
         """
 
-        print("HPC check if we can join at {}".format(now()))
+        self.vb_info("HPC check if we can join at {}".format(now()))
 
-        if self.grid_options["HPC_force_join"] == 0 and os.path.exists(joiningfile):
-            if vb:
-                print(
-                    "cannot join : joiningfile exists at {} (check 1)".format(
-                        joiningfile
-                    )
-                )
+        if self.population_options["HPC_force_join"] == 0 and os.path.exists(
+            joiningfile
+        ):
+            self.vb_warning(
+                "cannot join : joiningfile exists at {} (check 1)".format(joiningfile)
+            )
             return False
         else:
-            if vb:
-                print("joiningfile (at {}) does not exist".format(joiningfile))
+            self.vb_warning("joiningfile (at {}) does not exist".format(joiningfile))
 
         for file in joinfiles:
-            if vb:
-                print("check for {}".format(file))
-
+            self.vb_info("check for {}".format(file))
             if os.path.exists(file) is False:
-                if vb:
-                    print('cannot join : file "{}" does not exist'.format(file))
+                self.vb_warning('cannot join : file "{}" does not exist'.format(file))
                 return False
 
             savedfile = file + ".saved"
-            if vb:
-                print("check for {}".format(savedfile))
 
+            self.vb_info("check for {}".format(savedfile))
             if os.path.exists(savedfile) is False:
-                if vb:
-                    print(
-                        'cannot join : savedfile "{}" does not exist'.format(savedfile)
-                    )
+                self.vb_warning(
+                    'cannot join : savedfile "{}" does not exist'.format(savedfile)
+                )
                 return False
 
             # found both files
-            if vb:
-                print("found {} and {}".format(file, savedfile))
+            self.vb_info("found {} and {}".format(file, savedfile))
 
         # check for joiningfile again
-        if self.grid_options["HPC_force_join"] == 1:
-            print("Forcing join because HPC_force_join is set")
+        if self.population_options["HPC_force_join"] == 1:
+            self.vb_info("Forcing join because HPC_force_join is set")
             x = True
         elif os.path.exists(joiningfile):
-            if vb:
-                print(
-                    "cannot join: joiningfile exists at {} (check 2)".format(
-                        joiningfile
-                    )
-                )
+            self.vb_warning(
+                "cannot join: joiningfile exists at {} (check 2)".format(joiningfile)
+            )
             x = False
         elif vb:
-            print("joiningfile at {} does not exist : can join".format(joiningfile))
+            self.vb_warning(
+                "joiningfile at {} does not exist : can join".format(joiningfile)
+            )
             x = True
 
-        if vb:
-            print("returning {} from HPC_can_join()".format(x))
+        self.vb_info("returning {} from HPC_can_join()".format(x))
 
         return x
 
@@ -271,17 +266,20 @@ class HPC(condor, slurm):
         Function to return True if we're running an HPC (Slurm or Condor) job, False otherwise.
         """
 
-        return bool(self.grid_options["slurm"] > 0 or self.grid_options["condor"] > 0)
+        return bool(
+            self.population_options["slurm"] > 0
+            or self.population_options["condor"] > 0
+        )
 
     def HPC_job_task(self):
         """
         Function to return the HPC task number, which is 1 when setting
         up and running the scripts, 2 when joining data.
         """
-        if self.grid_options["slurm"] > 0:
-            x = self.grid_options["slurm"]
-        elif self.grid_options["condor"] > 0:
-            x = self.grid_options["condor"]
+        if self.population_options["slurm"] > 0:
+            x = self.population_options["slurm"]
+        elif self.population_options["condor"] > 0:
+            x = self.population_options["condor"]
         else:
             x = 0
         return x
@@ -291,9 +289,9 @@ class HPC(condor, slurm):
         Function to return a string telling us the type of an HPC job, i.e.
         "slurm", "condor" or "None".
         """
-        if self.grid_options["slurm"] > 0:
+        if self.population_options["slurm"] > 0:
             hpc_type = "slurm"
-        elif self.grid_options["condor"] > 0:
+        elif self.population_options["condor"] > 0:
             hpc_type = "condor"
         else:
             hpc_type = "None"
@@ -304,9 +302,9 @@ class HPC(condor, slurm):
         Function to return an HPC (Slurm or Condor) job id in the form of a string, x.y. Returns None if not an HPC job.
         """
 
-        if self.grid_options["slurm"] > 0:
+        if self.population_options["slurm"] > 0:
             hpc_jobid = self.slurmID()
-        elif self.grid_options["condor"] > 0:
+        elif self.population_options["condor"] > 0:
             hpc_jobid = self.condorID()
         else:
             # not an HPC job
@@ -339,9 +337,9 @@ class HPC(condor, slurm):
                  string : the new contents of the status file
         """
 
-        if self.grid_options["slurm"] > 0:
+        if self.population_options["slurm"] > 0:
             self.set_slurm_status(string)
-        elif self.grid_options["condor"] > 0:
+        elif self.population_options["condor"] > 0:
             self.set_condor_status(string)
         else:
             pass
@@ -356,11 +354,11 @@ class HPC(condor, slurm):
             job_id,job_index : the id and index of the job to be queried
         """
 
-        if self.grid_options["slurm"] > 0:
+        if self.population_options["slurm"] > 0:
             status = self.get_slurm_status(
                 jobid=job_id, jobarrayindex=job_index, slurm_dir=hpc_dir
             )
-        elif self.grid_options["condor"] > 0:
+        elif self.population_options["condor"] > 0:
             status = self.get_condor_status(
                 ClusterID=job_id, Process=job_index, condor_dir=hpc_dir
             )
@@ -373,9 +371,9 @@ class HPC(condor, slurm):
         """
         Function to return a list of directories required for this HPC job.
         """
-        if self.grid_options["slurm"] > 0:
+        if self.population_options["slurm"] > 0:
             dirs = self.slurm_dirs()
-        elif self.grid_options["condor"] > 0:
+        elif self.population_options["condor"] > 0:
             dirs = self.condor_dirs()
         else:
             dirs = []
@@ -401,9 +399,9 @@ class HPC(condor, slurm):
         if makejoiningfile and self.HPC_job_task() == 2 and jobid is not None:
             self.HPC_make_joiningfile()
 
-        if self.grid_options["slurm"] > 0:
+        if self.population_options["slurm"] > 0:
             x = self.slurm_grid()
-        elif self.grid_options["condor"] > 0:
+        elif self.population_options["condor"] > 0:
             x = self.condor_grid()
         else:
             x = None  # should not happen
@@ -417,9 +415,9 @@ class HPC(condor, slurm):
         """
         Function to check HPC option requirements have been met. Returns a tuple: (True,"") if all is ok, (False,<warning string>) otherwise.
         """
-        if self.grid_options["slurm"] > 0:
+        if self.population_options["slurm"] > 0:
             t = self.slurm_check_requirements()
-        elif self.grid_options["condor"] > 0:
+        elif self.population_options["condor"] > 0:
             t = self.condor_check_requirements()
         else:
             t = (True, "")
@@ -430,9 +428,9 @@ class HPC(condor, slurm):
         HPC jobs have a filename in their directory which specifies the job id. This function returns the contents of that file as a string, or None on failure.
         """
 
-        if self.grid_options["slurm"] > 0:
+        if self.population_options["slurm"] > 0:
             filename = "jobid"
-        elif self.grid_options["condor"] > 0:
+        elif self.population_options["condor"] > 0:
             filename = "ClusterID"
         else:
             filename = None
@@ -450,7 +448,7 @@ class HPC(condor, slurm):
         file = os.path.join(hpc_dir, filename)
         f = self.open(file, "r", encoding="utf-8")
         if not f:
-            print(
+            self.vb_error(
                 "Error: could not open {file} to read the HPC jobid of the directory {hpc_dir}".format(
                     file=file, hpc_dir=hpc_dir
                 )
@@ -459,7 +457,9 @@ class HPC(condor, slurm):
 
         oldjobid = f.read().strip()
         if not oldjobid:
-            print("Error: could not find jobid in {hpc_dir}".format(hpc_dir=hpc_dir))
+            self.vb_error(
+                "Error: could not find jobid in {hpc_dir}".format(hpc_dir=hpc_dir)
+            )
             self.exit(code=1)
         else:
             f.close()
@@ -467,9 +467,9 @@ class HPC(condor, slurm):
 
     def HPC_restore(self):
         """
-        Set grid_options['restore_from_snapshot_file'] so that we restore data from existing
-        an HPC run if self.grid_options[hpc_job_type+'_restart_dir'], where hpc_job_type is "slurm" or "condor",
-        is provided, otherwise do nothing. This only works if grid_options[hpc_job_type] == self.HPC_job_task() == 2, which is
+        Set population_options['restore_from_snapshot_file'] so that we restore data from existing
+        an HPC run if self.population_options[hpc_job_type+'_restart_dir'], where hpc_job_type is "slurm" or "condor",
+        is provided, otherwise do nothing. This only works if population_options[hpc_job_type] == self.HPC_job_task() == 2, which is
         the run-grid stage of the process.
         """
 
@@ -478,11 +478,11 @@ class HPC(condor, slurm):
             return
 
         key = hpc_job_type + "_restart_dir"
-        if key not in self.grid_options:
+        if key not in self.population_options:
             return
 
         # get restart directory
-        hpc_dir = self.grid_options[hpc_job_type + "_restart_dir"]
+        hpc_dir = self.population_options[hpc_job_type + "_restart_dir"]
         if hpc_dir is None:
             return
 
@@ -491,9 +491,11 @@ class HPC(condor, slurm):
         if index is None:
             return
 
-        if self.HPC_job_task() == 2:  # (same as) self.grid_options[hpc_job_type] == 2:
+        if (
+            self.HPC_job_task() == 2
+        ):  # (same as) self.population_options[hpc_job_type] == 2:
             old_id = self.HPC_id_from_dir(hpc_dir)
-            print(
+            self.vb_info(
                 "Restart from hpc_dir {hpc_dir} which was has (old) ID {old_id}, we are job index {index}".format(
                     hpc_dir=hpc_dir, old_id=old_id, index=index
                 )
@@ -503,7 +505,7 @@ class HPC(condor, slurm):
             status = self.HPC_get_status(hpc_dir=hpc_dir)
 
             if status == "finished":
-                print("Status is finished, cannot and do not need to restart.")
+                self.vb_info("Status is finished, cannot and do not need to restart.")
                 self.exit(code=0)
 
             file = os.path.join(
@@ -513,11 +515,11 @@ class HPC(condor, slurm):
             if os.path.exists(file):
                 # have data from which we can restore, set it in
                 # the appropriate grid option
-                print("Restore this run from snapshot {file}".format(file=file))
-                self.grid_options["restore_from_snapshot_file"] = file
+                self.vb_info("Restore this run from snapshot {file}".format(file=file))
+                self.population_options["restore_from_snapshot_file"] = file
             else:
                 # no snapshot: so no need to restore, just exit
-                print(
+                self.vb_info(
                     "Expected snapshot at {file} but none was found".format(file=file)
                 )
                 self.exit(code=0)
@@ -529,11 +531,11 @@ class HPC(condor, slurm):
         """
         # check that our job has finished
         status = self.HPC_get_status()
-        print("Job status", status)
+        self.vb_info("Job status", status)
 
-        if self.grid_options["HPC_force_join"] == 0 and status != "finished":
+        if self.population_options["HPC_force_join"] == 0 and status != "finished":
             # job did not finish : save a snapshot
-            print(
+            self.vb_info(
                 "This job did not finish (status is {status}) : cannot join".format(
                     status=status
                 )
@@ -545,7 +547,7 @@ class HPC(condor, slurm):
             # HPC_queue_stats = self.HPC_queue_stats()
 
             if HPC_status["status"]["finished"] != HPC_status["njobs"]:
-                print(
+                self.vb_info(
                     "HPC_status reports {} finished jobs out of {}. We cannot join because not all the jobs are finished. Exiting.".format(
                         HPC_status["status"]["finished"], HPC_status["njobs"]
                     )
@@ -554,49 +556,49 @@ class HPC(condor, slurm):
 
             joinfiles = self.HPC_load_joinfiles_list()
             joiningfile = self.HPC_path("joining")
-            print(
+            self.vb_info(
                 "Joinfile list n={n} (should be {m})".format(
                     n=len(joinfiles), m=self.HPC_njobs()
                 )
             )
-            print("Joingingfile path : ", joiningfile)
+            self.vb_info("Joingingfile path : ", joiningfile)
 
             if len(joinfiles) != self.HPC_njobs():
-                print("Number of joinfiles != njobs : this is wrong, exiting.")
+                self.vb_error("Number of joinfiles != njobs : this is wrong, exiting.")
                 self.exit(1)
 
             if self.HPC_can_join(joinfiles, joiningfile, vb=True):
                 # join object files
-                print("We can join")
+                self.vb_info("We can join")
                 try:
                     # touch joiningfile
-                    if self.grid_options["HPC_force_join"] == 0:
-                        print("Making joiningfile at {}".format(joiningfile))
+                    if self.population_options["HPC_force_join"] == 0:
+                        self.vb_info("Making joiningfile at {}".format(joiningfile))
                         self.HPC_touch(joiningfile)
                     try:
-                        print("Calling HPC_join_from_files()")
+                        self.vb_info("Calling HPC_join_from_files()")
                         self.HPC_join_from_files(self, joinfiles)
                     except Exception as e:
-                        print("Join gave exception", e)
+                        self.vb_info("Join gave exception", e)
                         # disable analytics calculations : use the
                         # values we just loaded
-                    self.grid_options["do_analytics"] = False
+                    self.population_options["do_analytics"] = False
                     return
                 except Exception as e:
-                    print("pass {}", e)
+                    self.vb_info("pass {}", e)
                     pass
             else:
-                print("cannot join : other tasks are not yet finished\n")
-                print("Finished this job : exiting")
+                self.vb_info("cannot join : other tasks are not yet finished\n")
+                self.vb_info("Finished this job : exiting")
         self.exit(code=1)
 
     def HPC_path(self, path):
         """
         Function to file the filename of this HPC job's file at path.
         """
-        if self.grid_options["slurm"] > 0:
+        if self.population_options["slurm"] > 0:
             p = self.slurmpath(path)
-        elif self.grid_options["condor"] > 0:
+        elif self.population_options["condor"] > 0:
             p = self.condorpath(path)
         else:
             p = None
@@ -616,10 +618,10 @@ class HPC(condor, slurm):
         """
         Function to return an HPC job's directory.
         """
-        if self.grid_options["slurm"] > 0:
-            d = self.grid_options["slurm_dir"]
-        elif self.grid_options["condor"] > 0:
-            d = self.grid_options["condor_dir"]
+        if self.population_options["slurm"] > 0:
+            d = self.population_options["slurm_dir"]
+        elif self.population_options["condor"] > 0:
+            d = self.population_options["condor_dir"]
         else:
             d = None
         return d
@@ -679,7 +681,6 @@ class HPC(condor, slurm):
 
             for i in self.HPC_job_id_range():
                 s = self.HPC_get_status(job_id=_id, job_index=i)
-                # print("HPC get job",_id,':',i," status=",s)
                 if s is None:
                     s = "unknown"
                 if s not in d["status"]:
@@ -703,19 +704,19 @@ class HPC(condor, slurm):
 
         d = self.HPC_status()
 
-        print("############################################################")
-        print("HPC job status " + string)
-        print(json.dumps(d, indent=4))
-        print("############################################################")
+        self.vb_info("############################################################")
+        self.vb_info("HPC job status " + string)
+        self.vb_info(json.dumps(d, indent=4))
+        self.vb_info("############################################################")
 
     def HPC_queue_stats(self):  # pragma: no cover
         """
         Function that returns the queue stats for the HPC grid
         """
 
-        if self.grid_options["slurm"] > 0:
+        if self.population_options["slurm"] > 0:
             x = self.slurm_queue_stats()
-        elif self.grid_options["condor"] > 0:
+        elif self.population_options["condor"] > 0:
             x = self.condor_queue_stats()
         else:
             x = None
@@ -724,12 +725,12 @@ class HPC(condor, slurm):
 
     def HPC_job_id_range(self):
         n = self.HPC_njobs()
-        if self.grid_options["slurm"] > 0:
+        if self.population_options["slurm"] > 0:
             return range(1, n + 1)
-        elif self.grid_options["condor"] > 0:
+        elif self.population_options["condor"] > 0:
             return range(0, n)
         else:
-            print(
+            self.vb_error(
                 "Called HPC_job_id_range when not running an HPC grid : you cannot do this."
             )
             raise
