@@ -4,7 +4,7 @@ File containing the class extension for the population object that contains cach
 Module containing (e.g. LRU) cache functionality for binary_c-python.
 
 We use cachetools when possible because this allows us to set up the
-cache of the appropriate size for the task in the grid_options dict.
+cache of the appropriate size for the task in the population_options dict.
 Please see the LRU_* options in there.
 """
 
@@ -31,9 +31,22 @@ class cache:
 
         return
 
+    # def default_cache_dir(self):
+    #     """
+    #     Return a default cache directory path, or None if we cannot find one.
+    #     """
+    #     error_string = "__*ERR*__"  # string that cannot be a path
+    #     for path in [
+    #         os.path.join(os.environ.get("HOME", error_string), ".cache", "binary_c"),
+    #         os.path.join(os.environ.get("TMP", error_string), "cache"),
+    #     ]:
+    #         if error_string not in path and os.path.isdir(path):
+    #             return path
+    #     return None
+
     def default_cache_dir(self):
         """
-        Return a default cache directory path for binary_c-python, or None if we cannot find one. This is used in grid_options_defaults.py
+        Return a default cache directory path for binary_c-python, or None if we cannot find one. This is used in population_options_defaults.py
         """
 
         error_string = "__*ERR*__"  # string that cannot be a path
@@ -92,8 +105,8 @@ class cache:
         """
         Function to wrap binary_c-python's functions in function cache.
 
-        The functions listed in self.grid_options['function_cache_functions'] are
-        given caches of size self.grid_options['function_cache_size'][func]
+        The functions listed in self.population_options['function_cache_functions'] are
+        given caches of size self.population_options['function_cache_size'][func]
 
         Args: None
         """
@@ -101,14 +114,14 @@ class cache:
         # add our custom NullCache to the cachetools selection
         setattr(cachetools, "NullCache", self.NullCache)
 
-        if not self.grid_options["function_cache"]:
+        if not self.population_options["function_cache"]:
             # no function cache: set all to NullCache
             # TODO: This cachetype(Nullcache) is wrong.
-            for func in self.grid_options["function_cache_functions"].keys():
+            for func in self.population_options["function_cache_functions"].keys():
                 self.function_cache[func] = cachetype(self.NullCache)
 
-        for func in self.grid_options["function_cache_functions"].keys():
-            (maxsize, cachetype, testargs) = self.grid_options[
+        for func in self.population_options["function_cache_functions"].keys():
+            (maxsize, cachetype, testargs) = self.population_options[
                 "function_cache_functions"
             ].get(func)
 
@@ -116,30 +129,31 @@ class cache:
             if cachetype:
                 # use type passed in, if given
                 usecachetype = cachetype
-            elif not self.grid_options["function_cache"]:
+            elif not self.population_options["function_cache"]:
                 # function cache is disabled, use NoCache
                 usecachetype = "NoCache"
             else:
                 if cachetype is None:
                     # use the default type
-                    usecachetype = self.grid_options["function_cache_default_type"]
+                    usecachetype = self.population_options[
+                        "function_cache_default_type"
+                    ]
                 else:
                     # use type passed in
                     usecachetype = cachetype
 
-            if vb:
-                print(
-                    "Setup cache for func {func} : maxsize={maxsize}, cachetype={cachetype}, testargs={testargs}-> use {usecachetype}".format(
-                        func=func,
-                        maxsize=maxsize,
-                        cachetype=cachetype,
-                        testargs=testargs,
-                        usecachetype=usecachetype,
-                    )
+            self.vb_info(
+                "Setup cache for func {func} : maxsize={maxsize}, cachetype={cachetype}, testargs={testargs}-> use {usecachetype}".format(
+                    func=func,
+                    maxsize=maxsize,
+                    cachetype=cachetype,
+                    testargs=testargs,
+                    usecachetype=usecachetype,
                 )
+            )
 
             if usecachetype == "TTLCache":
-                extra_cacheargs = [self.grid_options["function_cache_TTL"]]
+                extra_cacheargs = [self.population_options["function_cache_TTL"]]
             else:
                 extra_cacheargs = []
 
@@ -184,14 +198,13 @@ class cache:
                 cachetools_func = getattr(cachetools, usecachetype)
 
             if maxsize == 0:
-                maxsize = self.grid_options["function_cache_default_maxsize"]
+                maxsize = self.population_options["function_cache_default_maxsize"]
 
-            if vb:
-                print(
-                    "Make function cache for func {func}, maxsize {maxsize}".format(
-                        func=func, maxsize=maxsize
-                    )
+            self.vb_info(
+                "Make function cache for func {func}, maxsize {maxsize}".format(
+                    func=func, maxsize=maxsize
                 )
+            )
 
             # set up cache function args
             if maxsize is None:
@@ -222,25 +235,25 @@ class cache:
 
         # loop lists
         cachetypes = ("NoCache", "NullCache", "FIFOCache", "LRUCache", "TTLCache")
-        functions = self.grid_options["function_cache_functions"].keys()
+        functions = self.population_options["function_cache_functions"].keys()
         maxsizes = (0, 1, 2, 4, 8, 16, 32, 64, 128, 256)
 
-        self.grid_options["function_cache"] = True
+        self.population_options["function_cache"] = True
         for n, func in enumerate(functions):
-            print("Cache speed test of function {func}".format(func=func))
-            print("{:18s}".format(""), end="")
+            self.vb_debug("Cache speed test of function {func}".format(func=func))
+            self.vb_debug("{:18s}".format(""), end="")
             for x, maxsize in enumerate(maxsizes):
-                print("{:>9s}".format(str(maxsize)), end="")
-            print("")
+                self.vb_debug("{:>9s}".format(str(maxsize)), end="")
+            self.vb_debug("")
 
             best = 0
             best_type = None
             best_maxsize = None
             for y, type in enumerate(cachetypes):
-                print("{:18s}".format(type), end="")
-                self.grid_options["function_cache_default_type"] = type
+                self.vb_debug("{:18s}".format(type), end="")
+                self.population_options["function_cache_default_type"] = type
                 self.setup_function_cache()
-                (maxsize, cachetype, testargs) = self.grid_options[
+                (maxsize, cachetype, testargs) = self.population_options[
                     "function_cache_functions"
                 ].get(func)
 
@@ -280,21 +293,20 @@ class cache:
                                     count += 1
                             # TODO: specify the exception
                             except Exception as e:
-                                print("Cache call failed:", e)
+                                self.vb_error("Cache call failed:", e)
                                 self.exit(1)
 
                         if count < 99999:
-                            print("{:9d}".format(count), end="")
+                            self.vb_debug("{:9d}".format(count), end="")
                         else:
-                            print("{:9.2e}".format(float(count)), end="")
+                            self.vb_debug("{:9.2e}".format(float(count)), end="")
 
                         if count > best:
                             best = count
                             best_type = type
                             best_maxsize = maxsize
-                    print("")
 
-            print(
+            self.vb_info(
                 "Best cache type {type} with maxsize {maxsize}\n".format(
                     type=best_type, maxsize=best_maxsize
                 )
