@@ -34,12 +34,12 @@ class condor:
 
     def condorID(self, ClusterID=None, Process=None):
         """
-        Function to return a Condor job ID as a string, [ClusterID].[Process]. The ClusterID and Process passed in are used if given, otherwise we default to the condor_ClusterID and condor_Process in grid_options.
+        Function to return a Condor job ID as a string, [ClusterID].[Process]. The ClusterID and Process passed in are used if given, otherwise we default to the condor_ClusterID and condor_Process in population_options.
         """
         if ClusterID is None:
-            ClusterID = self.grid_options["condor_ClusterID"]
+            ClusterID = self.population_options["condor_ClusterID"]
         if Process is None:
-            Process = self.grid_options["condor_Process"]
+            Process = self.population_options["condor_Process"]
         return "{ClusterID}.{Process}".format(ClusterID=ClusterID, Process=Process)
 
     def condorpath(self, path, condor_dir=None):
@@ -48,12 +48,12 @@ class condor:
         """
 
         if condor_dir is None:
-            condor_dir = self.grid_options["condor_dir"]
+            condor_dir = self.population_options["condor_dir"]
         return os.path.abspath(os.path.join(condor_dir, path))
 
     def condor_status_file(self, ClusterID=None, Process=None, condor_dir=None):
         """
-        Return the condor status file corresponding to the ClusterID and Process, which default to grid_options condor_ClusterID and condor_Process, respectively.
+        Return the condor status file corresponding to the ClusterID and Process, which default to population_options condor_ClusterID and condor_Process, respectively.
         """
         return os.path.join(
             self.condorpath("status", condor_dir=condor_dir),
@@ -62,17 +62,17 @@ class condor:
 
     def condor_check_requirements(self):
         """
-        Function to check whether the condor parameters in grid_options have been set appropriately.
+        Function to check whether the condor parameters in population_options have been set appropriately.
         """
-        if self.grid_options["condor"] > 0 and (
-            self.grid_options["condor_dir"] is None
-            or not os.path.isdir(self.grid_options["condor_dir"])
+        if self.population_options["condor"] > 0 and (
+            self.population_options["condor_dir"] is None
+            or not os.path.isdir(self.population_options["condor_dir"])
         ):
             return (
                 False,
                 "You have set condor={condor} but not set condor_dir ({condor_dir}) correctly. Please set it and try again.".format(
-                    condor=self.grid_options["condor"],
-                    condor_dir=self.grid_options["condor_dir"],
+                    condor=self.population_options["condor"],
+                    condor_dir=self.population_options["condor_dir"],
                 ),
             )
         return (True, "")
@@ -95,14 +95,14 @@ class condor:
         # save condor ClusterID to file
 
         if condor_dir is None:
-            condor_dir = self.grid_options["condor_dir"]
+            condor_dir = self.population_options["condor_dir"]
 
         idfile = os.path.join(condor_dir, "ClusterID")
         if not os.path.exists(idfile):
             with self.open(idfile, "w", encoding="utf-8") as fClusterID:
                 fClusterID.write(
                     "{ClusterID}\n".format(
-                        ClusterID=self.grid_options["condor_ClusterID"]
+                        ClusterID=self.population_options["condor_ClusterID"]
                     )
                 )
                 fClusterID.close()
@@ -121,12 +121,11 @@ class condor:
         Get and return the condor status corresponing to the self object, or ClusterID.Process if they are passed in. If no status is found, returns an empty string..
         """
         if ClusterID is None:
-            ClusterID = self.grid_options["condor_ClusterID"]
+            ClusterID = self.population_options["condor_ClusterID"]
         if Process is None:
-            Process = self.grid_options["condor_Process"]
+            Process = self.population_options["condor_Process"]
         if ClusterID is None or Process is None:
             return None
-        # print("get_condor_status {}.{}".format(ClusterID,Process))
 
         try:
             path = pathlib.Path(
@@ -134,19 +133,14 @@ class condor:
                     condor_dir=condor_dir, ClusterID=ClusterID, Process=Process
                 )
             )
-            # print("path={}".format(path))
-            # print("size={}".format(path.stat().st_size))
             if path:
                 s = path.read_text().strip()
-                # print("contains {}".format(s))
                 return s
-            # print("path empty")
             return ""
 
         # NOTE: What is the actual exception that can occur here?
         # TODO: We should specify that exception
         except:
-            # print("read failed")
             return ""
 
     def condor_outfile(self, condor_dir=None):
@@ -155,7 +149,7 @@ class condor:
         """
         file = "{id}.gz".format(id=self.condorID())
         if condor_dir is None:
-            condor_dir = self.grid_options["condor_dir"]
+            condor_dir = self.population_options["condor_dir"]
         return os.path.abspath(os.path.join(condor_dir, "results", file))
 
     def make_condor_dirs(self, condor_dir=None):
@@ -165,10 +159,10 @@ class condor:
 
         # make the condor directories
         if condor_dir is None:
-            condor_dir = self.grid_options["condor_dir"]
+            condor_dir = self.population_options["condor_dir"]
         if not condor_dir:
-            print(
-                "You must set self.grid_options['condor_dir'] (or pass condor_dir=whatever to make_condor_dirs()) to a directory which we can use to set up binary_c-python's Condor files. This should be unique to your set of grids."
+            self.vb_error(
+                "You must set self.population_options['condor_dir'] (or pass condor_dir=whatever to make_condor_dirs()) to a directory which we can use to set up binary_c-python's Condor files. This should be unique to your set of grids."
             )
             os.exit()
 
@@ -188,7 +182,7 @@ class condor:
             # TODO: specify the actual exception
             # TODO: is this try-except necessary? Especially having the code fail here, instead of earlier, if the directories exist already. Otherwise we can also just do exist_ok=True?
             except:
-                print(
+                self.vb_error(
                     "Tried to make the directory {d} but it already exists. When you launch a set of binary_c jobs on Condor, you need to set your condor_dir to be a fresh directory with no contents.".format(
                         d=d
                     )
@@ -205,7 +199,7 @@ class condor:
             fail = False
             count += 1
             if count > count_warn:
-                print(
+                self.vb_warning(
                     "Warning: Have been waiting about {} seconds for Condor directories to be made, there seems to be significant delay...".format(
                         count
                     )
@@ -218,68 +212,68 @@ class condor:
 
     def condor_grid(self):  # pragma: no cover
         """
-        function to be called when running grids when grid_options['condor']>=1
+        function to be called when running grids when population_options['condor']>=1
 
-        if grid_options['condor']==1, we set up the condor script and launch the jobs, then return True to exit.
-        if grid_options['condor']==2, we run the stars, which means we return False to continue.
-        if grid_options['condor']==3, we are being called from the jobs to run the grids, return False to continue.
+        if population_options['condor']==1, we set up the condor script and launch the jobs, then return True to exit.
+        if population_options['condor']==2, we run the stars, which means we return False to continue.
+        if population_options['condor']==3, we are being called from the jobs to run the grids, return False to continue.
 
         TODO: split this function into some parts
         TODO: Comment this function better
         """
 
-        if self.grid_options["condor"] == 3:
+        if self.population_options["condor"] == 3:
             # joining : set the evolution type to "join"
             #
             # return False to continue
-            self.grid_options["evolution_type"] = "join"
+            self.population_options["evolution_type"] = "join"
             return False
 
-        if self.grid_options["condor"] == 2:
+        if self.population_options["condor"] == 2:
             # run a grid of stars only, leaving the results
             # in the appropriate outfile
             #
             # return False to actually run the stars
-            self.grid_options["evolution_type"] = "grid"
+            self.population_options["evolution_type"] = "grid"
             return False
 
-        if self.grid_options["condor"] == 1:
+        if self.population_options["condor"] == 1:
             # if condor=1,  we should have no evolution type, we
             # set up the Condor scripts and get them evolving
             # in a Condor queue
-            self.grid_options["evolution_type"] = None
+            self.population_options["evolution_type"] = None
 
             # make dirs
             self.make_condor_dirs()
 
             # check we're not using too much RAM
             if datasize.DataSize(
-                self.grid_options["condor_memory"]
-            ) > datasize.DataSize(self.grid_options["condor_warn_max_memory"]):
-                print(
+                self.population_options["condor_memory"]
+            ) > datasize.DataSize(self.population_options["condor_warn_max_memory"]):
+                self.vb_error(
                     "WARNING: you want to use {} MB of RAM : this is unlikely to be correct. If you believe it is, set condor_warn_max_memory to something very large (it is currently {} MB)\n".format(
-                        self.grid_options["condor_memory"],
-                        self.grid_options["condor_warn_max_memory"],
+                        self.population_options["condor_memory"],
+                        self.population_options["condor_warn_max_memory"],
                     )
                 )
                 self.exit(code=1)
 
             # get job id (might be passed in)
             ClusterID = (
-                self.grid_options["condor_ClusterID"]
-                if self.grid_options["condor_ClusterID"] != ""
+                self.population_options["condor_ClusterID"]
+                if self.population_options["condor_ClusterID"] != ""
                 else "$ClusterID"
             )
 
             # # get job array index
             # Process = (
-            #     self.grid_options["condor_Process"]
-            #     if self.grid_options["condor_Process"] != ""
+            #     self.population_options["condor_Process"]
+            #     if self.population_options["condor_Process"] != ""
             #     else "$Process"
             # )
 
-            if self.grid_options["condor_njobs"] == 0:
-                print(
+            if self.population_options["condor_njobs"] == 0:
+                self.vb_error(
                     "binary_c-python Condor : You must set grid_option condor_njobs to be non-zero"
                 )
                 self.exit(code=1)
@@ -288,24 +282,24 @@ class condor:
             pyscriptpath = str(lib_programname.get_path_executed_script())
 
             # set the condor initial dir to be our current working directory
-            if not self.grid_options["condor_initial_dir"]:
-                self.grid_options["condor_initial_dir"] = os.getcwd()
+            if not self.population_options["condor_initial_dir"]:
+                self.population_options["condor_initial_dir"] = os.getcwd()
 
             # build the grid command
             grid_command = (
                 [
-                    str(self.grid_options["condor_env"]),
+                    str(self.population_options["condor_env"]),
                     sys.executable,
                     pyscriptpath,
                 ]
                 + sys.argv[1:]
                 + [
                     "start_at=$Process",  # Process is 0,1,2... which is what we want
-                    "modulo=" + str(self.grid_options["condor_njobs"]),
-                    "condor_njobs=" + str(self.grid_options["condor_njobs"]),
-                    "condor_dir=" + self.grid_options["condor_dir"],
-                    "verbosity=" + str(self.grid_options["verbosity"]),
-                    "num_cores=" + str(self.grid_options["num_processes"]),
+                    "modulo=" + str(self.population_options["condor_njobs"]),
+                    "condor_njobs=" + str(self.population_options["condor_njobs"]),
+                    "condor_dir=" + self.population_options["condor_dir"],
+                    "verbosity=" + str(self.population_options["verbosity"]),
+                    "num_cores=" + str(self.population_options["_num_processes"]),
                 ]
             )
 
@@ -319,18 +313,19 @@ class condor:
             try:
                 submit_script = self.open(submit_script_path, "w", encoding="utf-8")
             except IOError:
-                print(
+                self.vb_error(
                     "Could not open Condor script at {path} for writing: please check you have set {condor_dir} correctly (it is currently {condor_dir} and can write to this directory.".format(
                         path=submit_script_path,
-                        condor_dir=self.grid_options["condor_dir"],
+                        condor_dir=self.population_options["condor_dir"],
                     )
                 )
             try:
                 job_script = self.open(job_script_path, "w", encoding="utf-8")
             except IOError:
-                print(
+                self.vb_error(
                     "Could not open Condor script at {path} for writing: please check you have set {condor_dir} correctly (it is currently {condor_dir} and can write to this directory.".format(
-                        path=job_script_path, condor_dir=self.grid_options["condor_dir"]
+                        path=job_script_path,
+                        condor_dir=self.population_options["condor_dir"],
                     )
                 )
 
@@ -360,21 +355,22 @@ echo \"running\" > "{condor_dir}/status/$ClusterID.$ProcessID"
 
 # run grid of stars and, if this returns 0, set status to finished
 {grid_command} "condor=2" "evolution_type=grid" "condor_ClusterID=$ClusterID" "condor_Process=$Process" "save_population_object={condor_dir}/results/$ClusterID.$Process.gz" && echo -n \"finished\" > "{condor_dir}/status/$ClusterID.$ProcessID" && echo """.format(
-                bash=self.grid_options["condor_bash"],
-                date=self.grid_options["condor_date"],
-                pwd=self.grid_options["condor_pwd"],
-                cmdline=repr(self.grid_options["command_line"]),
+                bash=self.population_options["condor_bash"],
+                date=self.population_options["condor_date"],
+                pwd=self.population_options["condor_pwd"],
+                cmdline=repr(self.population_options["command_line"]),
                 grid_command=grid_command,
-                condor_dir=self.grid_options["condor_dir"],
+                condor_dir=self.population_options["condor_dir"],
             )
 
-            if not self.grid_options["condor_postpone_join"]:
+            if not self.population_options["condor_postpone_join"]:
                 joinfile = "{condor_dir}/results/{ClusterID}.all".format(
-                    condor_dir=self.grid_options["condor_dir"], ClusterID=ClusterID
+                    condor_dir=self.population_options["condor_dir"],
+                    ClusterID=ClusterID,
                 )
                 condor_job_script += """&& echo \"Checking if we can join...\" && echo && {grid_command} "condor=3" "evolution_type=join" "joinlist={joinfile}" "condor_ClusterID=$ClusterID" "condor_Process=$Process"
                 """.format(
-                    # bash=self.grid_options["condor_bash"],
+                    # bash=self.population_options["condor_bash"],
                     grid_command=grid_command,
                     joinfile=joinfile,
                 )
@@ -385,11 +381,11 @@ echo \"running\" > "{condor_dir}/status/$ClusterID.$ProcessID"
                 # each job
                 ############################################################
                 extra_settings = ""
-                if self.grid_options["condor_extra_settings"]:
-                    for key in self.grid_options["condor_extra_settings"]:
+                if self.population_options["condor_extra_settings"]:
+                    for key in self.population_options["condor_extra_settings"]:
                         extra_settings += "{key} = {value}\n".format(
                             key=key,
-                            value=self.grid_options["condor_extra_settings"][key],
+                            value=self.population_options["condor_extra_settings"][key],
                         )
 
                 jobid = "$(Cluster).$(Process)"
@@ -414,36 +410,42 @@ kill_sig = {kill_sig}
 {extra_settings}
 queue {njobs}
             """.format(
-                    usr_bin_env=self.grid_options["condor_env"],
-                    bash=self.grid_options["condor_bash"],
+                    usr_bin_env=self.population_options["condor_env"],
+                    bash=self.population_options["condor_bash"],
                     job_script_path=job_script_path,
-                    universe=self.grid_options["condor_universe"],
-                    getenv=self.grid_options["condor_getenv"],
-                    initial_dir=self.grid_options["condor_initial_dir"],
+                    universe=self.population_options["condor_universe"],
+                    getenv=self.population_options["condor_getenv"],
+                    initial_dir=self.population_options["condor_initial_dir"],
                     outfile=os.path.abspath(
-                        os.path.join(self.grid_options["condor_dir"], "stdout", jobid)
+                        os.path.join(
+                            self.population_options["condor_dir"], "stdout", jobid
+                        )
                     ),
                     errfile=os.path.abspath(
-                        os.path.join(self.grid_options["condor_dir"], "stderr", jobid)
+                        os.path.join(
+                            self.population_options["condor_dir"], "stderr", jobid
+                        )
                     ),
                     logfile=os.path.abspath(
-                        os.path.join(self.grid_options["condor_dir"], "log", jobid)
+                        os.path.join(
+                            self.population_options["condor_dir"], "log", jobid
+                        )
                     ),
-                    stream_output=self.grid_options["condor_stream_output"],
-                    stream_error=self.grid_options["condor_stream_error"],
-                    request_memory=self.grid_options["condor_memory"],
-                    request_cpus=self.grid_options["num_processes"],
-                    should_transfer_files=self.grid_options[
+                    stream_output=self.population_options["condor_stream_output"],
+                    stream_error=self.population_options["condor_stream_error"],
+                    request_memory=self.population_options["condor_memory"],
+                    request_cpus=self.population_options["_num_processes"],
+                    should_transfer_files=self.population_options[
                         "condor_should_transfer_files"
                     ],
-                    when_to_transfer_output=self.grid_options[
+                    when_to_transfer_output=self.population_options[
                         "condor_when_to_transfer_output"
                     ],
-                    requirements=self.grid_options["condor_requirements"],
-                    batchname=self.grid_options["condor_batchname"],
-                    kill_sig=self.grid_options["condor_kill_sig"],
+                    requirements=self.population_options["condor_requirements"],
+                    batchname=self.population_options["condor_batchname"],
+                    kill_sig=self.population_options["condor_kill_sig"],
                     extra_settings=extra_settings,
-                    njobs=self.grid_options["condor_njobs"],
+                    njobs=self.population_options["condor_njobs"],
                 )
 
             # write the scripts, close them and make them executable by
@@ -466,9 +468,9 @@ queue {njobs}
                     | stat.S_IXOTH,
                 )
 
-            if not self.grid_options["condor_postpone_submit"]:
+            if not self.population_options["condor_postpone_submit"]:
                 # call sbatch to launch the condor jobs
-                cmd = [self.grid_options["condor_submit"], submit_script_path]
+                cmd = [self.population_options["condor_submit"], submit_script_path]
                 with subprocess.Popen(
                     cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE
                 ) as pipes:
@@ -485,7 +487,7 @@ queue {njobs}
                     raise Exception(err_msg)
 
                 if len(std_err) > 0:
-                    print(
+                    self.vb_info(
                         "{red}{err}{reset}".format(
                             red=self.ANSI_colours["red"],
                             reset=self.ANSI_colours["reset"],
@@ -493,7 +495,7 @@ queue {njobs}
                         )
                     )
 
-                print(
+                self.vb_info(
                     "{yellow}{out}{reset}".format(
                         yellow=self.ANSI_colours["yellow"],
                         reset=self.ANSI_colours["reset"],
@@ -502,22 +504,22 @@ queue {njobs}
                 )
             else:
                 # just say we would have (use this for testing)
-                print(
+                self.vb_info(
                     "Condor script is at {path} but has not been launched".format(
                         path=submit_script_path
                     )
                 )
 
         # some messages to the user, then return
-        if self.grid_options["condor_postpone_submit"] == 1:
-            print(
+        if self.population_options["condor_postpone_submit"] == 1:
+            self.vb_info(
                 "Condor script written, to {path}, but launching the jobs with sbatch was postponed.".format(
                     path=submit_script_path
                 )
             )
         else:
-            print("Condor jobs launched.")
-            print("All done in condor_grid().")
+            self.vb_info("Condor jobs launched.")
+            self.vb_info("All done in condor_grid().")
 
         # return True so we exit immediately
         return True
@@ -527,18 +529,18 @@ queue {njobs}
         Return condor queue statistics for this job
         """
 
-        _id = self.grid_options["condor_ClusterID"]
+        _id = self.population_options["condor_ClusterID"]
         if not _id:
             return None
 
         cmd = "{} {} 2>&1".format(
-            "/usr/bin/condor_q", _id  # self.grid_options["condor_q"],
+            "/usr/bin/condor_q", _id  # self.population_options["condor_q"],
         )
-        print("Q cmd", cmd)
+        self.vb_debug("Q cmd", cmd)
 
         with subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE) as subp:
             result = subp.stdout.read()
-        print("Q result ", result)
+        self.vb_debug("Q result ", result)
 
         if not result:
             return None
@@ -553,11 +555,11 @@ queue {njobs}
             "held",
             "suspended",
         ]:
-            print("Q x ", x)
+            self.vb_debug("Q x ", x)
             m = re.search("(\d+)\s+{}".format(x), result)  # noqa: W605
-            print("Q m ", m)
+            self.vb_debug("Q m ", m)
             if m:
                 d[x] = m.group(0)
 
-        print("Q d ", d)
+        self.vb_debug("Q d ", d)
         return d
