@@ -29,7 +29,7 @@ class custom_generator_sampling:
         Function to get the generator for the _custom_generator_sampling sampling method. Called by _get_generator and used in the actual evolution loop.
         """
 
-        generator = self.grid_options["custom_generator"]
+        generator = self.population_options["custom_generator"]
 
         return generator
 
@@ -38,10 +38,10 @@ class custom_generator_sampling:
         Function to prepare the class for sampling via a custom generator
         """
 
-        if not isinstance(self.grid_options["custom_generator"], Iterable):
-            print(
+        if not isinstance(self.population_options["custom_generator"], Iterable):
+            self.vb_error(
                 "Error. provided no or wrong custom value for the system generator (custom_generator: {})".format(
-                    self.grid_options["custom_generator"]
+                    self.population_options["custom_generator"]
                 )
             )
             raise ValueError
