@@ -20,7 +20,7 @@ import msgpack
 
 from binarycpython.utils.dicts import merge_dicts
 from binarycpython.utils.ensemble import ensemble_file_type
-from binarycpython.utils.functions import now, verbose_print
+from binarycpython.utils.functions import now
 
 
 class dataIO:
@@ -50,11 +50,11 @@ class dataIO:
         compression="gzip",
     ):
         """
-        Save pickled Population object to file at filename or, if filename is None, whatever is set at self.grid_options['save_population_object']
+        Save pickled Population object to file at filename or, if filename is None, whatever is set at self.population_options['save_population_object']
 
         Args:
             population_object : the object to be saved to the file. If population_object is None, use self.
-            filename : the name of the file to be saved. If not set, use self.grid_options['save_population_object']
+            filename : the name of the file to be saved. If not set, use self.population_options['save_population_object']
             confirmation : if True, a file "filename.saved" is touched just after the dump, so we know it is finished. TODO: fix this
             compression (optional, default = "gzip"): TODO: fix this
 
@@ -73,13 +73,13 @@ class dataIO:
 
         if filename is None:
             # get filename from self
-            filename = self.grid_options["save_population_object"]
+            filename = self.population_options["save_population_object"]
 
         if filename:
-            print(
+            self.vb_info(
                 "Save population {id}, probtot {probtot} to pickle in {filename}".format(
-                    id=self.grid_options["_population_id"],
-                    probtot=population_object.grid_options["_probtot"],
+                    id=self.population_options["_population_id"],
+                    probtot=population_object.population_options["_probtot"],
                     filename=filename,
                 )
             )
@@ -92,12 +92,12 @@ class dataIO:
             population_object.shared_memory = None
 
             # delete system generator
-            system_generator = population_object.grid_options["_system_generator"]
-            population_object.grid_options["_system_generator"] = None
+            system_generator = population_object.population_options["_system_generator"]
+            population_object.population_options["_system_generator"] = None
 
             # delete _store_memaddr
-            _store_memaddr = population_object.grid_options["_store_memaddr"]
-            population_object.grid_options["_store_memaddr"] = None
+            _store_memaddr = population_object.population_options["_store_memaddr"]
+            population_object.population_options["_store_memaddr"] = None
 
             # delete persistent_data_memory_dict
             persistent_data_memory_dict = population_object.persistent_data_memory_dict
@@ -121,7 +121,7 @@ class dataIO:
                     "max_memory_use"
                 ] = copy.deepcopy(sum(shared_memory["max_memory_use_per_thread"]))
             except Exception as e:
-                print("save_population_object : Error: ", e)
+                self.vb_error("save_population_object : Error: ", e)
                 raise Exception(e) from e
 
             # dump pickle file
@@ -129,11 +129,11 @@ class dataIO:
 
             # restore data
             population_object.shared_memory = shared_memory
-            population_object.grid_options["_system_generator"] = system_generator
+            population_object.population_options["_system_generator"] = system_generator
             del population_object.grid_ensemble_results["metadata"][
                 "save_population_time"
             ]
-            population_object.grid_options["store_memaddr"] = _store_memaddr
+            population_object.population_options["store_memaddr"] = _store_memaddr
             population_object.persistent_data_memory_dict = persistent_data_memory_dict
 
             self.NFS_flush_hack(filename)
@@ -155,7 +155,9 @@ class dataIO:
                 obj = compress_pickle.load(filename, pickler_method="dill")
             except Exception as e:
                 obj = None
-                print("Loading of the compressed object went wrong: {}".format(e))
+                self.vb_error(
+                    "Loading of the compressed object went wrong: {}".format(e)
+                )
         return obj
 
     def merge_populations(self, refpop, newpop):
@@ -174,7 +176,9 @@ class dataIO:
         """
 
         # combine data
-        refpop.grid_results = merge_dicts(refpop.grid_results, newpop.grid_results)
+        refpop.population_results = merge_dicts(
+            refpop.population_results, newpop.population_results
+        )
 
         # special cases
         maxmem = 0
@@ -213,13 +217,13 @@ class dataIO:
             refpop.grid_ensemble_results["metadata"]["max_memory_use"] = maxmem
 
         except Exception as e:
-            print("Error merging grid_ensemble_results:", e)
+            self.vb_error("Error merging grid_ensemble_results:", e)
             raise Exception(e) from e
 
         for key in ["_probtot"]:
-            refpop.grid_options[key] += newpop.grid_options[key]
+            refpop.population_options[key] += newpop.population_options[key]
 
-        refpop.grid_options["_killed"] |= newpop.grid_options["_killed"]
+        refpop.population_options["_killed"] |= newpop.population_options["_killed"]
 
     def merge_populations_from_file(self, refpop, filename):
         """
@@ -236,7 +240,7 @@ class dataIO:
 
         mtime = time.localtime(os.path.getmtime(filename))
         modtime = time.strftime("%a, %d %b %Y %H:%M:%S", mtime)
-        print(
+        self.vb_debug(
             "Load data from {filename} : size {size}, modtime {modtime}".format(
                 filename=filename,
                 size=os.path.getsize(filename),
@@ -246,10 +250,10 @@ class dataIO:
 
         newpop = self.load_population_object(filename)
 
-        if "total_count" in newpop.grid_options:
-            n = newpop.grid_options["total_count"]
-        elif "_count" in newpop.grid_options:
-            n = newpop.grid_options["_count"]
+        if "total_count" in newpop.population_options:
+            n = newpop.population_options["total_count"]
+        elif "_count" in newpop.population_options:
+            n = newpop.population_options["_count"]
         elif (
             "metadata" in newpop.grid_ensemble_results
             and "_count" in newpop.grid_ensemble_results["metadata"]
@@ -258,7 +262,7 @@ class dataIO:
         else:
             n = -1
 
-        print("Loaded data from {n} stars".format(n=n))
+        self.vb_info("Loaded data from {n} stars".format(n=n))
 
         # merge with refpop
         self.merge_populations(refpop, newpop)
@@ -270,7 +274,7 @@ class dataIO:
         if self.HPC_job():
             return self.HPC_snapshot_filename()
 
-        file = os.path.join(self.grid_options["tmp_dir"], "snapshot.gz")
+        file = os.path.join(self.population_options["tmp_dir"], "snapshot.gz")
         return file
 
     def load_snapshot(self, file):
@@ -280,19 +284,19 @@ class dataIO:
         newpop = self.load_population_object(file)
 
         # unset the _killed flag, in case it was set
-        newpop.grid_options["_killed"] = False
+        newpop.population_options["_killed"] = False
 
         # set in preloaded_population for later  merge
         self.preloaded_population = newpop
 
         # set the start position for new stars
-        self.grid_options["start_at"] = newpop.grid_options["start_at"]
+        self.population_options["start_at"] = newpop.population_options["start_at"]
 
-        print(
+        self.vb_info(
             "Loaded from snapshot at {file} : {nstars} stars, start at star {nstart}".format(
                 file=file,
-                nstars=0,  # self.grid_options[''],
-                nstart=self.grid_options["start_at"],
+                nstars=0,  # self.population_options[''],
+                nstart=self.population_options["start_at"],
             )
         )
         return
@@ -304,13 +308,13 @@ class dataIO:
         if file is None:
             file = self.snapshot_filename()
 
-        if "_count" in self.grid_options:
-            n = self.grid_options["_count"]
+        if "_count" in self.population_options:
+            n = self.population_options["_count"]
         else:
             n = "?"
 
-        print("Saving snapshot containing {} stars to {}".format(n, file))
-        self.save_population_object(object=self, filename=file)
+        self.vb_info("Saving snapshot containing {} stars to {}".format(n, file))
+        self.save_population_object(population_object=self, filename=file)
 
     def write_ensemble(
         self,
@@ -359,7 +363,7 @@ class dataIO:
             data = self.grid_ensemble_results
 
         if not file_type:
-            print(
+            self.vb_error(
                 "Unable to determine file type from ensemble filename {} : it should be .json or .msgpack.".format(
                     output_file
                 )
@@ -387,7 +391,7 @@ class dataIO:
 
             f.close()
 
-        print(
+        self.vb_info(
             "Thread {thread}: Wrote ensemble results to file: {colour}{file}{reset} (file type {file_type})".format(
                 thread=self.process_ID,
                 file=output_file,
@@ -425,22 +429,20 @@ class dataIO:
         """
 
         # Check if there is no compiled grid yet. If not, lets try to build it first.
-        if not self.grid_options["_system_generator"]:
+        if not self.population_options["_system_generator"]:
 
             ## check the settings:
             if self.bse_options.get("ensemble", None):
                 if self.bse_options["ensemble"] == 1:
                     if not self.bse_options.get("ensemble_defer", 0) == 1:
-                        verbose_print(
+                        self.vb_error(
                             "Error, if you want to run an ensemble in a population, the output needs to be deferred",
-                            self.grid_options["verbosity"],
-                            0,
                         )
                         raise ValueError
 
             # Put in check
-            if len(self.grid_options["_sampling_variables"]) == 0:
-                print("Error: you haven't defined any grid variables! Aborting")
+            if len(self.population_options["_sampling_variables"]) == 0:
+                self.vb_error("Error: you haven't defined any grid variables! Aborting")
                 raise ValueError
 
             #
@@ -450,14 +452,14 @@ class dataIO:
             self._load_grid_function()
 
         # then if the _system_generator is present, we go through it
-        if self.grid_options["_system_generator"]:
+        if self.population_options["_system_generator"]:
             # Check if there is an output dir configured
             if self.custom_options.get("data_dir", None):
                 binary_c_calls_output_dir = self.custom_options["data_dir"]
                 # otherwise check if there's one passed to the function
             else:
                 if not output_dir:
-                    print(
+                    self.vb_error(
                         "Error. No data_dir configured and you gave no output_dir. Aborting"
                     )
                     raise ValueError
@@ -473,7 +475,9 @@ class dataIO:
             binary_c_calls_full_filename = os.path.join(
                 binary_c_calls_output_dir, binary_c_calls_filename
             )
-            print("Writing binary_c calls to {}".format(binary_c_calls_full_filename))
+            self.vb_info(
+                "Writing binary_c calls to {}".format(binary_c_calls_full_filename)
+            )
 
             # Write to file
             with self.open(
@@ -488,14 +492,14 @@ class dataIO:
                 else:
                     full_system_dict = self.bse_options.copy()
 
-                for system in self.grid_options["_system_generator"](self):
+                for system in self.population_options["_system_generator"](self):
                     # update values with current system values
                     full_system_dict.update(system)
 
                     binary_cmdline_string = self._return_argline(full_system_dict)
                     file.write(binary_cmdline_string + "\n")
         else:
-            print("Error. No grid function found!")
+            self.vb_error("Error. No grid function found!")
             raise ValueError
 
         return binary_c_calls_full_filename
@@ -508,9 +512,9 @@ class dataIO:
         if ID is None:
             ID = self.process_ID
 
-        if self.grid_options["status_dir"]:
+        if self.population_options["status_dir"]:
             path = os.path.join(
-                self.grid_options["status_dir"],
+                self.population_options["status_dir"],
                 format_statment.format(ID),
             )
             with self.open(path, "w", encoding="utf-8") as f:
@@ -587,89 +591,76 @@ class dataIO:
         """
 
         if exists_ok is False and os.path.isfile(filename):
-            if vb:
-                print("File at {} already exists: cannot write to it".format(filename))
+            self.vb_warning(
+                "File at {} already exists: cannot write to it".format(filename)
+            )
             return (None, None)
 
         # set the lockfile path: this should be the same
         # for all processes, so it's just the original file
         # plus the lock_suffix
         lockfilename = filename + lock_suffix
-        if vb:
-            print("lockfile={}".format(lockfilename))
+        self.vb_info("lockfile={}".format(lockfilename))
 
         while True:
             # if the file exists, just return
             if os.path.isfile(lockfilename):
-                if vb:
-                    print(
-                        "lockfile at {} already exists (corresponding to file at {})".format(
-                            lockfilename, filename
-                        )
+                self.vb_warning(
+                    "lockfile at {} already exists (corresponding to file at {})".format(
+                        lockfilename, filename
                     )
+                )
                 return (None, None)
 
             # make the lock object by opening the lockfile
             lock = flufl.lock.Lock(lockfilename, default_timeout=lock_timeout)
-            if vb:
-                print("post-lock: {}".format(lock))
+            self.vb_info("post-lock: {}".format(lock))
 
             if lock:
                 # we have the lockfile, so set the lifetime and try to lock it
                 lock.lifetime = datetime.timedelta(seconds=lock_lifetime)
                 try:
-                    if vb:
-                        print("try to lock {}".format(lock))
+                    self.vb_info("try to lock {}".format(lock))
                     lock.lock()
-                    if vb:
-                        if lock.is_locked:
-                            print("locked {}".format(lock))
-                        else:
-                            print("failed to lock {}".format(lock))
+                    if lock.is_locked:
+                        self.vb_info("locked {}".format(lock))
+                    else:
+                        self.vb_info("failed to lock {}".format(lock))
                 except:
                     pass
 
                 # if we acquired the lock, try to open the file
                 if lock.is_locked:
-                    if vb:
-                        print(
-                            "{} is locked by {} to {}".format(
-                                filename, lock, lockfilename
-                            )
-                        )
+                    self.vb_info(
+                        "{} is locked by {} to {}".format(filename, lock, lockfilename)
+                    )
 
                     if exists_ok is False and os.path.isfile(filename):
-                        if vb:
-                            print(
-                                "File at {} already exists (2): cannot write to it, unlocking and returning (None,None)".format(
-                                    filename
-                                )
+                        self.vb_warning(
+                            "File at {} already exists (2): cannot write to it, unlocking and returning (None,None)".format(
+                                filename
                             )
+                        )
                         lock.unlock()
                         return (None, None)
 
                     # All is apparently ok: file is locked
                     try:
-                        if vb:
-                            print("Try to open file at {}".format(filename))
+                        self.vb_info("Try to open file at {}".format(filename))
                         f = self.open(filename, mode="w", encoding=encoding, **kwargs)
-                        if vb:
-                            print("Return locked file {}, {}".format(f, lock))
+                        self.vb_info("Return locked file {}, {}".format(f, lock))
                         return (f, lock)
 
                     # error on open should be fatal
                     except Exception as e:
-                        print("Error in locked_open_for_write() : {}".format(e))
+                        self.vb_error("Error in locked_open_for_write() : {}".format(e))
                         if fatal_open_errors:
-                            if vb:
-                                print("fatal exit on open")
+                            self.vb_error("fatal exit on open")
                             self.exit(1)
                         else:
-                            if vb:
-                                print("unlock {}".format(lock))
+                            self.vb_info("unlock {}".format(lock))
                             lock.unlock()
-                            if vb:
-                                print("unlocked {} return None,None".format(lock))
+                            self.vb_info("unlocked {} return None,None".format(lock))
                             return (None, None)
 
             # failed to lock this time, keep trying
@@ -723,15 +714,14 @@ class dataIO:
         if compression is None:
             compression = self.compression_type(file)
 
-        if vb:
-            print(
-                'open() file at "{file}" with mode = {mode}, compression {compression}, compresslevel {compresslevel}'.format(
-                    file=file,
-                    compression=compression,
-                    compresslevel=compresslevel,
-                    mode=mode,
-                )
+        self.vb_info(
+            'open() file at "{file}" with mode = {mode}, compression {compression}, compresslevel {compresslevel}'.format(
+                file=file,
+                compression=compression,
+                compresslevel=compresslevel,
+                mode=mode,
             )
+        )
 
         if compression:
             if compresslevel is None:
@@ -741,14 +731,12 @@ class dataIO:
                 # defaults to binary, which isn't compatible with JSON,
                 # so default to text if not specified otherwise
                 mode += "t"
-                if vb:
-                    print("open() adding text mode")
+                self.vb_debug("open() adding text mode")
             else:
                 encoding = None
                 errors = None
                 newline = None
-                if vb:
-                    print("open() setting encoding=errors=newline=None")
+                self.vb_debug("open() setting encoding=errors=newline=None")
             if compression == "bzip2":
                 file_object = bz2.open(
                     file,
@@ -779,8 +767,7 @@ class dataIO:
                 opener=opener,
             )
 
-        if vb:
-            print("open() return file_object =", file_object)
+        self.vb_debug("open() return file_object = {}".format(file_object))
         return file_object
 
     def NFSpath(self, path):
