@@ -14,6 +14,32 @@ _count = 0  # used for file symlinking (for testing only)
 _numba = False  # activate experimental numba code?
 
 
+###########################
+# Some context managers
+class indentation_context_manager:
+    def __init__(self, population_object, indentation_delta=1):
+        self.population_object = population_object
+        self.indentation_delta = indentation_delta
+
+    def __enter__(self):
+        self.population_object._increment_indent_depth(+self.indentation_delta)
+
+    def __exit__(self, exc, value, exc_traceback):
+        self.population_object._increment_indent_depth(-self.indentation_delta)
+
+
+class boxed_context_manager:
+    def __init__(self, population_object, width_box=40):
+        self.population_object = population_object
+        self.width_box = width_box
+
+    def __enter__(self):
+        self.population_object._add_code("#" * self.width_box + "\n")
+
+    def __exit__(self, exc, value, exc_traceback):
+        self.population_object._add_code("#" * self.width_box + "\n")
+
+
 class grid_sampling:
     """
     Extension to the population grid object that contains functionality to handle the metadata that will be put in the ensemble
@@ -41,7 +67,9 @@ class grid_sampling:
 
         # load generator
         self._load_grid_function()
-        generator = self.grid_options["_system_generator"](self, print_results=False)
+        generator = self.population_options["_system_generator"](
+            self, print_results=False
+        )
 
         return generator
 
@@ -57,14 +85,14 @@ class grid_sampling:
         # Dry run and getting starcount
         ############################################################
         # Put in check
-        if len(self.grid_options["_sampling_variables"]) == 0:
-            print("Error: you haven't defined any grid variables! Aborting")
+        if len(self.population_options["_sampling_variables"]) == 0:
+            self.vb_error("Error: you haven't defined any grid variables! Aborting")
             raise ValueError
 
         # Set up the grid code with a dry run option to see total probability
-        print("Do dry run? {}".format(self.grid_options["do_dry_run"]))
-        if self.grid_options["do_dry_run"]:
-            print("Doing dry run to calculate total starcount and probability")
+        self.vb_info("Do dry run? {}".format(self.population_options["do_dry_run"]))
+        if self.population_options["do_dry_run"]:
+            self.vb_info("Doing dry run to calculate total starcount and probability")
             self._generate_grid_code(dry_run=True)
 
             # Load the grid code
@@ -73,37 +101,36 @@ class grid_sampling:
             # Do a dry run
             self._dry_run()
 
-            self.verbose_print(
-                self._boxed(
+            self.vb_critical(
+                "\n"
+                + self._boxed(
                     "Dry run",
                     "Total starcount is {starcount}".format(
-                        starcount=self.grid_options["_total_starcount"]
+                        starcount=self.population_options["_total_starcount"]
                     ),
                     "Total probability is {probtot:g}".format(
-                        probtot=self.grid_options["_probtot"]
+                        probtot=self.population_options["_probtot"]
                     ),
                 ),
-                self.grid_options["verbosity"],
-                0,
             )
-            if self.grid_options["exit_after_dry_run"]:
-                print(
+            if self.population_options["exit_after_dry_run"]:
+                self.vb_info(
                     "Exiting after dry run {}".format(
-                        self.grid_options["exit_after_dry_run"]
+                        self.population_options["exit_after_dry_run"]
                     )
                 )
                 self.exit(code=0)
-            elif self.grid_options["return_after_dry_run"]:
-                print(
+            elif self.population_options["return_after_dry_run"]:
+                self.vb_info(
                     "Returning after dry run {}".format(
-                        self.grid_options["exit_after_dry_run"]
+                        self.population_options["exit_after_dry_run"]
                     )
                 )
                 return False
 
         #######################
         # Reset values and prepare the grid function
-        self.grid_options[
+        self.population_options[
             "_probtot"
         ] = 0  # To make sure that the values are reset. TODO: fix this in a cleaner way
 
@@ -114,7 +141,7 @@ class grid_sampling:
         # self._load_grid_function()
 
         #
-        self.grid_options["_system_generator"] = None
+        self.population_options["_system_generator"] = None
 
     ###################################################
     # Grid code functions
@@ -128,17 +155,17 @@ class grid_sampling:
         """
         if self.HPC_job():
             filename = os.path.join(
-                self.grid_options["tmp_dir"],
+                self.population_options["tmp_dir"],
                 "binary_c_grid_{population_id}.{jobid}.py".format(
-                    population_id=self.grid_options["_population_id"],
+                    population_id=self.population_options["_population_id"],
                     jobid=self.jobID(),
                 ),
             )
         else:
             filename = os.path.join(
-                self.grid_options["tmp_dir"],
+                self.population_options["tmp_dir"],
                 "binary_c_grid_{population_id}.py".format(
-                    population_id=self.grid_options["_population_id"]
+                    population_id=self.population_options["_population_id"]
                 ),
             )
         return filename
@@ -182,49 +209,96 @@ class grid_sampling:
 
         Results in a generated file that contains a system_generator function.
 
-        # TODO: make sure running systems with multiplicity 3+ is also possible.
-        # TODO: there is a lot of things going on in this function. Make sure to describe clearly what happens here.
+        NOTE: this function is large and has many moving parts.
+            Broadly it constructs a nested dictionary with yield calls at different depths (if they are branch points)
+
+        TODO: make sure running systems with multiplicity 3+ is also possible.
+        TODO: there is a lot of things going on in this function. Make sure to describe clearly what happens here.
+        TODO: this code could very much benefit from context managers that handle indent and dedents
         """
-        self.verbose_print("Generating grid code", self.grid_options["verbosity"], 1)
 
-        total_sampling_variables = len(self.grid_options["_sampling_variables"])
+        self.vb_info("Generating grid code")
 
+        # turn vb to True to have debugging output
+        vb = False
+
+        ######################################
+        # First part:
+        #   The code below generats the import statements, and sets up the function.
+        self._grid_sampling_write_grid_generator_function_start()
+
+        #################################################################################
+        # Nested loop generation
+        #################################################################################
+        self._add_code("\n")
+
+        ######################################
+        # Second part:
+        #   The code below generates the nested structure of the sampling variables
+        #       calls to the distribution functions and the calculation of the probabilities.
+        #   This part does *not* generate the yield statements
+        self._grid_sampling_write_grid_generator_function_nesting(
+            dry_run=dry_run, vb=vb
+        )
+
+        self._add_code("\n")
+
+        ######################################
+        # Third part:
+        #   The code below generates the yield calls and handles the branch points at different nest levels.
+        #   The order is reverse, and it starts at the deepest nesting.
+        self._grid_sampling_write_grid_generator_function_denesting(dry_run=dry_run)
+
+        ######################################
+        # Fourth part:
+        #   The code below wraps up the function and writes statements that handle returning information and some statistics.
+        self._grid_sampling_write_grid_generator_function_end(dry_run=dry_run)
+
+    def _grid_sampling_write_grid_generator_function_start(self):
+        """
+        This function is responsible for setting up the file, handling the imports and writing the beginning of the function, initialising parameters etc.
+        """
+
+        total_sampling_variables = len(self.population_options["_sampling_variables"])
+
+        ###############
+        # Import packages
         self._add_code(
-            # Import packages
             "import math\n",
             "import numpy as np\n",
             "from collections import OrderedDict\n",
             "from binarycpython.utils.useful_funcs import *\n",
             "import numba" if _numba else "",
             "\n\n",
-            # Make the function
-            "def grid_code(self, print_results=True):\n",
         )
 
+        ###############
+        # Define the function
+        self._add_code("def grid_code(self, print_results=True):\n")
+
         # Increase indent_depth
         self._increment_indent_depth(+1)
 
+        ###############
+        # Write comments at docstring
         self._add_code(
-            # Write some info in the function
             "# Grid code generated on {}\n".format(datetime.datetime.now().isoformat()),
-            "# This function generates the systems that will be evolved with binary_c\n\n"
-            # Set some values in the generated code:
+            "# This function generates the systems that will be evolved with binary_c\n\n",
+        )
+
+        ###############
+        # Initialise parameters, lists and dictionaries
+        self._add_code(
             "# Set initial values\n",
             "_total_starcount = 0\n",
             "starcounts = [0 for i in range({})]\n".format(
                 total_sampling_variables + 1
             ),
-            "probabilities = {}\n",
-            "probabilities_list = [0 for i in range({})]\n".format(
-                total_sampling_variables + 1
-            ),
-            "probabilities_sum = [0 for i in range({})]\n".format(
-                total_sampling_variables + 1
-            ),
             "parameter_dict = {}\n",
             "phasevol = 1\n",
         )
 
+        ###############
         # Set up the system parameters
         self._add_code(
             "M_1 = None\n",
@@ -235,15 +309,28 @@ class grid_sampling:
             "orbital_period_triple = None\n",
             "orbital_period_quadruple = None\n",
             "eccentricity = None\n",
-            "eccentricity2 = None\n",
-            "eccentricity3 = None\n",
+            "eccentricity_triple = None\n",
+            "eccentricity_quadruple = None\n",
             "\n",
-            # Prepare the probability
-            "# set probability lists\n",
         )
 
+        ###############
+        # Set up probability lists, dicts
+        self._add_code(
+            # Prepare the probability
+            "# set probability objects\n",
+            "probabilities = {}\n",
+            "probabilities_list = [0 for i in range({})]\n".format(
+                total_sampling_variables + 1
+            ),
+            "probabilities_sum = [0 for i in range({})]\n".format(
+                total_sampling_variables + 1
+            ),
+        )
+
+        # Fill the probability dictionary with zeroes
         for sampling_variable_el in sorted(
-            self.grid_options["_sampling_variables"].items(),
+            self.population_options["_sampling_variables"].items(),
             key=lambda x: x[1]["sampling_variable_number"],
         ):
             # Make probabilities dict
@@ -252,25 +339,22 @@ class grid_sampling:
                 'probabilities["{}"] = 0\n'.format(sampling_variable["name"])
             )
 
-        #################################################################################
-        # Start of code generation
-        #################################################################################
-        self._add_code("\n")
-
-        # turn vb to True to have debugging output
-        vb = False
+    def _grid_sampling_write_grid_generator_function_nesting(self, dry_run, vb):
+        """
+        This function generates the nested structure of the grid code generator.
+        Sets up the calculation of the sampling variables, calls to the distribution functions
+        and the calculation of the probabilities.
+        """
 
         # Generate code
         for loopnr, sampling_variable_el in enumerate(
             sorted(
-                self.grid_options["_sampling_variables"].items(),
+                self.population_options["_sampling_variables"].items(),
                 key=lambda x: x[1]["sampling_variable_number"],
             )
         ):
-            self.verbose_print(
+            self.vb_debug(
                 "Constructing/adding: {}".format(sampling_variable_el[0]),
-                self.grid_options["verbosity"],
-                2,
             )
             sampling_variable = sampling_variable_el[1]
 
@@ -586,7 +670,7 @@ class grid_sampling:
                 )
 
                 # Add condition failed action:
-                if self.grid_options["verbosity"] >= 4:
+                if self.population_options["verbosity"] >= 4:
                     self._add_code(
                         'print("Grid generator: Condition for {name} not met!")'.format(
                             name=sampling_variable["name"]
@@ -619,6 +703,7 @@ class grid_sampling:
                     + "\n"
                 )
 
+            #########################
             # Set phasevol
             self._add_code(
                 "phasevol *= dphasevol_{name}\n".format(
@@ -662,7 +747,7 @@ class grid_sampling:
                     + "\n"
                 )
 
-            ##############
+            #########################
             # postcode
             if sampling_variable["postcode"]:
                 self._add_code(
@@ -674,7 +759,7 @@ class grid_sampling:
                     + "\n"
                 )
 
-            #######################
+            #########################
             # Increment starcount for this parameter
             self._add_code(
                 "\n",
@@ -693,37 +778,31 @@ class grid_sampling:
                 "\n",
             )
 
-            self._increment_indent_depth(-1)
-
-            # The final parts of the code, where things are returned, are within the deepest loop,
-            # but in some cases code from a higher loop needs to go under it again
-            # SO I think its better to put an if statement here that checks
-            # whether this is the last loop.
-            if loopnr == len(self.grid_options["_sampling_variables"]) - 1:
+            #########################
+            # Construct system call
+            #   The final parts of the code, where things are returned, are within the deepest loop,
+            #   but in some cases code from a higher loop needs to go under it again
+            #   SO I think its better to put an if statement here that checks
+            #   whether this is the last loop.
+            if loopnr == len(self.population_options["_sampling_variables"]) - 1:
                 self._write_gridcode_system_call(
                     sampling_variable,
                     dry_run,
-                    sampling_variable["branchpoint"],
-                    sampling_variable["branchcode"],
                 )
 
-            # increment indent_depth
-            self._increment_indent_depth(+1)
-
             ####################
             # bottom code
             if sampling_variable["bottomcode"]:
                 self._add_code(sampling_variable["bottomcode"])
 
-        self._increment_indent_depth(-1)
-        self._add_code("\n")
+    def _grid_sampling_write_grid_generator_function_denesting(self, dry_run):
+        """
+        The code below generates the yield calls and handles the branch points at different nest levels.
+        The order is reverse, and it starts at the deepest nesting.
+        """
 
-        # Write parts to write below the part that yield the results.
-        # this has to go in a reverse order:
-        # Here comes the stuff that is put after the deepest nested part that calls returns stuff.
-        # Here we will have a
         reverse_sorted_sampling_variables = sorted(
-            self.grid_options["_sampling_variables"].items(),
+            self.population_options["_sampling_variables"].items(),
             key=lambda x: x[1]["sampling_variable_number"],
             reverse=True,
         )
@@ -732,15 +811,24 @@ class grid_sampling:
         ):
             sampling_variable = sampling_variable_el[1]
 
-            self._increment_indent_depth(+1)
             self._add_code(
                 "#" * 40 + "\n",
-                "# Code below is for finalising the handling of this iteration of the parameter {name}\n".format(
+                "# Code below is for finalising the handling of this iteration of the parameter {name}\n\n".format(
                     name=sampling_variable["name"]
                 ),
             )
 
-            # Set phasevol
+            ################
+            # Check the branchpoint part here. The branchpoint makes sure that we can construct
+            # a grid with several multiplicities and still can make the system calls for each
+            # multiplicity without reconstructing the grid each time
+            self._grid_sampling_handle_branchpoint(
+                sampling_variable=sampling_variable, dry_run=dry_run, loopnr=loopnr
+            )
+
+            #############
+            # Unset phasevol
+            #   This happens in the same loop as the actual variable
             # TODO: fix. this isn't supposed to be the value that we give it here. discuss
             self._add_code(
                 "phasevol /= dphasevol_{name}\n\n".format(
@@ -748,96 +836,70 @@ class grid_sampling:
                 )
             )
 
-            self._increment_indent_depth(-2)
-
             if _numba and sampling_variable["dry_parallel"]:
                 self._add_code("__parallel_func(phasevol,_total_starcount)\n")
                 self._increment_indent_depth(-1)
 
-            # Check the branchpoint part here. The branchpoint makes sure that we can construct
-            # a grid with several multiplicities and still can make the system calls for each
-            # multiplicity without reconstructing the grid each time
-            if sampling_variable["branchpoint"] > 0:
+            # Decrement level
+            self._increment_indent_depth(-1)
 
-                self._increment_indent_depth(+1)
-
-                self._add_code(
-                    # Add comment
-                    "# Condition for branchpoint at {}".format(
-                        reverse_sorted_sampling_variables[loopnr + 1][1]["name"]
-                    )
-                    + "\n",
-                    # # Add condition check
-                    #     "if not {}:".format(sampling_variable["condition"])
-                    #     + "\n"
-                    # Add branchpoint
-                    "if multiplicity=={}:".format(sampling_variable["branchpoint"])
-                    + "\n",
-                )
-
-                self._write_gridcode_system_call(
-                    reverse_sorted_sampling_variables[loopnr + 1][1],
-                    dry_run,
-                    sampling_variable["branchpoint"],
-                    sampling_variable["branchcode"],
-                )
-                self._increment_indent_depth(-1)
-                self._add_code("\n")
+    def _grid_sampling_write_grid_generator_function_end(self, dry_run):
+        """
+        This function is responsible for wrapping up the grid code generator. It wraps up the function, writes statements
+        """
 
         ###############################
         # Finalise print statements
         #
-        self._increment_indent_depth(+1)
         self._add_code("\n", "#" * 40 + "\n", "if print_results:\n")
         self._add_code(
-            "print('Grid has handled {starcount} stars with a total probability of {probtot:g}'.format(starcount=_total_starcount,probtot=self.grid_options['_probtot']))\n",
+            "print('Grid has handled {starcount} stars with a total probability of {probtot:g}'.format(starcount=_total_starcount,probtot=self.population_options['_probtot']))\n",
             indent=1,
         )
 
-        ################
         # Finalise return statement for dry run.
-        #
         if dry_run:
             self._add_code("return _total_starcount\n")
 
-        self._increment_indent_depth(-1)
         #################################################################################
-        # Stop of code generation. Here the code is saved and written
+        # Stop of code generation.
+        #   Here the code is saved and written
 
-        # Save the grid code to the grid_options
-        self.verbose_print(
-            "Save grid code to grid_options", self.grid_options["verbosity"], 1
+        #########
+        # Save the grid code to the population_options
+        self.vb_info(
+            "Save grid code to population_options",
         )
 
-        self.grid_options["code_string"] = self.code_string
+        self.population_options["code_string"] = self.code_string
 
         # Write to file
         gridcode_filename = self._gridcode_filename()
 
-        self.grid_options["gridcode_filename"] = gridcode_filename
+        self.population_options["gridcode_filename"] = gridcode_filename
 
-        self.verbose_print(
+        self.vb_error(
             "{blue}Write grid code to {file} [dry_run = {dry}]{reset}".format(
                 blue=self.ANSI_colours["blue"],
                 file=gridcode_filename,
                 dry=dry_run,
                 reset=self.ANSI_colours["reset"],
             ),
-            self.grid_options["verbosity"],
-            1,
         )
 
+        # Write code
         with self.open(gridcode_filename, "w", encoding="utf-8") as file:
             file.write(self.code_string)
 
         # reset the code string
         self.code_string = ""
+        self.indent_depth = 0
 
         # perhaps create symlink
-        if not self.HPC_job() and self.grid_options["symlink_latest_gridcode"]:
+        if not self.HPC_job() and self.population_options["symlink_latest_gridcode"]:
             global _count
             symlink = os.path.join(
-                self.grid_options["tmp_dir"], "binary_c_grid-latest" + str(_count)
+                self.population_options["tmp_dir"], "binary_c_grid-latest" + str(_count)
             )
             _count += 1
             try:
@@ -847,99 +909,133 @@ class grid_sampling:
 
             try:
                 os.symlink(gridcode_filename, symlink)
-                self.verbose_print(
+                self.vb_info(
                     "{blue}Symlinked grid code to {symlink} {reset}".format(
                         blue=self.ANSI_colours["blue"],
                         symlink=symlink,
                         reset=self.ANSI_colours["reset"],
                     ),
-                    self.grid_options["verbosity"],
-                    1,
                 )
             except OSError:
-                print("symlink failed")
+                self.vb_error("symlink failed")
 
-    def _write_gridcode_system_call(
-        self, sampling_variable, dry_run, branchpoint, branchcode
-    ):
+    def _grid_sampling_handle_branchpoint(self, sampling_variable, dry_run, loopnr):
+        """
+        Function to handle the branch point
+        """
+
+        # Check if there is a branchpoint and that this is not the deepest loop
+        if (sampling_variable["branchpoint"]) and (loopnr > 0):
+            ###########################
+            # Handle branch point
+            if sampling_variable["branchcode"]:
+                with boxed_context_manager(population_object=self):
+                    self._add_code("# Branch code\n")
+                    self._add_code(
+                        "if {branchcode}:\n".format(
+                            branchcode=sampling_variable["branchcode"]
+                        )
+                    )
+
+                    ###########################
+                    # Indent and write the grid system call
+                    with indentation_context_manager(population_object=self):
+                        ###########################
+                        # Handle system call
+                        self._write_gridcode_system_call(
+                            sampling_variable,
+                            dry_run,
+                        )
+
+                        self._add_code("\n")
+            else:
+                raise ValueError("Handling branch point but no branchcode provided")
+
+            #
+            self._add_code("\n")
+
+    def _write_gridcode_system_call(self, sampling_variable, dry_run):
         """
         Function to write the block of code (as string) that handles the setting the final probability, taking into account the weight and repeat settings, incrementing the total starcount and total probability.
 
         Then if the run is a dry run we implement the dry_run_hook or pass depending on the settings. If it is not a dry run we yield the system dict
         """
 
-        self._increment_indent_depth(+1)
-        self._add_code("#" * 40 + "\n")
-
-        if branchcode:
+        with boxed_context_manager(population_object=self):
             self._add_code(
-                "# Branch code\nif {branchcode}:\n".format(branchcode=branchcode)
-            )
-
-        if branchpoint:
-            self._add_code(
-                "# Code below will get evaluated for every system at this level of multiplicity (last one of that being {name})\n".format(
-                    name=sampling_variable["name"]
+                "# grid sampling system call section ({})\n\n".format(
+                    sampling_variable["name"]
                 )
             )
-        else:
+
+            ##################
+            # Write the code that handles the probability calculation
+
+            #########
+            # Weight probability by custom weight factor
             self._add_code(
-                "# Code below will get evaluated for every generated system\n"
+                "# Weigh the probability by a custom weighting factor\n",
+                'probability = self.population_options["weight"] * probabilities_list[{n}]\n'.format(
+                    n=sampling_variable["sampling_variable_number"]
+                ),
             )
 
-        # Factor in the custom weight input
-        self._add_code(
-            "\n",
-            "# Weigh the probability by a custom weighting factor\n",
-            'probability = self.grid_options["weight"] * probabilities_list[{n}]'.format(
-                n=sampling_variable["sampling_variable_number"]
-            )
-            + "\n",
+            #########
             # Take into account the multiplicity fraction:
-            "\n",
-            "# Factor the multiplicity fraction into the probability\n",
-            "probability *= self._calculate_multiplicity_fraction(parameter_dict)"
-            + "\n",
+            self._add_code(
+                "\n",
+                "# Factor the multiplicity fraction into the probability\n",
+                "probability *= self._calculate_multiplicity_fraction(parameter_dict)\n",
+            )
+
+            #########
             # Divide by number of repeats
-            "\n",
-            "# Divide the probability by the number of repeats\n",
-            'probability /= self.grid_options["repeat"]' + "\n",
-            # Now we yield the system self.grid_options["repeat"] times.
-            "\n",
-            "# Loop over the repeats\n",
-            'for _ in range(self.grid_options["repeat"]):' + "\n",
-        )
-        self._add_code(
-            "_total_starcount += 1\n",
-            # set probability and phasevol values into the system dict
-            'parameter_dict["{p}"] = {p}'.format(p="probability") + "\n",
-            'parameter_dict["{v}"] = {v}'.format(v="phasevol") + "\n",
-            # Increment total probability
-            "self._increment_probtot(probability)\n",
-            indent=1,
-        )
+            self._add_code(
+                "\n",
+                "# Divide the probability by the number of repeats\n",
+                'probability /= self.population_options["repeat"]\n',
+            )
 
-        if not dry_run:
-            # Handle what is returned, or what is not.
-            self._add_code("yield(parameter_dict)\n", indent=1)
+            #########
+            # Now we yield the system self.population_options["repeat"] times.
+            self._add_code(
+                "\n",
+                "# Loop over the repeats\n",
+                'for _ in range(self.population_options["repeat"]):\n',
+            )
+            with indentation_context_manager(population_object=self):
+                #########
+                # Increment starcount
+                self._add_code("_total_starcount += 1\n")
 
-        # If its a dry run, dont do anything with it
-        else:
-            # run the hook function, only if given
-            if self.grid_options["dry_run_hook"]:
+                #########
+                # set probability and phasevol values into the system dict
                 self._add_code(
-                    "self.grid_options['dry_run_hook'](self, parameter_dict)\n",
-                    indent=1,
+                    'parameter_dict["{p}"] = {p}'.format(p="probability") + "\n",
+                    'parameter_dict["{v}"] = {v}'.format(v="phasevol") + "\n",
                 )
+
+                #########
+                # Increment total probability
+                self._add_code(
+                    "self._increment_probtot(probability)\n",
+                )
+
+            #########
+            # Handle dry run or actual call
+            if not dry_run:
+                # Handle what is returned, or what is not.
+                self._add_code("yield(parameter_dict)\n", indent=1)
             else:
-                # or pass
-                self._add_code("pass\n", indent=1)
-
-        self._add_code("#" * 40 + "\n")
-
-        self._increment_indent_depth(-1)
-
-        return self.code_string
+                # run the hook function, only if given
+                if self.population_options["dry_run_hook"]:
+                    self._add_code(
+                        "self.population_options['dry_run_hook'](self, parameter_dict)\n",
+                        indent=1,
+                    )
+                else:
+                    # or pass
+                    self._add_code("pass\n", indent=1)
 
     def _load_grid_function(self):
         """
@@ -947,22 +1043,20 @@ class grid_sampling:
         """
 
         # Code to load the
-        self.verbose_print(
+        self.vb_info(
             message="Load grid code function from {file}".format(
-                file=self.grid_options["gridcode_filename"]
+                file=self.population_options["gridcode_filename"]
             ),
-            verbosity=self.grid_options["verbosity"],
-            minimal_verbosity=1,
         )
 
         spec = importlib.util.spec_from_file_location(
             "binary_c_python_grid",
-            os.path.join(self.grid_options["gridcode_filename"]),
+            os.path.join(self.population_options["gridcode_filename"]),
         )
         grid_file = importlib.util.module_from_spec(spec)
         spec.loader.exec_module(grid_file)
         generator = grid_file.grid_code
 
-        self.grid_options["_system_generator"] = generator
+        self.population_options["_system_generator"] = generator
 
-        self.verbose_print("Grid code loaded", self.grid_options["verbosity"], 1)
+        self.vb_info("Grid code loaded")
