@@ -68,21 +68,21 @@ class metadata:
 
     def add_ensemble_metadata(self, combined_output_dict):
         """
-        Function to add metadata to the grid_ensemble_results and grid_options
+        Function to add metadata to the grid_ensemble_results and population_options
         """
 
         self.grid_ensemble_results["metadata"] = {}
 
-        self.grid_ensemble_results["metadata"]["population_id"] = self.grid_options[
-            "_population_id"
-        ]
+        self.grid_ensemble_results["metadata"][
+            "population_id"
+        ] = self.population_options["_population_id"]
         self.grid_ensemble_results["metadata"][
             "total_probability_weighted_mass"
         ] = combined_output_dict["_total_probability_weighted_mass_run"]
         self.grid_ensemble_results["metadata"][
             "factored_in_probability_weighted_mass"
         ] = False
-        if self.grid_options["ensemble_factor_in_probability_weighted_mass"]:
+        if self.population_options["ensemble_factor_in_probability_weighted_mass"]:
             multiply_values_dict(
                 self.grid_ensemble_results["ensemble"],
                 1.0
@@ -93,7 +93,9 @@ class metadata:
             self.grid_ensemble_results["metadata"][
                 "factored_in_probability_weighted_mass"
             ] = True
-        self.grid_ensemble_results["metadata"]["_killed"] = self.grid_options["_killed"]
+        self.grid_ensemble_results["metadata"]["_killed"] = self.population_options[
+            "_killed"
+        ]
 
         # Add settings of the populations
         all_info = self.return_all_info(
@@ -109,8 +111,8 @@ class metadata:
         ##############################
         # Update grid options
         for x in self._metadata_keylist():
-            self.grid_options[x] = combined_output_dict[x]
-        self.grid_options["_failed_systems_error_codes"] = list(
+            self.population_options[x] = combined_output_dict[x]
+        self.population_options["_failed_systems_error_codes"] = list(
             set(combined_output_dict["_failed_systems_error_codes"])
         )
 
