@@ -36,8 +36,9 @@ class monte_carlo_sampling:
         Cleanup function for the Monte-Carlo sampling evolution type
         """
 
-        self.grid_options["_monte_carlo_threshold_reached"] = False
-        self.grid_options["_monte_carlo_current_total_mass_evolved"] = 0
+        self.population_options["_monte_carlo_threshold_reached"] = False
+        self.population_options["_monte_carlo_current_total_mass_evolved"] = 0
+        self.population_options["_monte_carlo_current_total_count_evolved"] = 0
 
     def _monte_carlo_sampling_check_mass_threshold(self, system_dict):
         """
@@ -45,28 +46,50 @@ class monte_carlo_sampling:
         """
 
         # Only if the monte_carlo_mass_threshold is positive (default = -1)
-        if self.grid_options["monte_carlo_mass_threshold"] > 0:
+        if self.population_options["monte_carlo_mass_threshold"] > 0:
 
             # Add total mass of current system tot total mass evolved
-            self.grid_options[
+            self.population_options[
                 "_monte_carlo_current_total_mass_evolved"
             ] += calculate_total_mass_system(system_dict)
 
             # Check if exceeds threshold
             if (
-                self.grid_options["_monte_carlo_current_total_mass_evolved"]
-                > self.grid_options["monte_carlo_mass_threshold"]
+                self.population_options["_monte_carlo_current_total_mass_evolved"]
+                > self.population_options["monte_carlo_mass_threshold"]
             ):
-                self.grid_options["_monte_carlo_threshold_reached"] = True
+                self.population_options["_monte_carlo_threshold_reached"] = True
+
+    def _monte_carlo_sampling_check_count_threshold(self):
+        """
+        Function to handle checking the total count evolved and signal to stop
+        """
+
+        # Only if the monte_carlo_count_threshold is positive (default = -1)
+        if self.population_options["monte_carlo_count_threshold"] > 0:
+
+            # Add total mass of current system tot total count evolved
+            self.population_options["_monte_carlo_current_total_count_evolved"] += 1
+
+            # Check if exceeds threshold
+            if (
+                self.population_options["_monte_carlo_current_total_count_evolved"]
+                > self.population_options["monte_carlo_count_threshold"]
+            ):
+                self.population_options["_monte_carlo_threshold_reached"] = True
 
     def _monte_carlo_sampling_check_custom_threshold(self, result_queue):
         """
         Function to handle checking the content of the result queue and look for a
-        TODO: put in the user-defined custom threshold function
+
+        The user-defined function has access to the result_queue and is responsible for processing (and emptying it)
         """
 
-        # raise NotImplementedError("Functionality in not implemented")
-        pass
+        # Pass output of binary_c to a user-defined parsing function
+        if self.population_options["monte_carlo_custom_threshold_function"]:
+            self.population_options["monte_carlo_custom_threshold_function"](
+                self, result_queue
+            )
 
     ##############
     # Generator functions
@@ -74,22 +97,25 @@ class monte_carlo_sampling:
     # Management
     def _monte_carlo_sampling_get_generator_filename(self):
         """
-        Returns a filename for the gridcode.
+        Returns a filename of the generator file for the monte-carlo sampling
+
+        Returns:
+            filename (str): filename of the generator file for the monte-carlo sampling.
         """
 
         if self.HPC_job():
             filename = os.path.join(
-                self.grid_options["tmp_dir"],
+                self.population_options["tmp_dir"],
                 "binary_c_monte_carlo_sampling_generator_{population_id}.{jobid}.py".format(
-                    population_id=self.grid_options["_population_id"],
+                    population_id=self.population_options["_population_id"],
                     jobid=self.jobID(),
                 ),
             )
         else:
             filename = os.path.join(
-                self.grid_options["tmp_dir"],
+                self.population_options["tmp_dir"],
                 "binary_c_monte_carlo_sampling_generator_{population_id}.py".format(
-                    population_id=self.grid_options["_population_id"]
+                    population_id=self.population_options["_population_id"]
                 ),
             )
         return filename
@@ -99,6 +125,9 @@ class monte_carlo_sampling:
         Function to write the function that can generate the sample for the parameter
 
         Contrary to the grid sampling variable generator code, this code is not nested, but is linear.
+
+        Args:
+            dry_run (bool, optional): flag to build with dry-run functionality.
         """
 
         #########
@@ -131,7 +160,7 @@ class monte_carlo_sampling:
         )
 
         # Add method for the pre-calculation of the arrays
-        if self.grid_options["monte_carlo_use_pre_calculated_distributions"]:
+        if self.population_options["monte_carlo_use_pre_calculated_distributions"]:
             self._add_code("self.handle_pre_calc(self)\n")
 
         #########
@@ -152,7 +181,7 @@ class monte_carlo_sampling:
         # Run loop of sampling variable setup
         for loopnr, sampling_variable_el in enumerate(
             sorted(
-                self.grid_options["_sampling_variables"].items(),
+                self.population_options["_sampling_variables"].items(),
                 key=lambda x: x[1]["sampling_variable_number"],
             )
         ):
@@ -177,18 +206,16 @@ class monte_carlo_sampling:
             self._monte_carlo_sampling_get_generator_filename()
         )
 
-        self.grid_options[
+        self.population_options[
             "_monte_carlo_sampling_generator_filename"
         ] = monte_carlo_sampling_generator_filename
 
-        self.verbose_print(
+        self.vb_info(
             "{blue}Write grid code to {file} {reset}".format(
                 blue=self.ANSI_colours["blue"],
                 file=monte_carlo_sampling_generator_filename,
                 reset=self.ANSI_colours["reset"],
             ),
-            self.grid_options["verbosity"],
-            1,
         )
 
         with self.open(
@@ -220,7 +247,7 @@ class monte_carlo_sampling:
             self._add_code(
                 "\n",
                 "# Loop over the repeats\n",
-                'for _ in range(self.grid_options["repeat"]):' + "\n",
+                'for _ in range(self.population_options["repeat"]):' + "\n",
             )
             self._add_code(
                 "_total_starcount += 1\n",
@@ -234,9 +261,9 @@ class monte_carlo_sampling:
             # If its a dry run, dont do anything with it
             else:
                 # run the hook function, only if given
-                if self.grid_options["dry_run_hook"]:
+                if self.population_options["dry_run_hook"]:
                     self._add_code(
-                        "self.grid_options['dry_run_hook'](self, system_dict)\n\n",
+                        "self.population_options['dry_run_hook'](self, system_dict)\n\n",
                         indent=1,
                     )
                 else:
@@ -252,10 +279,8 @@ class monte_carlo_sampling:
         Function to write the parameter lines and the pre and postcode around it to the monte carlo sampling generator function.
         """
 
-        self.verbose_print(
+        self.vb_debug(
             "Constructing/adding: {}".format(sampling_variable["parameter_name"]),
-            self.grid_options["verbosity"],
-            2,
         )
 
         ####################
@@ -264,12 +289,10 @@ class monte_carlo_sampling:
             comment_line, "# Sampling variable {}\n\n".format(sampling_variable["name"])
         )
 
-        self.verbose_print(
+        self.vb_debug(
             "Writing sampling variable {} to monte-carlo sampling generator".format(
                 sampling_variable["parameter_name"]
             ),
-            self.grid_options["verbosity"],
-            1,
         )
 
         ####################
@@ -323,8 +346,9 @@ class monte_carlo_sampling:
         """
 
         filename = os.path.join(
+            self.population_options["tmp_dir"],
             "binary_c_monte_carlo_sampling_sampling_functions_{population_id}.py".format(
-                population_id=self.grid_options["_population_id"]
+                population_id=self.population_options["_population_id"]
             ),
         )
 
@@ -336,21 +360,21 @@ class monte_carlo_sampling:
         """
 
         # Code to load the generator code
-        self.verbose_print(
+        self.vb_debug(
             message="Load monte-carlo sampling functions from {file}".format(
-                file=self.grid_options[
+                file=self.population_options[
                     "_monte_carlo_sampling_sampling_functions_filename"
                 ]
             ),
-            verbosity=self.grid_options["verbosity"],
-            minimal_verbosity=1,
         )
 
         # Load the module from file and the functions in it.
         spec = importlib.util.spec_from_file_location(
             "binary_c_python_monte_carlo_sampling_functions",
             os.path.join(
-                self.grid_options["_monte_carlo_sampling_sampling_functions_filename"]
+                self.population_options[
+                    "_monte_carlo_sampling_sampling_functions_filename"
+                ]
             ),
         )
         monte_carlo_sampling_functions_file = importlib.util.module_from_spec(spec)
@@ -381,7 +405,7 @@ class monte_carlo_sampling:
                     obj.replace("calc_pdf_cdf_value_array_dict_", "")
                 ] = getattr(monte_carlo_sampling_functions_file, obj)
 
-        # Load handler function
+        # Load calc_sampled_value handler function
         for obj in dir(monte_carlo_sampling_functions_file):
             if obj.startswith("handle_calc_sampled_value"):
                 self.handle_calc_sampled_value = getattr(
@@ -389,15 +413,18 @@ class monte_carlo_sampling:
                 )
                 break
 
-        # Load handler function
-        for obj in dir(monte_carlo_sampling_functions_file):
-            if obj.startswith("handle_pre_calc"):
-                self.handle_pre_calc = getattr(monte_carlo_sampling_functions_file, obj)
-                # setattr(self, obj, getattr(monte_carlo_sampling_functions_file, obj))
-                # MethodType(func, obj)
-                # MethodType(getattr(monte_carlo_sampling_functions_file, obj), self)
+        # Load pre_calc handler function
+        if self.population_options["monte_carlo_use_pre_calculated_distributions"]:
+            for obj in dir(monte_carlo_sampling_functions_file):
+                if obj.startswith("handle_pre_calc"):
+                    self.handle_pre_calc = getattr(
+                        monte_carlo_sampling_functions_file, obj
+                    )
+                    # setattr(self, obj, getattr(monte_carlo_sampling_functions_file, obj))
+                    # MethodType(func, obj)
+                    # MethodType(getattr(monte_carlo_sampling_functions_file, obj), self)
 
-                break
+                    break
 
     def _monte_carlo_sampling_write_sampling_functions_file(self, dry_run=False):
         """
@@ -420,7 +447,7 @@ class monte_carlo_sampling:
         # Write functions to calculate the values for each parameter.
         for loopnr, sampling_variable_el in enumerate(
             sorted(
-                self.grid_options["_sampling_variables"].items(),
+                self.population_options["_sampling_variables"].items(),
                 key=lambda x: x[1]["sampling_variable_number"],
             )
         ):
@@ -441,7 +468,7 @@ class monte_carlo_sampling:
 
             ######################
             # Call to function to write the pre_calc_sample_value function
-            if self.grid_options["monte_carlo_use_pre_calculated_distributions"]:
+            if self.population_options["monte_carlo_use_pre_calculated_distributions"]:
                 self._monte_carlo_sampling_write_pre_calc_function(sampling_variable)
 
         ######################
@@ -450,7 +477,7 @@ class monte_carlo_sampling:
 
         ######################
         # Call to function to write the handle_pre_calc function and other functions
-        if self.grid_options["monte_carlo_use_pre_calculated_distributions"]:
+        if self.population_options["monte_carlo_use_pre_calculated_distributions"]:
             self._monte_carlo_sampling_write_handle_pre_calc_function()
 
             self._monte_carlo_sampling_write_bin_function()
@@ -463,18 +490,16 @@ class monte_carlo_sampling:
             self._monte_carlo_sampling_get_sampling_functions_filename()
         )
 
-        self.grid_options[
+        self.population_options[
             "_monte_carlo_sampling_sampling_functions_filename"
         ] = monte_carlo_sampling_sampling_functions_filename
 
-        self.verbose_print(
+        self.vb_debug(
             "{blue}Write sampling functions code to {file} {reset}".format(
                 blue=self.ANSI_colours["blue"],
                 file=monte_carlo_sampling_sampling_functions_filename,
                 reset=self.ANSI_colours["reset"],
             ),
-            self.grid_options["verbosity"],
-            1,
         )
 
         with self.open(
@@ -570,12 +595,20 @@ class monte_carlo_sampling:
         Function to write the bin function
         """
 
+        # self._add_code(
+        #     comment_line,
+        #     "def bin(parameter_value_array, parameter_value):\n",
+        #     "    index = np.digitize(parameter_value, bins=parameter_value_array, right=False)-1\n",
+        #     "    center_value = (parameter_value_array[index+1]+parameter_value_array[index])/2\n",
+        #     "    return center_value\n",
+        # )
+
         self._add_code(
             comment_line,
             "def bin(parameter_value_array, parameter_value):\n",
             "    index = np.digitize(parameter_value, bins=parameter_value_array, right=False)-1\n",
-            "    center_value = (parameter_value_array[index+1]+parameter_value_array[index])/2\n",
-            "    return center_value\n",
+            "    binned_value = parameter_value_array[index+1]\n",
+            "    return binned_value\n",
         )
 
     def _monte_carlo_sampling_write_center_function(self):
@@ -613,7 +646,7 @@ class monte_carlo_sampling:
         # Loop over variables and call them to set the pre-calculated pdf cdf information in the dictionary
         for loopnr, sampling_variable_el in enumerate(
             sorted(
-                self.grid_options["_sampling_variables"].items(),
+                self.population_options["_sampling_variables"].items(),
                 key=lambda x: x[1]["sampling_variable_number"],
             )
         ):
@@ -664,7 +697,7 @@ class monte_carlo_sampling:
         # Call to pdf_cdf_value_array_dict function
         self._add_code(
             comment_line,
-            "if self.grid_options['monte_carlo_use_pre_calculated_distributions']:\n",
+            "if self.population_options['monte_carlo_use_pre_calculated_distributions']:\n",
         )
 
         ######
@@ -676,15 +709,15 @@ class monte_carlo_sampling:
                     dependency_variable
                 )
 
-                if self.grid_options["_sampling_variables_parameter_names"][
+                if self.population_options["_sampling_variables_parameter_names"][
                     dependency_variable
                 ]["dependency_variables"]:
                     for depth in range(
                         0,
                         len(
-                            self.grid_options["_sampling_variables_parameter_names"][
-                                dependency_variable
-                            ]["dependency_variables"]
+                            self.population_options[
+                                "_sampling_variables_parameter_names"
+                            ][dependency_variable]["dependency_variables"]
                         ),
                     ):
                         string += "['{{:.6f}}'.format(binned_{})]".format(
@@ -891,7 +924,7 @@ class monte_carlo_sampling:
 
             sampling_variable_dict_based_on_parameter_name = {
                 sampling_variable_el["parameter_name"]: sampling_variable_el
-                for sampling_variable_el in self.grid_options[
+                for sampling_variable_el in self.population_options[
                     "_sampling_variables"
                 ].values()
             }
@@ -935,9 +968,10 @@ class monte_carlo_sampling:
 
                 #######
                 # Set up loop for sampling the distribution function
+                # NOTE: previously there was a center statement here (for {} in center(value_array_{})). Not sure why i did that. I removed it now.
                 self._add_code(
                     comment_line,
-                    "for {} in center(value_array_{}):\n\n".format(
+                    "for {} in value_array_{}:\n\n".format(
                         dependency_variable["name"], dependency_variable["name"]
                     ),
                 )
@@ -1017,7 +1051,7 @@ class monte_carlo_sampling:
 
         ##############
         # If we choose to use no multiplicity fraction function then we always return multiplicity of 1
-        if self.grid_options["multiplicity_fraction_function"] in [0, "None"]:
+        if self.population_options["multiplicity_fraction_function"] in [0, "None"]:
             return 1
 
         # Otherwise we will get the multiplicity fraction dict sample a random value to determine which multiplicty we have
@@ -1052,36 +1086,45 @@ class monte_carlo_sampling:
         """
 
         # Code to load the generator code
-        self.verbose_print(
+        self.vb_info(
             message="Load monte-carlo generator function from {file}".format(
-                file=self.grid_options["_monte_carlo_sampling_generator_filename"]
+                file=self.population_options["_monte_carlo_sampling_generator_filename"]
             ),
-            verbosity=self.grid_options["verbosity"],
-            minimal_verbosity=1,
         )
 
         spec = importlib.util.spec_from_file_location(
             "binary_c_python_monte_carlo_sampling_generator",
-            os.path.join(self.grid_options["_monte_carlo_sampling_generator_filename"]),
+            os.path.join(
+                self.population_options["_monte_carlo_sampling_generator_filename"]
+            ),
         )
         monte_carlo_sampling_generator_file = importlib.util.module_from_spec(spec)
         spec.loader.exec_module(monte_carlo_sampling_generator_file)
         generator = monte_carlo_sampling_generator_file.monte_carlo_generator
 
-        self.grid_options["_monte_carlo_sampling_generator"] = generator
+        self.population_options["_monte_carlo_sampling_generator"] = generator
 
-        self.verbose_print("Grid code loaded", self.grid_options["verbosity"], 1)
-
-        # raise NotImplementedError("This functionality is not available yet")
+        self.vb_info("Monte-carlo system generator")
 
     def _monte_carlo_sampling_setup(self):
         """
         Function to prepate the class for a monte-carlo sampling simulation
         """
 
-        print("setup mc sampling")
+        self.vb_info("setup mc sampling")
 
-        # raise NotImplementedError("This functionality is not available yet")
+        # Put in check
+        if len(self.population_options["_sampling_variables"]) == 0:
+            msg = "Error: you haven't defined any sampling variables! Aborting"
+            raise ValueError(msg)
+
+        # Make a dictionary with the names of the sampling variables
+        self.population_options["_sampling_variables_parameter_names"] = {
+            sampling_variable[1]["parameter_name"]: sampling_variable[1]
+            for sampling_variable in self.population_options[
+                "_sampling_variables"
+            ].items()
+        }
 
     def _monte_carlo_sampling_get_generator(self):
         """
@@ -1101,7 +1144,7 @@ class monte_carlo_sampling:
         self._monte_carlo_sampling_load_generator()
 
         # Get generator file
-        generator = self.grid_options["_monte_carlo_sampling_generator"](
+        generator = self.population_options["_monte_carlo_sampling_generator"](
             self, print_results=False
         )
 
@@ -1124,7 +1167,7 @@ class monte_carlo_sampling:
         # Start up the generator
         generator = self._get_generator()
 
-        if not self.grid_options["monte_carlo_mass_threshold"] > 0:
+        if not self.population_options["monte_carlo_mass_threshold"] > 0:
             raise ValueError("Cant write MC sampling to file without a mass threshold")
 
         # then if the _system_generator is present, we go through it
@@ -1146,7 +1189,7 @@ class monte_carlo_sampling:
 
                     ######
                     # Handle monte-carlo threshold based on evolved mass
-                    if self.grid_options["evolution_type"] == "monte_carlo":
+                    if self.population_options["evolution_type"] == "monte_carlo":
                         # Check based on mass threshold
                         self._monte_carlo_sampling_check_mass_threshold(
                             full_system_dict
@@ -1154,14 +1197,14 @@ class monte_carlo_sampling:
 
                         ######
                         # Check if evolution threshold is reached.
-                        if self.grid_options["_monte_carlo_threshold_reached"]:
+                        if self.population_options["_monte_carlo_threshold_reached"]:
                             break
 
                     #
                     binary_cmdline_string = self._return_argline(full_system_dict)
                     file.write(binary_cmdline_string + "\n")
         else:
-            print("Error. No grid function found!")
+            self.vb_error("Error. No grid function found!")
             raise ValueError
 
         return output_file
