@@ -5,6 +5,7 @@ Main script to provide the sampling variable class extension. Here the sampling
 # pylint: disable=E1101
 import json
 from typing import Union
+from warnings import warn
 
 
 class sampling_variables:
@@ -26,19 +27,21 @@ class sampling_variables:
         """
 
         # Get total number of sampling variables
-        number = len(self.grid_options["_sampling_variables"])
+        number = len(self.population_options["_sampling_variables"])
 
         # Get dictionary of grid variable numbers
         # RGI: broken?
-        #sampling_variable_dict = {
+        # sampling_variable_dict = {
         #    sampling_variable["sampling_variable_number"]: sampling_variable
-        #    for sampling_variable in self.grid_options["_sampling_variables"]
-        #}
+        #    for sampling_variable in self.population_options["_sampling_variables"]
+        # }
 
         # Get dictionary of grid variable numbers
         sampling_variable_dict = {
-            self.grid_options['_sampling_variables'][sampling_variable]["sampling_variable_number"]: sampling_variable
-            for sampling_variable in self.grid_options["_sampling_variables"]
+            self.population_options["_sampling_variables"][sampling_variable][
+                "sampling_variable_number"
+            ]: sampling_variable
+            for sampling_variable in self.population_options["_sampling_variables"]
         }
 
         #
@@ -55,18 +58,16 @@ class sampling_variables:
                 key-value pairs to override the existing grid variable data. See add_sampling_variable for these names.
         """
 
-        if name in self.grid_options["_sampling_variables"]:
-            sampling_variable = self.grid_options["_sampling_variables"][name]
+        if name in self.population_options["_sampling_variables"]:
+            sampling_variable = self.population_options["_sampling_variables"][name]
 
             # Set the value and print
             for key, value in kwargs.items():
                 sampling_variable[key] = value
-                self.verbose_print(
+                self.vb_info(
                     "Updated grid variable: {}".format(
                         json.dumps(sampling_variable, indent=4, ensure_ascii=False)
                     ),
-                    self.grid_options["verbosity"],
-                    1,
                 )
         else:
             msg = "Unknown sampling variable {} - please create it with the add_sampling_variable() method.".format(
@@ -86,12 +87,10 @@ class sampling_variables:
                 name of the sampling variable to be deleted.
         """
 
-        if name in self.grid_options["_sampling_variables"]:
-            del self.grid_options["_sampling_variables"][name]
-            self.verbose_print(
+        if name in self.population_options["_sampling_variables"]:
+            del self.population_options["_sampling_variables"][name]
+            self.vb_info(
                 "Deleted sampling variable: {}".format(name),
-                self.grid_options["verbosity"],
-                1,
             )
         else:
             msg = (
@@ -106,7 +105,7 @@ class sampling_variables:
         Function to rename a sampling variable.
 
         note: this does NOT alter the order
-        of the self.grid_options["_sampling_variables"] dictionary.
+        of the self.population_options["_sampling_variables"] dictionary.
 
         The order in which the sampling variables are loaded into the grid is based on their
         `sampling_variable_number` property
@@ -118,15 +117,13 @@ class sampling_variables:
                 new name of the sampling variable
         """
 
-        if oldname in self.grid_options["_sampling_variables"]:
-            self.grid_options["_sampling_variables"][newname] = self.grid_options[
-                "_sampling_variables"
-            ].pop(oldname)
-            self.grid_options["_sampling_variables"][newname]["name"] = newname
-            self.verbose_print(
+        if oldname in self.population_options["_sampling_variables"]:
+            self.population_options["_sampling_variables"][
+                newname
+            ] = self.population_options["_sampling_variables"].pop(oldname)
+            self.population_options["_sampling_variables"][newname]["name"] = newname
+            self.vb_info(
                 "Rename sampling variable: {} to {}".format(oldname, newname),
-                self.grid_options["verbosity"],
-                1,
             )
         else:
             msg = "Failed to rename sampling variable {} to {}.".format(
@@ -155,7 +152,7 @@ class sampling_variables:
         dependency_variables: Union[list, None] = None,
     ) -> None:
         """
-        Function to add sampling variables to the grid_options.
+        Function to add sampling variables to the population_options.
 
         The execution of the sampling generation will be through a nested for loop.
         Each of the grid variables will get create a deeper for loop.
@@ -239,7 +236,7 @@ class sampling_variables:
 
                 Examples::
 
-                    condition = "self.grid_options['binary']==1"
+                    condition = "self.population_options['binary']==1"
 
             gridtype:
                 Method on how the value range is sampled. Can be either 'edge' (steps starting at
@@ -262,7 +259,7 @@ class sampling_variables:
         # check parameters
         # if False and dphasevol != -1.0 and gridtype == "discrete":
         if dphasevol != -1.0 and gridtype == "discrete":
-            print(
+            self.vb_error(
                 "Error making grid: you have set the phasevol to be not -1 and gridtype to discrete, but a discrete grid has no phasevol calculation. You should only set the gridtype to discrete and not set the phasevol in this case."
             )
 
@@ -285,7 +282,9 @@ class sampling_variables:
             "branchcode": branchcode,
             "topcode": topcode,
             "bottomcode": bottomcode,
-            "sampling_variable_number": len(self.grid_options["_sampling_variables"]),
+            "sampling_variable_number": len(
+                self.population_options["_sampling_variables"]
+            ),
             "dry_parallel": dry_parallel,
             "dependency_variables": dependency_variables,
         }
@@ -309,17 +308,15 @@ class sampling_variables:
             ) + ",".join(allowed_gridtypes)
             raise ValueError(msg)
 
-        # Load it into the grid_options
-        self.grid_options["_sampling_variables"][
+        # Load it into the population_options
+        self.population_options["_sampling_variables"][
             sampling_variable["name"]
         ] = sampling_variable
 
-        self.verbose_print(
+        self.vb_error(
             "Added sampling variable: {}".format(
                 json.dumps(sampling_variable, indent=4, ensure_ascii=False)
             ),
-            self.grid_options["verbosity"],
-            2,
         )
 
     ######################################################################
@@ -372,7 +369,7 @@ class sampling_variables:
         Function to rename a sampling variable. Calls rename_sampling_variable()
 
         note: this does NOT alter the order
-        of the self.grid_options["_sampling_variables"] dictionary.
+        of the self.population_options["_sampling_variables"] dictionary.
 
         The order in which the sampling variables are loaded into the grid is based on their
         `sampling_variable_number` property
@@ -408,7 +405,7 @@ class sampling_variables:
         """
         NOTE: this function exists for backward compatability with older scripts. Please use add_sampling_variable from now on.
 
-        Function to add sampling variables to the grid_options. Calls add_sampling_variable().
+        Function to add sampling variables to the population_options. Calls add_sampling_variable().
 
         The execution of the sampling generation will be through a nested for loop.
         Each of the grid variables will get create a deeper for loop.
@@ -492,7 +489,7 @@ class sampling_variables:
 
                 Examples::
 
-                    condition = "self.grid_options['binary']==1"
+                    condition = "self.population_options['binary']==1"
 
             gridtype:
                 Method on how the value range is sampled. Can be either 'edge' (steps starting at
@@ -509,6 +506,12 @@ class sampling_variables:
                 Code added at the very bottom of the block.
         """
 
+        warn(
+            "This function is getting deprecated soon. please use add_sampling_variable",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+
         self.add_sampling_variable(
             name=name,
             parameter_name=parameter_name,
