@@ -33,12 +33,12 @@ class slurm:
 
     def slurmID(self, jobid=None, jobarrayindex=None):
         """
-        Function to return a Slurm job ID as a string, [jobid].[jobarrayindex]. The jobid and jobarrayindex passed in are used if given, otherwise we default to the jobid and jobarrayindex in grid_options.
+        Function to return a Slurm job ID as a string, [jobid].[jobarrayindex]. The jobid and jobarrayindex passed in are used if given, otherwise we default to the jobid and jobarrayindex in population_options.
         """
         if jobid is None:
-            jobid = self.grid_options["slurm_jobid"]
+            jobid = self.population_options["slurm_jobid"]
         if jobarrayindex is None:
-            jobarrayindex = self.grid_options["slurm_jobarrayindex"]
+            jobarrayindex = self.population_options["slurm_jobarrayindex"]
         return "{jobid}.{jobarrayindex}".format(
             jobid=jobid, jobarrayindex=jobarrayindex
         )
@@ -48,13 +48,13 @@ class slurm:
         Function to return the full slurm directory path.
         """
         if slurm_dir is None:
-            slurm_dir = self.grid_options["slurm_dir"]
+            slurm_dir = self.population_options["slurm_dir"]
 
         return os.path.abspath(os.path.join(slurm_dir, path))
 
     def slurm_status_file(self, jobid=None, jobarrayindex=None, slurm_dir=None):
         """
-        Return the slurm status file corresponding to the jobid and jobarrayindex, which default to grid_options slurm_jobid and slurm_jobarrayindex, respectively.
+        Return the slurm status file corresponding to the jobid and jobarrayindex, which default to population_options slurm_jobid and slurm_jobarrayindex, respectively.
         """
         return os.path.join(
             self.slurmpath("status", slurm_dir=slurm_dir),
@@ -63,18 +63,18 @@ class slurm:
 
     def slurm_check_requirements(self):
         """
-        Function to check whether the slurm parameters in grid_options have been set appropriately.
+        Function to check whether the slurm parameters in population_options have been set appropriately.
         """
 
-        if self.grid_options["slurm"] > 0 and (
-            self.grid_options["slurm_dir"] is None
-            or not os.path.isdir(self.grid_options["slurm_dir"])
+        if self.population_options["slurm"] > 0 and (
+            self.population_options["slurm_dir"] is None
+            or not os.path.isdir(self.population_options["slurm_dir"])
         ):
             return (
                 False,
                 "You have set slurm={slurm} but not set slurm_dir ({slurm_dir}) correctly. Please set it and try again.".format(
-                    slurm=self.grid_options["slurm"],
-                    slurm_dir=self.grid_options["slurm_dir"],
+                    slurm=self.population_options["slurm"],
+                    slurm_dir=self.population_options["slurm_dir"],
                 ),
             )
         return (True, "")
@@ -95,12 +95,14 @@ class slurm:
         """
         # save slurm jobid to file
         if slurm_dir is None:
-            slurm_dir = self.grid_options["slurm_dir"]
+            slurm_dir = self.population_options["slurm_dir"]
 
         idfile = os.path.join(slurm_dir, "jobid")
         if not os.path.exists(idfile):
             with self.open(idfile, "w", encoding="utf-8") as fjobid:
-                fjobid.write("{jobid}\n".format(jobid=self.grid_options["slurm_jobid"]))
+                fjobid.write(
+                    "{jobid}\n".format(jobid=self.population_options["slurm_jobid"])
+                )
                 fjobid.close()
                 self.NFS_flush_hack(idfile)
 
@@ -112,10 +114,10 @@ class slurm:
                 f.close()
                 self.NFS_flush_hack(status_file)
 
-        print("Have set status in", status_file, "to", string)
+        self.vb_info("Have set status in {} to {}".format(status_file, string))
         with self.open(status_file, "r", encoding="utf-8") as f:
-            print("Contents")
-            print(f.readlines())
+            self.vb_info("Contents")
+            self.vb_info(f.readlines())
             f.close()
 
     def get_slurm_status(self, jobid=None, jobarrayindex=None, slurm_dir=None):
@@ -123,9 +125,9 @@ class slurm:
         Get and return the slurm status string corresponing to the self object, or jobid.jobarrayindex if they are passed in. If no status is found, returns an empty string.
         """
         if jobid is None:
-            jobid = self.grid_options["slurm_jobid"]
+            jobid = self.population_options["slurm_jobid"]
         if jobarrayindex is None:
-            jobarrayindex = self.grid_options["slurm_jobarrayindex"]
+            jobarrayindex = self.population_options["slurm_jobarrayindex"]
         if jobid is None or jobarrayindex is None:
             return None
         try:
@@ -151,7 +153,7 @@ class slurm:
             id=self.slurmID(),
         )
         if slurm_dir is None:
-            slurm_dir = self.grid_options["slurm_dir"]
+            slurm_dir = self.population_options["slurm_dir"]
         return os.path.abspath(os.path.join(slurm_dir, "results", file))
 
     def make_slurm_dirs(self, slurm_dir=None):
@@ -162,11 +164,11 @@ class slurm:
         # TODO: replace the code block below with a function call to slurmpath
         # make the slurm directories
         if slurm_dir is None:
-            slurm_dir = self.grid_options["slurm_dir"]
+            slurm_dir = self.population_options["slurm_dir"]
 
         if not slurm_dir:
-            print(
-                "You must set self.grid_options['slurm_dir'] (or pass slurm_dir=whatever to make_slurm_dirs()) to a directory which we can use to set up binary_c-python's Slurm files. This should be unique to your set of grids."
+            self.vb_error(
+                "You must set self.population_options['slurm_dir'] (or pass slurm_dir=whatever to make_slurm_dirs()) to a directory which we can use to set up binary_c-python's Slurm files. This should be unique to your set of grids."
             )
             os.exit()
 
@@ -185,7 +187,7 @@ class slurm:
                 )
             # TODO: fix this bare exception
             except:
-                print(
+                self.vb_error(
                     "Tried to make the directory {d} but it already exists. When you launch a set of binary_c jobs on Slurm, you need to set your slurm_dir to be a fresh directory with no contents.".format(
                         d=d
                     )
@@ -202,7 +204,7 @@ class slurm:
             fail = False
             count += 1
             if count > count_warn:
-                print(
+                self.vb_warning(
                     "Warning: Have been waiting about {count} seconds for Slurm directories to be made, there seems to be significant delay...".format(
                         count=count
                     )
@@ -215,44 +217,44 @@ class slurm:
 
     def slurm_grid(self):  # pragma: no cover
         """
-        function to be called when running grids when grid_options['slurm']>=1
+        function to be called when running grids when population_options['slurm']>=1
 
-        if grid_options['slurm']==1, we set up the slurm script and launch the jobs, then return True to exit.
-        if grid_options['slurm']==2, we run the stars, which means we return False to continue.
-        if grid_options['slurm']==3, we are being called from the jobs to run the grids, return False to continue.
+        if population_options['slurm']==1, we set up the slurm script and launch the jobs, then return True to exit.
+        if population_options['slurm']==2, we run the stars, which means we return False to continue.
+        if population_options['slurm']==3, we are being called from the jobs to run the grids, return False to continue.
 
         TODO: split this function into some parts
         TODO: Comment this function better
         """
 
-        if self.grid_options["slurm"] == 2:
+        if self.population_options["slurm"] == 2:
             # run a grid of stars only, leaving the results
             # in the appropriate outfile
             return False
 
-        if self.grid_options["slurm"] == 3:
+        if self.population_options["slurm"] == 3:
             # joining : set the evolution type to "join" and return
             # False to continue
-            self.grid_options["evolution_type"] = "join"
+            self.population_options["evolution_type"] = "join"
             return False
 
-        if self.grid_options["slurm"] == 1:
+        if self.population_options["slurm"] == 1:
             # if slurm=1,  we should have no evolution type, we
             # set up the Slurm scripts and get them evolving
             # in a Slurm array
-            self.grid_options["evolution_type"] = None
+            self.population_options["evolution_type"] = None
 
             # make dirs
             self.make_slurm_dirs()
 
             # check we're not using too much RAM
-            if datasize.DataSize(self.grid_options["slurm_memory"]) > datasize.DataSize(
-                self.grid_options["slurm_warn_max_memory"]
-            ):
-                print(
+            if datasize.DataSize(
+                self.population_options["slurm_memory"]
+            ) > datasize.DataSize(self.population_options["slurm_warn_max_memory"]):
+                self.vb_error(
                     "WARNING: you want to use {slurm_memory} MB of RAM : this is unlikely to be correct. If you believe it is, set slurm_warn_max_memory to something very large (it is currently {slurm_warn_max_memory} MB)\n".format(
-                        slurm_memory=self.grid_options["slurm_memory"],
-                        slurm_warn_max_memory=self.grid_options[
+                        slurm_memory=self.population_options["slurm_memory"],
+                        slurm_warn_max_memory=self.population_options[
                             "slurm_warn_max_memory"
                         ],
                     )
@@ -260,24 +262,24 @@ class slurm:
                 self.exit(code=1)
 
             # set up slurm_array
-            if not self.grid_options["slurm_array_max_jobs"]:
-                self.grid_options["slurm_array_max_jobs"] = self.grid_options[
-                    "slurm_njobs"
-                ]
-                slurm_array = self.grid_options[
+            if not self.population_options["slurm_array_max_jobs"]:
+                self.population_options[
+                    "slurm_array_max_jobs"
+                ] = self.population_options["slurm_njobs"]
+                slurm_array = self.population_options[
                     "slurm_array"
                 ] or "1-{njobs}%{max_jobs}".format(
-                    njobs=self.grid_options["slurm_njobs"],
-                    max_jobs=self.grid_options["slurm_array_max_jobs"],
+                    njobs=self.population_options["slurm_njobs"],
+                    max_jobs=self.population_options["slurm_array_max_jobs"],
                 )
 
             # get job array index
-            jobarrayindex = self.grid_options["slurm_jobarrayindex"]
+            jobarrayindex = self.population_options["slurm_jobarrayindex"]
             if jobarrayindex is None:
                 jobarrayindex = "$SLURM_ARRAY_TASK_ID"
 
-            if self.grid_options["slurm_njobs"] == 0:
-                print(
+            if self.population_options["slurm_njobs"] == 0:
+                self.vb_error(
                     "binary_c-python Slurm : You must set grid_option slurm_njobs to be non-zero"
                 )
                 self.exit(code=1)
@@ -285,18 +287,18 @@ class slurm:
             # build the grid command
             grid_command = (
                 [
-                    str(self.grid_options["slurm_env"]),
+                    str(self.population_options["slurm_env"]),
                     sys.executable,
                     str(lib_programname.get_path_executed_script()),
                 ]
                 + sys.argv[1:]
                 + [
                     "start_at=$((" + str(jobarrayindex) + "-1))",
-                    "modulo=" + str(self.grid_options["slurm_njobs"]),
-                    "slurm_njobs=" + str(self.grid_options["slurm_njobs"]),
-                    "slurm_dir=" + self.grid_options["slurm_dir"],
-                    "verbosity=" + str(self.grid_options["verbosity"]),
-                    "num_cores=" + str(self.grid_options["num_processes"]),
+                    "modulo=" + str(self.population_options["slurm_njobs"]),
+                    "slurm_njobs=" + str(self.population_options["slurm_njobs"]),
+                    "slurm_dir=" + self.population_options["slurm_dir"],
+                    "verbosity=" + str(self.population_options["verbosity"]),
+                    "num_cores=" + str(self.population_options["_num_processes"]),
                 ]
             )
 
@@ -308,9 +310,9 @@ class slurm:
             try:
                 script = self.open(scriptpath, "w", encoding="utf-8")
             except IOError:
-                print(
+                self.vb_warning(
                     "Could not open Slurm script at {path} for writing: please check you have set {slurm_dir} correctly (it is currently {slurm_dir} and can write to this directory.".format(
-                        path=scriptpath, slurm_dir=self.grid_options["slurm_dir"]
+                        path=scriptpath, slurm_dir=self.population_options["slurm_dir"]
                     )
                 )
 
@@ -328,20 +330,20 @@ class slurm:
 #SBATCH --array={slurm_array}
 #SBATCH --cpus-per-task={ncpus}
 """.format(
-                bash=self.grid_options["slurm_bash"],
-                slurm_dir=self.grid_options["slurm_dir"],
-                slurm_jobname=self.grid_options["slurm_jobname"],
-                slurm_partition=self.grid_options["slurm_partition"],
-                slurm_time=self.grid_options["slurm_time"],
-                slurm_ntasks=self.grid_options["slurm_ntasks"],
-                slurm_memory=self.grid_options["slurm_memory"],
+                bash=self.population_options["slurm_bash"],
+                slurm_dir=self.population_options["slurm_dir"],
+                slurm_jobname=self.population_options["slurm_jobname"],
+                slurm_partition=self.population_options["slurm_partition"],
+                slurm_time=self.population_options["slurm_time"],
+                slurm_ntasks=self.population_options["slurm_ntasks"],
+                slurm_memory=self.population_options["slurm_memory"],
                 slurm_array=slurm_array,
-                ncpus=self.grid_options["num_processes"],
+                ncpus=self.population_options["_num_processes"],
             )
 
-            for key in self.grid_options["slurm_extra_settings"]:
+            for key in self.population_options["slurm_extra_settings"]:
                 slurmscript += "#SBATCH --{key} = {value}\n".format(
-                    key=key, value=self.grid_options["slurm_extra_settings"][key]
+                    key=key, value=self.population_options["slurm_extra_settings"][key]
                 )
 
             slurmscript += """
@@ -358,17 +360,17 @@ echo \"running\" > "{slurm_dir}/status/$SLURM_ARRAY_JOB_ID.$SLURM_ARRAY_TASK_ID"
 
 # run grid of stars and, if this returns 0, set status to finished
 {grid_command} "slurm=2" "evolution_type=grid" "slurm_jobid=$SLURM_ARRAY_JOB_ID" "slurm_jobarrayindex=$SLURM_ARRAY_TASK_ID" "save_population_object={slurm_dir}/results/$SLURM_ARRAY_JOB_ID.$SLURM_ARRAY_TASK_ID.gz" && echo -n \"finished\" > "{slurm_dir}/status/$SLURM_ARRAY_JOB_ID.$SLURM_ARRAY_TASK_ID" && echo """.format(
-                slurm_dir=self.grid_options["slurm_dir"],
+                slurm_dir=self.population_options["slurm_dir"],
                 grid_command=grid_command,
-                cmdline=repr(self.grid_options["command_line"]),
-                date=self.grid_options["slurm_date"],
-                pwd=self.grid_options["slurm_pwd"],
+                cmdline=repr(self.population_options["command_line"]),
+                date=self.population_options["slurm_date"],
+                pwd=self.population_options["slurm_pwd"],
             )
 
-            if not self.grid_options["slurm_postpone_join"]:
+            if not self.population_options["slurm_postpone_join"]:
                 slurmscript += """&& echo \"Checking if we can join...\" && echo && {grid_command} "slurm=3" "evolution_type=join" "joinlist={slurm_dir}/results/$SLURM_ARRAY_JOB_ID.all" "slurm_jobid=$SLURM_ARRAY_JOB_ID" "slurm_jobarrayindex=$SLURM_ARRAY_TASK_ID"
                 """.format(
-                    slurm_dir=self.grid_options["slurm_dir"],
+                    slurm_dir=self.population_options["slurm_dir"],
                     grid_command=grid_command,
                 )
             else:
@@ -389,9 +391,9 @@ echo \"running\" > "{slurm_dir}/status/$SLURM_ARRAY_JOB_ID.$SLURM_ARRAY_TASK_ID"
                 | stat.S_IXOTH,
             )
 
-            if not self.grid_options["slurm_postpone_sbatch"]:
+            if not self.population_options["slurm_postpone_sbatch"]:
                 # call sbatch to launch the jobs
-                cmd = [self.grid_options["slurm_sbatch"], scriptpath]
+                cmd = [self.population_options["slurm_sbatch"], scriptpath]
 
                 with subprocess.Popen(
                     cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE
@@ -409,7 +411,7 @@ echo \"running\" > "{slurm_dir}/status/$SLURM_ARRAY_JOB_ID.$SLURM_ARRAY_TASK_ID"
                         raise Exception(err_msg)
 
                 if len(std_err):
-                    print(
+                    self.vb_info(
                         "{red}{err}{reset}".format(
                             red=self.ANSI_colours["red"],
                             reset=self.ANSI_colours["reset"],
@@ -417,7 +419,7 @@ echo \"running\" > "{slurm_dir}/status/$SLURM_ARRAY_JOB_ID.$SLURM_ARRAY_TASK_ID"
                         )
                     )
 
-                print(
+                self.vb_info(
                     "{yellow}{out}{reset}".format(
                         yellow=self.ANSI_colours["yellow"],
                         reset=self.ANSI_colours["reset"],
@@ -426,20 +428,20 @@ echo \"running\" > "{slurm_dir}/status/$SLURM_ARRAY_JOB_ID.$SLURM_ARRAY_TASK_ID"
                 )
             else:
                 # just say we would have (use this for testing)
-                print(
+                self.vb_warning(
                     "Slurm script is at {path} but has not been launched".format(
                         path=scriptpath
                     )
                 )
 
         # some messages to the user, then return
-        if self.grid_options["slurm_postpone_sbatch"] == 1:
-            print(
+        if self.population_options["slurm_postpone_sbatch"] == 1:
+            self.vb_info(
                 "Slurm script written, but launching the jobs with sbatch was postponed."
             )
         else:
-            print("Slurm jobs launched")
-            print("All done in slurm_grid().")
+            self.vb_info("Slurm jobs launched")
+            self.vb_info("All done in slurm_grid().")
 
         # return True so we exit immediately
         return True
