@@ -21,6 +21,8 @@ import diskcache
 import numpy as np
 import py_rinterpolate
 
+from binarycpython.utils.functions import output_lines
+
 
 class spacing_functions:
     """
@@ -199,7 +201,7 @@ class spacing_functions:
             logmasses: if True, the masses are logged with math.log()
             log10masses: if True, the masses are logged with math.log10()
             usecache: if True (the default) uses cached results if they are saved (in cachedir) and cachedir is not None
-            cachedir: where the cache is stored. if None, defaults to grid_options['cache_dir']+'/const_dt_cache'
+            cachedir: where the cache is stored. if None, defaults to population_options['cache_dir']+'/const_dt_cache'
             vb : verbose logging flag (default False)
 
         Returns:
@@ -218,16 +220,16 @@ class spacing_functions:
 
         if usecache:
             if cachedir is None:
-                cachedir = self.grid_options["cache_dir"]
+                cachedir = self.population_options["cache_dir"]
 
             if cachedir is not None:
                 cachedir += "/const_dt_cache"
                 cache = diskcache.Cache(cachedir)
-                print(
+                self.vb_info(
                     "Use const_dt cache in {} [cache object {}]".format(cachedir, cache)
                 )
             else:
-                print("const_dt uses no cache")
+                self.vb_info("const_dt uses no cache")
                 cache = None
 
         def _const_dt_wrapper(
@@ -258,7 +260,7 @@ class spacing_functions:
             Wrapper function for the const_dt funtion which handles verbose logging and filtering of arguments
             """
 
-            print(
+            self.vb_debug(
                 "call _const_dt num_cores={} dt={} dlogt={} mmin={} mmax={} nres={} logspacing={} tmin={} mindm={} maxdm={} fsample={} factor={} logmasses={} log10masses={} showlist={} usecache={} [cache={} vb={}]".format(
                     num_cores,
                     dt,
@@ -299,7 +301,7 @@ class spacing_functions:
                 bse_stripped, sort_keys=True, ensure_ascii=False
             )
             if vb:
-                print("BSE options JSON:", bse_options_json)
+                self.vb_info("BSE options JSON:", bse_options_json)
 
             return _const_dt(
                 cachedir=cachedir,
@@ -439,36 +441,40 @@ class spacing_functions:
                 """
 
                 if output:
-                    for line in output.splitlines():
+                    for line in output_lines(output):
                         data = line.split()
                         if data[0] == "SINGLE_STAR_LIFETIME":
                             # append (log10(mass), log10(lifetime)) tuples
                             logm = math.log10(float(data[1]))
                             logt = math.log10(float(data[2]))
-                            # print(line)
-                            # print("logM=",logm,"M=",10.0**logm," -> logt=",logt)
-                            self.grid_results["interpolation table m->t"][logm] = logt
-                            self.grid_results["interpolation table t->m"][logt] = logm
+
+                            self.population_results["interpolation table m->t"][
+                                logm
+                            ] = logt
+                            self.population_results["interpolation table t->m"][
+                                logt
+                            ] = logm
 
             lifetime_population.set(
                 parse_function=_parse_function,
             )
 
             # run to build the interpolation table
-            print(
+            self.vb_info(
                 "Running population to make lifetime interpolation table, please wait"
             )
             lifetime_population.evolve()
-            # print("Data table",lifetime_population.grid_results['interpolation table t->m'])
 
             if (
-                "interpolation table t->m" not in lifetime_population.grid_results
+                "interpolation table t->m" not in lifetime_population.population_results
                 or len(
-                    lifetime_population.grid_results["interpolation table t->m"].keys()
+                    lifetime_population.population_results[
+                        "interpolation table t->m"
+                    ].keys()
                 )
                 == 0
             ):
-                print(
+                self.vb_error(
                     "\n\n\nError: The t->m lifetime table is empty. One usual cause for this is that the tmax or max_evolution_time option (currently passed in to const_dt as {tmax}) is too short for there to be any entries in the table before the first timestep. Try increasing tmax and max_evolution_time, shorten the timestep or, if using log times, set tstart to be closer to 0.\n".format(
                         tmax=tmax
                     )
@@ -480,12 +486,14 @@ class spacing_functions:
             # make time -> mass table
             data_table_time_mass = []
             times = sorted(
-                lifetime_population.grid_results["interpolation table t->m"].keys()
+                lifetime_population.population_results[
+                    "interpolation table t->m"
+                ].keys()
             )
             for time in times:
-                mass = lifetime_population.grid_results["interpolation table t->m"][
-                    time
-                ]
+                mass = lifetime_population.population_results[
+                    "interpolation table t->m"
+                ][time]
                 # we have to make sure the time is monotonic (not guaranteed at high mass)
                 if len(data_table_time_mass) == 0:
                     data_table_time_mass.append([time, mass])
@@ -495,12 +503,14 @@ class spacing_functions:
             # make mass -> time table
             data_table_mass_time = []
             masses = sorted(
-                lifetime_population.grid_results["interpolation table m->t"].keys()
+                lifetime_population.population_results[
+                    "interpolation table m->t"
+                ].keys()
             )
             for mass in masses:
-                time = lifetime_population.grid_results["interpolation table m->t"][
-                    mass
-                ]
+                time = lifetime_population.population_results[
+                    "interpolation table m->t"
+                ][mass]
                 data_table_mass_time.append([mass, time])
 
             # set up interpolators
@@ -630,7 +640,7 @@ class spacing_functions:
                     t = _time_from_mass(m)
                     logt = math.log10(t)
                     if twas > 0.0:
-                        print(
+                        self.vb_debug(
                             "{i:4d} m={m:13g} t={t:13g} log10(t)={logt:13g} dt={dt:13g} dlog10(t)={dlogt:13g}".format(
                                 i=i,
                                 m=m,
@@ -641,7 +651,7 @@ class spacing_functions:
                             )
                         )
                     else:
-                        print(
+                        self.vb_debug(
                             "{i:4d} m={m:13g} t={t:13g} log10(t)={logt:13g}".format(
                                 i=i, m=m, t=t, logt=logt
                             )
@@ -671,7 +681,7 @@ class spacing_functions:
 
         mass_list = _const_dt_wrapper(
             cachedir=cachedir,
-            num_cores=self.grid_options["num_cores"],
+            num_cores=self.population_options["num_cores"],
             bse_options=self.bse_options,
             **kwargs,
         )
@@ -679,6 +689,8 @@ class spacing_functions:
             cache.close()
 
         if kwargs.get("showlist", True):
-            print("const_dt mass list ({} masses)\n".format(len(mass_list)), mass_list)
+            self.vb_debug(
+                "const_dt mass list ({} masses)\n".format(len(mass_list)), mass_list
+            )
 
         return mass_list
