@@ -46,56 +46,55 @@ class version_info:
             dictionary
         """
 
-        found_prev = False
+        #####
+        # Check if the headers were previously defined
+        found_prev_MACRO_HEADER = False
         if "BINARY_C_MACRO_HEADER" in os.environ:
             # the env var is already present. lets save that and put that back later
-            found_prev = True
-            prev_value = os.environ["BINARY_C_MACRO_HEADER"]
+            found_prev_MACRO_HEADER = True
+            prev_value_MACRO_HEADER = os.environ["BINARY_C_MACRO_HEADER"]
 
-        #
+        found_prev_DEFLIST_HEADER = False
+        if "BINARY_C_DEFLIST_HEADER" in os.environ:
+            # the env var is already present. lets save that and put that back later
+            found_prev_DEFLIST_HEADER = True
+            prev_value_DEFLIST_HEADER = os.environ["BINARY_C_DEFLIST_HEADER"]
+
+        #############
+        # set new headers
         os.environ["BINARY_C_MACRO_HEADER"] = "macroxyz"
+        os.environ["BINARY_C_DEFLIST_HEADER"] = "deflist "
 
+        #############
         # Get version_info
         raw_version_info = _binary_c_bindings.return_version_info().strip()
 
-        # delete value
+        #############
+        # delete current headers
         del os.environ["BINARY_C_MACRO_HEADER"]
+        del os.environ["BINARY_C_DEFLIST_HEADER"]
 
-        # put stuff back if we found a previous one
-        if found_prev:
-            os.environ["BINARY_C_MACRO_HEADER"] = prev_value
+        #############
+        # put back previous headers
+        if found_prev_MACRO_HEADER:
+            os.environ["BINARY_C_MACRO_HEADER"] = prev_value_MACRO_HEADER
 
-        # parse if wanted
+        if found_prev_DEFLIST_HEADER:
+            os.environ["BINARY_C_DEFLIST_HEADER"] = prev_value_DEFLIST_HEADER
+
+        ##############
+        # return (parsed) version info
         if parsed:
             parsed_version_info = self.parse_binary_c_version_info(raw_version_info)
             return parsed_version_info
 
         return raw_version_info
 
-    def parse_binary_c_version_info(self, version_info_string: str) -> dict:
+    def _parse_binary_c_version_info_networks(self, networks):
         """
-        Function that parses the binary_c version info. Long function with a lot of branches
-
-        Args:
-            version_info_string: raw output of version_info call to binary_c
-
-        Returns:
-            Parsed version of the version info, which is a dictionary containing the keys: 'isotopes' for isotope info, 'argpairs' for argument pair info (TODO: explain), 'ensembles' for ensemble settings/info, 'macros' for macros, 'elements' for atomic element info, 'DTlimit' for (TODO: explain), 'nucleosynthesis_sources' for nucleosynthesis sources, and 'miscellaneous' for all those that were not caught by the previous groups. 'git_branch', 'git_build', 'revision' and 'email' are also keys, but its clear what those contain.
+        Function to parse the networks info
         """
 
-        version_info_dict = {}
-
-        # Clean data and put in correct shape
-        splitted = version_info_string.strip().splitlines()
-        cleaned = {el.strip() for el in splitted if not el == ""}
-
-        ##########################
-        # Network:
-        # Split off all the networks and parse the info.
-
-        networks = {el for el in cleaned if el.startswith("Network ")}
-        cleaned = cleaned - networks
-
         networks_dict = {}
         for el in networks:
             network_dict = {}
@@ -124,13 +123,13 @@ class version_info:
                     ]
 
             networks_dict[network_number] = copy.deepcopy(network_dict)
-        version_info_dict["networks"] = networks_dict if networks_dict else None
 
-        ##########################
-        # Isotopes:
-        # Split off
-        isotopes = {el for el in cleaned if el.startswith("Isotope ")}
-        cleaned -= isotopes
+        return networks_dict if networks_dict else None
+
+    def _parse_binary_c_version_info_isotopes(self, isotopes):
+        """
+        Function to parse the isotopes info
+        """
 
         isotope_dict = {}
         for el in isotopes:
@@ -161,13 +160,13 @@ class version_info:
                 "mass_g": mass_g,
                 "mass_amu": mass_amu,
             }
-        version_info_dict["isotopes"] = isotope_dict if isotope_dict else None
 
-        ##########################
-        # Arg pairs:
-        # Split off
-        argpairs = {el for el in cleaned if el.startswith("ArgPair")}
-        cleaned -= argpairs
+        return isotope_dict if isotope_dict else None
+
+    def _parse_binary_c_version_info_argpairs(self, argpairs):
+        """
+        Function to parse the argpairs info
+        """
 
         argpair_dict = {}
         for el in sorted(argpairs):
@@ -178,13 +177,12 @@ class version_info:
             else:
                 argpair_dict[split_info[0]][split_info[1]] = split_info[2]
 
-        version_info_dict["argpairs"] = argpair_dict if argpair_dict else None
+        return argpair_dict if argpair_dict else None
 
-        ##########################
-        # ensembles:
-        # Split off
-        ensembles = {el for el in cleaned if el.startswith("Ensemble")}
-        cleaned -= ensembles
+    def _parse_binary_c_version_info_ensembles(self, ensembles):
+        """
+        Function to parse the ensembles info
+        """
 
         ensemble_dict = {}
         ensemble_filter_dict = {}
@@ -198,16 +196,12 @@ class version_info:
                     filter_no = int(split_info[0].replace("filter ", ""))
                     ensemble_filter_dict[filter_no] = split_info[-1]
 
-        version_info_dict["ensembles"] = ensemble_dict if ensemble_dict else None
-        version_info_dict["ensemble_filters"] = (
-            ensemble_filter_dict if ensemble_filter_dict else None
-        )
+        return ensemble_dict, ensemble_filter_dict
 
-        ##########################
-        # macros:
-        # Split off
-        macros = {el for el in cleaned if el.startswith("macroxyz")}
-        cleaned -= macros
+    def _parse_binary_c_version_info_macros(self, macros):
+        """
+        Function to parse the macros info
+        """
 
         param_type_dict = {
             "STRING": str,
@@ -228,13 +222,10 @@ class version_info:
             param_value = " is ".join(new_split[1:])
             param_value = param_value.strip()
 
-            # print("macro ",param_name,"=",param_value," float?",isfloat(param_value)," int?",isint(param_value))
-
             # If we're trying to set the value to "on", check that
             # it doesn't already exist. If it does, do nothing, as the
             # extra information is better than just "on"
             if param_name in macros_dict:
-                # print("already exists (is ",macros_dict[param_name]," float? ",isfloat(macros_dict[param_name]),", int? ",isint(macros_dict[param_name]),") : check that we can improve it")
                 if macros_dict[param_name] == "on":
                     # update with better value
                     store = True
@@ -248,10 +239,6 @@ class version_info:
                     # don't override existing number
                     store = False
 
-                # if store:
-                #    print("Found improved macro value of param",param_name,", was ",macros_dict[param_name],", is",param_value)
-                # else:
-                #    print("Cannot improve: use old value")
             else:
                 store = True
 
@@ -263,13 +250,12 @@ class version_info:
                 except ValueError:
                     macros_dict[param_name] = str(param_value)
 
-        version_info_dict["macros"] = macros_dict if macros_dict else None
+        return macros_dict if macros_dict else None
 
-        ##########################
-        # Elements:
-        # Split off:
-        elements = {el for el in cleaned if el.startswith("Element")}
-        cleaned -= elements
+    def _parse_binary_c_version_info_elements(self, elements):
+        """
+        Function to parse the elements info
+        """
 
         # Fill dict:
         elements_dict = {}
@@ -292,13 +278,13 @@ class version_info:
                 "amt_isotopes": len(isotopes),
                 "isotopes": isotopes,
             }
-        version_info_dict["elements"] = elements_dict if elements_dict else None
 
-        ##########################
-        # dt_limits:
-        # split off
-        dt_limits = {el for el in cleaned if el.startswith("DTlimit")}
-        cleaned -= dt_limits
+        return elements_dict if elements_dict else None
+
+    def _parse_binary_c_version_info_dt_limits(self, dt_limits):
+        """
+        Function to parse the dt_limits info
+        """
 
         # Fill dict
         dt_limits_dict = {}
@@ -309,15 +295,17 @@ class version_info:
                 "value": float(split_info[-1]),
             }
 
-        version_info_dict["dt_limits"] = dt_limits_dict if dt_limits_dict else None
+        return dt_limits_dict if dt_limits_dict else None
 
-        ##############################
-        # Units
+    def _parse_binary_c_version_info_units(self, unit, units):
+        """
+        Function to parse the units info
+
+        TODO: i'm not sure that this parsing is correct
+        """
 
-        units = {el for el in cleaned if el.startswith("Unit ")}
-        cleaned -= units
         units_dict = {}
-        for el in units:
+        for el in unit:
             split_info = el.split("Unit ")[-1].split(",")
             s = split_info[0].split(" is ")
 
@@ -326,7 +314,7 @@ class version_info:
             elif len(s) == 1:
                 long, short = None, s[0]
             else:
-                print("Warning: Failed to split unit string {}".format(el))
+                self.vb_warning("Warning: Failed to split unit string {}".format(el))
 
             to_cgs = (split_info[1].split())[3].strip().strip('"')
             code_units = split_info[2].split()
@@ -343,19 +331,16 @@ class version_info:
             }
 
         # Add the list of units
-        units = {el for el in cleaned if el.startswith("Units: ")}
-        cleaned -= units
         for el in units:
             el = el[7:]  # removes "Units: "
             units_dict["units list"] = el.strip("Units:")
 
-        version_info_dict["units"] = units_dict
+        return units_dict if units_dict else None
 
-        ##########################
-        # Nucleosynthesis sources:
-        # Split off
-        nucsyn_sources = {el for el in cleaned if el.startswith("Nucleosynthesis")}
-        cleaned -= nucsyn_sources
+    def _parse_binary_c_version_nucsyn_sources(self, nucsyn_sources):
+        """
+        Function to parse the nucsyn_sources info
+        """
 
         # Fill dict
         nucsyn_sources_dict = {}
@@ -363,10 +348,210 @@ class version_info:
             split_info = el.split("Nucleosynthesis source")[-1].strip().split(" is ")
             nucsyn_sources_dict[int(split_info[0])] = split_info[-1]
 
-        version_info_dict["nucleosynthesis_sources"] = (
-            nucsyn_sources_dict if nucsyn_sources_dict else None
+        return nucsyn_sources_dict if nucsyn_sources_dict else None
+
+    def _parse_binary_c_version_binary_c_error_codes(self, binary_c_error_codes):
+        """
+        Function to parse the binary_c_error_codes info
+        """
+
+        binary_c_error_codes_dict = {}
+        for el in binary_c_error_codes:
+            split_info = el.split("Error code")[-1].strip().split(" = ")
+
+            # extract info
+            number = int(split_info[1].split()[0])
+            name = str(split_info[0])
+            description = str(split_info[1].split()[1].replace('"', ""))
+
+            binary_c_error_codes_dict[number] = {
+                "number": number,
+                "name": name,
+                "description": description,
+            }
+
+        return binary_c_error_codes_dict if binary_c_error_codes_dict else None
+
+    def _parse_binary_c_version_deflists(self, deflists):
+        """
+        Function to parse the deflists info
+        """
+
+        deflist_dict = {}
+        for el in deflists:
+            split_info = el.split("deflist")[-1].strip().split()
+
+            # Extract data
+            deflist_type = split_info[0]
+            deflist_data = " ".join(split_info[1:])
+
+            # Check if current type is already known
+            if deflist_type not in deflist_dict:
+                deflist_dict[deflist_type] = {}
+
+            # store data in current type dict
+            deflist_data_split = deflist_data.split(" is ")
+            deflist_data_number = int(deflist_data_split[0])
+            deflist_data_name = str(deflist_data_split[1])
+
+            deflist_dict[deflist_type][deflist_data_number] = deflist_data_name
+
+        return deflist_dict if deflist_dict else None
+
+    def parse_binary_c_version_info(self, version_info_string: str) -> dict:
+        """
+        Function that parses the binary_c version info. Long function with a lot of branches
+
+        Args:
+            version_info_string: raw output of version_info call to binary_c
+
+        Returns:
+            Parsed version of the version info, which is a dictionary containing the keys: 'isotopes' for isotope info, 'argpairs' for argument pair info (TODO: explain), 'ensembles' for ensemble settings/info, 'macros' for macros, 'elements' for atomic element info, 'DTlimit' for (TODO: explain), 'nucleosynthesis_sources' for nucleosynthesis sources, and 'miscellaneous' for all those that were not caught by the previous groups. 'git_branch', 'git_build', 'revision' and 'email' are also keys, but its clear what those contain.
+        """
+
+        version_info_dict = {}
+
+        # Clean data and put in correct shape
+        splitted = version_info_string.strip().splitlines()
+        cleaned = {el.strip() for el in splitted if not el == ""}
+
+        ##########################
+        # Network:
+
+        # Split off all the networks
+        networks = {el for el in cleaned if el.startswith("Network ")}
+        cleaned = cleaned - networks
+
+        # and parse the info
+        version_info_dict["networks"] = self._parse_binary_c_version_info_networks(
+            networks
         )
 
+        ##########################
+        # Isotopes:
+
+        # Split off all the isotopes
+        isotopes = {el for el in cleaned if el.startswith("Isotope ")}
+        cleaned -= isotopes
+
+        # and parse the info
+        version_info_dict["isotopes"] = self._parse_binary_c_version_info_isotopes(
+            isotopes
+        )
+
+        ##########################
+        # Arg pairs:
+
+        # Split off all the argpairs
+        argpairs = {el for el in cleaned if el.startswith("ArgPair")}
+        cleaned -= argpairs
+
+        # and parse the info
+        version_info_dict["argpairs"] = self._parse_binary_c_version_info_argpairs(
+            argpairs
+        )
+
+        ##########################
+        # ensembles:
+
+        # Split off all the ensembles
+        ensembles = {el for el in cleaned if el.startswith("Ensemble")}
+        cleaned -= ensembles
+
+        # and parse the info
+        (
+            ensemble_dict,
+            ensemble_filter_dict,
+        ) = self._parse_binary_c_version_info_ensembles(ensembles)
+
+        version_info_dict["ensembles"] = ensemble_dict if ensemble_dict else None
+        version_info_dict["ensemble_filters"] = (
+            ensemble_filter_dict if ensemble_filter_dict else None
+        )
+
+        ##########################
+        # macros:
+
+        # Split off of all the macros
+        macros = {el for el in cleaned if el.startswith("macroxyz")}
+        cleaned -= macros
+
+        # and parse the info
+        version_info_dict["macros"] = self._parse_binary_c_version_info_macros(macros)
+
+        ##########################
+        # Elements:
+
+        # Split off all the elements
+        elements = {el for el in cleaned if el.startswith("Element")}
+        cleaned -= elements
+
+        # and parse the info
+        version_info_dict["elements"] = self._parse_binary_c_version_info_elements(
+            elements
+        )
+
+        ##########################
+        # dt_limits:
+
+        # split off all the dt_limits
+        dt_limits = {el for el in cleaned if el.startswith("DTlimit")}
+        cleaned -= dt_limits
+
+        # and parse the info
+        version_info_dict["dt_limits"] = self._parse_binary_c_version_info_dt_limits(
+            dt_limits
+        )
+
+        ##############################
+        # Units
+
+        # split off all the units
+        unit = {el for el in cleaned if el.startswith("Unit ")}
+        cleaned -= unit
+
+        units = {el for el in cleaned if el.startswith("Units: ")}
+        cleaned -= units
+
+        # and parse the info
+        version_info_dict["units"] = self._parse_binary_c_version_info_units(
+            unit, units
+        )
+
+        ##########################
+        # Nucleosynthesis sources:
+
+        # Split off all the nucsyn sources
+        nucsyn_sources = {el for el in cleaned if el.startswith("Nucleosynthesis")}
+        cleaned -= nucsyn_sources
+
+        # and parse the info
+        version_info_dict[
+            "nucleosynthesis_sources"
+        ] = self._parse_binary_c_version_nucsyn_sources(nucsyn_sources)
+
+        ##########################
+        # binary_c_errors:
+
+        # Split off all the nucsyn sources
+        binary_c_error_codes = {el for el in cleaned if el.startswith("Error code")}
+        cleaned -= binary_c_error_codes
+
+        # and parse the info
+        version_info_dict[
+            "binary_c_error_codes"
+        ] = self._parse_binary_c_version_binary_c_error_codes(binary_c_error_codes)
+
+        ##########################
+        # deflist:
+
+        # Split off all the deflists
+        deflists = {el for el in cleaned if el.startswith("deflist")}
+        cleaned -= deflists
+
+        # and parse the info
+        version_info_dict["deflists"] = self._parse_binary_c_version_deflists(deflists)
+
         ##########################
         # miscellaneous:
         # All those that I didn't catch with the above filters. Could try to get some more out though.
@@ -425,7 +610,8 @@ class version_info:
         """
         Function to return the minimum stellar mass (in Msun) from binary_c.
         """
-        if not self._minimum_stellar_mass:
+
+        if not hasattr(self, "_minimum_stellar_mass"):
             self._minimum_stellar_mass = self.return_binary_c_version_info(parsed=True)[
                 "macros"
             ]["BINARY_C_MINIMUM_STELLAR_MASS"]
