@@ -3,17 +3,11 @@ Module containing the utility function run_system,
 which handles a lot of things by analysing the passed kwargs
 """
 
-from binarycpython.utils.functions import (
-    create_arg_string,
-    get_arg_keys,
-    remove_file,
-)
-
+from binarycpython import _binary_c_bindings
 from binarycpython.utils.custom_logging_functions import (
     create_and_load_logging_function,
 )
-
-from binarycpython import _binary_c_bindings
+from binarycpython.utils.functions import create_arg_string, get_arg_keys, remove_file
 
 
 def run_system(**kwargs):
@@ -80,7 +74,7 @@ def run_system(**kwargs):
 
         # Notify user when this key wont be used
         else:
-            if not key in other_keywords:
+            if key not in other_keywords:
                 print(
                     "The following keyword was not recognised and wont be used:\n\t{}".format(
                         key
