@@ -19,7 +19,7 @@
  *
  * The second section is composed of the functions that interface with the binary_c API
  *
- * Written by David Hendriks (davidhendriks93@gmail.com), Robert Izzard (r.izzard@surrey.ac.uk).
+ * Written by David Hendriks (davidhendriks93@gmail.com), Robert Izzard (rob.izzard@gmail.com).
  * Based on initial work of Jeff Andrews
  * Remember: variables must be passed by references
  * (i.e. as pointers).
@@ -107,8 +107,8 @@ static PyObject* python_run_system(PyObject *self, PyObject *args, PyObject *kwa
 
 // Utility function headers
 static PyObject* python_return_arglines(PyObject *self, PyObject *args);
-static PyObject* python_return_help_info(PyObject *self, PyObject *args);
-static PyObject* python_return_help_all_info(PyObject *self, PyObject *args);
+static PyObject* python_return_help_info(PyObject *self, PyObject *args, PyObject *kwargs);
+static PyObject* python_return_help_all_info(PyObject *self, PyObject *args, PyObject *kwargs);
 static PyObject* python_return_version_info(PyObject *self, PyObject *args);
 static PyObject* python_return_minimum_orbit_for_RLOF(PyObject *self, PyObject *args, PyObject *kwargs);
 static PyObject* python_return_maximum_mass_ratio_for_RLOF(PyObject *self, PyObject *args, PyObject *kwargs);
@@ -130,8 +130,8 @@ static PyMethodDef module_methods[] =
 
     //
     {"return_arglines", python_return_arglines, METH_VARARGS, return_arglines_docstring},
-    {"return_help", python_return_help_info, METH_VARARGS, return_help_info_docstring},
-    {"return_help_all", python_return_help_all_info, METH_VARARGS, return_help_all_info_docstring},
+    {"return_help", (PyCFunction)python_return_help_info, METH_VARARGS | METH_KEYWORDS, return_help_info_docstring},
+    {"return_help_all", (PyCFunction)python_return_help_all_info, METH_VARARGS | METH_KEYWORDS, return_help_all_info_docstring},
     {"return_version_info", python_return_version_info, METH_VARARGS, return_version_info_docstring},
     {"return_minimum_orbit_for_RLOF", (PyCFunction)python_return_minimum_orbit_for_RLOF, METH_VARARGS | METH_KEYWORDS, return_minimum_orbit_for_RLOF_docstring},
     {"return_maximum_mass_ratio_for_RLOF", (PyCFunction)python_return_maximum_mass_ratio_for_RLOF, METH_VARARGS | METH_KEYWORDS, return_maximum_mass_ratio_for_RLOF_docstring},
@@ -300,20 +300,37 @@ static PyObject* python_return_arglines(PyObject *self, PyObject *args)
     return return_string;
 }
 
-static PyObject* python_return_help_info(PyObject *self, PyObject *args)
+static PyObject* python_return_help_info(PyObject *self, PyObject *args, PyObject *kwargs)
 {
+
+    static char* keywords[] = {"argstring", "store_memaddr", NULL};
+
     /* Parse the input tuple */
     char *argstring;
+    PyObject *  store_capsule = NULL;
 
-    if (!PyArg_ParseTuple(args, "s", &argstring))
+    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "s|O", keywords, &argstring, &store_capsule))
     {
         return NULL;
     }
 
+    // Store
+    struct libbinary_c_store_t * store = NULL;
+    if (store_capsule != NULL)
+    {
+        if (PyCapsule_IsValid(store_capsule, "STORE"))
+        {
+            if (!(store = (struct libbinary_c_store_t *) PyCapsule_GetPointer(store_capsule, "STORE")))
+                return NULL;
+            debug_printf("Unpacked store pointer %p from capsule\n", store_capsule);
+        }
+    }
+
     char * buffer;
     char * error_buffer;
     size_t nbytes;
     int out MAYBE_UNUSED = return_help_info(argstring,
+                                            store,                // TODO: change. memory adress for the store object
                                             &buffer,
                                             &error_buffer,
                                             &nbytes);
@@ -335,14 +352,43 @@ static PyObject* python_return_help_info(PyObject *self, PyObject *args)
     return return_string;
 }
 
-static PyObject* python_return_help_all_info(PyObject *self, PyObject *args)
+static PyObject* python_return_help_all_info(PyObject *self, PyObject *args, PyObject *kwargs)
 {
+
+    static char* keywords[] = {"store_memaddr", NULL};
+
+    /* Parse the input tuple */
+    char *argstring = NULL;
+    PyObject *  store_capsule = NULL;
+
+    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "|O", keywords, &store_capsule))
+    {
+        return NULL;
+    }
+
+    // Store
+    struct libbinary_c_store_t * store = NULL;
+    if (store_capsule != NULL)
+    {
+        if (PyCapsule_IsValid(store_capsule, "STORE"))
+        {
+            if (!(store = (struct libbinary_c_store_t *) PyCapsule_GetPointer(store_capsule, "STORE")))
+                return NULL;
+            debug_printf("Unpacked store pointer %p from capsule\n", store_capsule);
+        }
+    }
+
     char * buffer;
     char * error_buffer;
     size_t nbytes;
-    int out MAYBE_UNUSED = return_help_all_info(&buffer,
-                           &error_buffer,
-                           &nbytes);
+
+    int out MAYBE_UNUSED = return_help_all_info(
+                               argstring,
+                               store,                // TODO: change. memory adress for the store object
+                               &buffer,
+                               &error_buffer,
+                               &nbytes
+                           );
 
     /* copy the buffer to a python string */
     PyObject * return_string = Py_BuildValue("s", buffer);
@@ -938,12 +984,20 @@ int return_arglines(char ** const buffer,
 
 
 int return_help_info(char * argstring,
+                     struct libbinary_c_store_t * store,
                      char ** const buffer,
                      char ** const error_buffer,
                      size_t * const nbytes)
 {
     struct libbinary_c_stardata_t *stardata = NULL;
-    struct libbinary_c_store_t *store = NULL;
+
+    /* Determine whether to free the store memory adress*/
+    Boolean free_store = FALSE;
+    if (store == NULL)
+    {
+        debug_printf("Decided to free the store memaddr\n");
+        free_store = TRUE;
+    }
 
     /* Set up new system */
     binary_c_new_system(&stardata,          // stardata
@@ -972,7 +1026,7 @@ int return_help_info(char * argstring,
     binary_c_free_memory(&stardata, // Stardata
                          TRUE,                       // free_preferences
                          TRUE,                       // free_stardata
-                         TRUE,                       // free_store
+                         free_store,                       // free_store
                          FALSE,                      // free_raw_buffer
                          TRUE                        // free_persistent
                         );
@@ -981,14 +1035,24 @@ int return_help_info(char * argstring,
 }
 
 
-int return_help_all_info(char ** const buffer,
-                         char ** const error_buffer,
-                         size_t * const nbytes)
+int return_help_all_info(
+    char * argstring,
+    struct libbinary_c_store_t * store,
+    char ** const buffer,
+    char ** const error_buffer,
+    size_t * const nbytes)
 {
     struct libbinary_c_stardata_t *stardata = NULL;
-    struct libbinary_c_store_t *store = NULL;
     char * empty_str = "";
 
+    /* Determine whether to free the store memory adress*/
+    Boolean free_store = FALSE;
+    if (store == NULL)
+    {
+        debug_printf("Decided to free the store memaddr\n");
+        free_store = TRUE;
+    }
+
     /* Set up new system */
     binary_c_new_system(&stardata,          // stardata
                         NULL,               // previous_stardatas
@@ -1016,7 +1080,7 @@ int return_help_all_info(char ** const buffer,
     binary_c_free_memory(&stardata, // Stardata
                          TRUE,                       // free_preferences
                          TRUE,                       // free_stardata
-                         TRUE,                       // free_store
+                         free_store,                 // free_store
                          FALSE,                      // free_raw_buffer
                          TRUE                        // free_persistent
                         );
